
#ifdef GET_DIAG_ARRAYS
static const int16_t DiagArrays[] = {
  /* Empty */ -1,
  /* DiagArray1 */ diag::warn_pragma_message, -1,
  /* DiagArray2 */ diag::pp_hash_warning, -1,
  /* DiagArray3 */ diag::warn_cfstring_truncated, -1,
  /* DiagArray5 */ diag::warn_independentclass_attribute, diag::warn_ptr_independentclass_attribute, -1,
  /* DiagArray6 */ diag::warn_nsobject_attribute, -1,
  /* DiagArray8 */ diag::warn_abs_too_small, diag::warn_pointer_abs, diag::warn_unsigned_abs, diag::warn_wrong_absolute_value_type, -1,
  /* DiagArray9 */ diag::warn_abstract_final_class, -1,
  /* DiagArray10 */ diag::warn_abstract_vbase_init_ignored, -1,
  /* DiagArray12 */ diag::warn_taking_address_of_packed_member, -1,
  /* DiagArray13 */ diag::ext_typecheck_addrof_temporary, -1,
  /* DiagArray16 */ diag::warn_alloca_align_alignof, -1,
  /* DiagArray17 */ diag::warn_ambiguous_suitable_delete_function_found, -1,
  /* DiagArray18 */ diag::warn_misplaced_ellipsis_vararg, -1,
  /* DiagArray19 */ diag::warn_pp_ambiguous_macro, -1,
  /* DiagArray20 */ diag::ext_nested_name_member_ref_lookup_ambiguous, -1,
  /* DiagArray21 */ diag::warn_incompatible_analyzer_plugin_api, -1,
  /* DiagArray22 */ diag::ext_abstract_pack_declarator_parens, -1,
  /* DiagArray24 */ diag::warn_arc_bridge_cast_nonarc, -1,
  /* DiagArray25 */ diag::warn_arc_possible_repeated_use_of_weak, -1,
  /* DiagArray26 */ diag::warn_arc_object_memaccess, -1,
  /* DiagArray27 */ diag::warn_arc_perform_selector_leaks, -1,
  /* DiagArray28 */ diag::warn_arc_repeated_use_of_weak, -1,
  /* DiagArray29 */ diag::warn_arc_retain_cycle, -1,
  /* DiagArray30 */ diag::warn_arc_literal_assign, diag::warn_arc_retained_assign, diag::warn_arc_retained_property_assign, -1,
  /* DiagArray31 */ diag::warn_argument_invalid_range, -1,
  /* DiagArray32 */ diag::warn_array_index_exceeds_bounds, diag::warn_array_index_precedes_bounds, diag::warn_static_array_too_small, diag::warn_typecheck_zero_static_array_size, -1,
  /* DiagArray33 */ diag::warn_ptr_arith_exceeds_bounds, diag::warn_ptr_arith_precedes_bounds, -1,
  /* DiagArray35 */ diag::warn_asm_qualifier_ignored, diag::warn_file_asm_volatile, -1,
  /* DiagArray36 */ diag::warn_asm_mismatched_size_modifier, -1,
  /* DiagArray37 */ diag::warn_not_in_enum_assignment, -1,
  /* DiagArray38 */ diag::warn_assume_side_effects, -1,
  /* DiagArray40 */ diag::warn_atimport_in_framework_header, -1,
  /* DiagArray41 */ diag::warn_atomic_op_misaligned, -1,
  /* DiagArray42 */ diag::warn_atomic_implicit_seq_cst, -1,
  /* DiagArray43 */ diag::warn_atomic_op_has_invalid_memory_order, -1,
  /* DiagArray45 */ diag::warn_atomic_property_rule, -1,
  /* DiagArray46 */ diag::warn_attribute_packed_for_bitfield, -1,
  /* DiagArray48 */ diag::warn_drv_disabling_vptr_no_rtti_default, -1,
  /* DiagArray49 */ diag::warn_auto_module_import, -1,
  /* DiagArray50 */ diag::ext_auto_storage_class, -1,
  /* DiagArray51 */ diag::warn_auto_var_is_id, -1,
  /* DiagArray52 */ diag::warn_availability_and_unavailable, diag::warn_availability_on_static_initializer, diag::warn_availability_swift_unavailable_deprecated_only, diag::warn_availability_unknown_platform, diag::warn_availability_version_ordering, diag::warn_expected_consistent_version_separator, diag::warn_mismatched_availability, diag::warn_mismatched_availability_override, diag::warn_mismatched_availability_override_unavail, -1,
  /* DiagArray53 */ diag::warn_drv_avr_family_linking_stdlibs_not_implemented, diag::warn_drv_avr_gcc_not_found, diag::warn_drv_avr_libc_not_found, diag::warn_drv_avr_mcu_not_specified, diag::warn_drv_avr_stdlib_not_linked, -1,
  /* DiagArray54 */ diag::warn_fe_backend_plugin, -1,
  /* DiagArray55 */ diag::backslash_newline_space, -1,
  /* DiagArray56 */ diag::warn_bad_function_cast, -1,
  /* DiagArray58 */ diag::ext_rvalue_to_reference_access_ctor, diag::ext_rvalue_to_reference_temp_copy_no_viable, -1,
  /* DiagArray59 */ diag::ext_decomp_decl_cond, -1,
  /* DiagArray60 */ diag::warn_impcast_bitfield_precision_constant, -1,
  /* DiagArray61 */ diag::warn_bitfield_too_small_for_enum, diag::warn_signed_bitfield_enum_conversion, diag::warn_unsigned_bitfield_assigned_signed_enum, -1,
  /* DiagArray62 */ diag::warn_anon_bitfield_width_exceeds_type_width, diag::warn_bitfield_width_exceeds_type_width, -1,
  /* DiagArray63 */ diag::warn_bitwise_op_in_bitwise_op, -1,
  /* DiagArray64 */ diag::warn_block_capture_autoreleasing, -1,
  /* DiagArray65 */ diag::warn_impcast_bool_to_null_pointer, -1,
  /* DiagArray67 */ diag::warn_braces_around_scalar_init, -1,
  /* DiagArray68 */ diag::warn_objc_invalid_bridge, diag::warn_objc_invalid_bridge_to_cf, -1,
  /* DiagArray69 */ diag::ext_pp_redef_builtin_macro, diag::ext_pp_undef_builtin_macro, -1,
  /* DiagArray70 */ diag::warn_builtin_chk_overflow, -1,
  /* DiagArray71 */ diag::warn_implicit_decl_requires_sysheader, -1,
  /* DiagArray72 */ diag::warn_zero_size_struct_union_compat, -1,
  /* DiagArray76 */ diag::ext_old_implicitly_unsigned_long_cxx, diag::warn_auto_storage_class, diag::warn_cxx11_compat_user_defined_literal, diag::warn_cxx11_keyword, diag::warn_cxx11_right_shift_in_template_arg, diag::warn_explicit_instantiation_inline_0x, diag::warn_explicit_instantiation_must_be_global_0x, diag::warn_explicit_instantiation_out_of_scope_0x, diag::warn_explicit_instantiation_unqualified_wrong_namespace_0x, diag::warn_old_implicitly_unsigned_long_cxx, -1,
  /* DiagArray77 */ diag::warn_deprecated_string_literal_conversion, -1,
  /* DiagArray79 */ diag::warn_cxx11_compat_reserved_user_defined_literal, -1,
  /* DiagArray80 */ diag::ext_alias_declaration, diag::ext_array_size_conversion, diag::ext_auto_type_specifier, diag::ext_cxx11_enum_fixed_underlying_type, diag::ext_defaulted_deleted_function, diag::ext_enum_friend, diag::ext_enumerator_list_comma_cxx, diag::ext_explicit_conversion_functions, diag::ext_extern_template, diag::ext_for_range, diag::ext_generalized_initializer_lists, diag::ext_nested_name_spec_is_enum, diag::ext_nonclass_type_friend, diag::ext_nonstatic_member_init, diag::ext_override_control_keyword, diag::ext_ref_qualifier, diag::ext_rvalue_reference, diag::ext_scoped_enum, diag::ext_static_data_member_in_union, diag::ext_template_arg_object_internal, diag::ext_template_outside_of_template, diag::ext_template_parameter_default_in_function_template, diag::ext_typename_outside_of_template, diag::ext_unelaborated_friend_type, diag::ext_variadic_templates, -1,
  /* DiagArray81 */ diag::ext_extra_semi_cxx11, -1,
  /* DiagArray82 */ diag::ext_inline_namespace, -1,
  /* DiagArray83 */ diag::ext_cxx11_longlong, -1,
  /* DiagArray84 */ diag::ext_cce_narrowing, diag::ext_init_list_constant_narrowing, diag::ext_init_list_type_narrowing, diag::ext_init_list_variable_narrowing, diag::warn_init_list_constant_narrowing, diag::warn_init_list_type_narrowing, diag::warn_init_list_variable_narrowing, -1,
  /* DiagArray85 */ diag::ext_binary_literal_cxx14, -1,
  /* DiagArray88 */ diag::ext_constexpr_body_invalid_stmt, diag::ext_constexpr_body_multiple_return, diag::ext_constexpr_local_var, diag::ext_constexpr_type_definition, diag::ext_cxx14_attr, diag::ext_decltype_auto_type_specifier, diag::ext_init_capture, diag::ext_variable_template, -1,
  /* DiagArray90 */ diag::warn_cxx17_compat_exception_spec_in_signature, -1,
  /* DiagArray92 */ diag::ext_auto_new_list_init, diag::ext_constexpr_if, diag::ext_constexpr_on_lambda_cxx17, diag::ext_cxx17_attr, diag::ext_decomp_decl, diag::ext_fold_expression, diag::ext_for_range_begin_end_types_differ, diag::ext_hex_literal_invalid, diag::ext_init_statement, diag::ext_inline_variable, diag::ext_multi_using_declaration, diag::ext_nested_namespace_definition, diag::ext_ns_enum_attribute, diag::ext_star_this_lambda_capture_cxx17, diag::ext_static_assert_no_message, diag::ext_template_template_param_typename, diag::ext_using_attribute_ns, diag::ext_using_declaration_pack, -1,
  /* DiagArray97 */ diag::warn_cxx20_compat_consteval, diag::warn_cxx2a_compat_aggregate_init_with_ctors, diag::warn_cxx2a_compat_explicit_bool, diag::warn_cxx2a_compat_spaceship, diag::warn_cxx2a_compat_utf8_string, diag::warn_cxx2a_keyword, -1,
  /* DiagArray99 */ diag::ext_adl_only_template_id, diag::ext_bitfield_member_init, diag::ext_constexpr_body_invalid_stmt_cxx2a, diag::ext_constexpr_function_try_block_cxx2a, diag::ext_decomp_decl_spec, diag::ext_equals_this_lambda_capture_cxx2a, diag::ext_for_range_init_stmt, diag::ext_init_capture_pack, diag::ext_inline_nested_namespace_definition, diag::ext_lambda_template_parameter_list, diag::ext_pointer_to_const_ref_member_on_rvalue, -1,
  /* DiagArray100 */ diag::warn_cxx17_compat_adl_only_template_id, diag::warn_cxx17_compat_bitfield_member_init, diag::warn_cxx17_compat_constexpr_body_invalid_stmt, diag::warn_cxx17_compat_constexpr_function_try_block, diag::warn_cxx17_compat_constexpr_virtual, diag::warn_cxx17_compat_decomp_decl_spec, diag::warn_cxx17_compat_defaulted_method_type_mismatch, diag::warn_cxx17_compat_equals_this_lambda_capture, diag::warn_cxx17_compat_for_range_init_stmt, diag::warn_cxx17_compat_init_capture_pack, diag::warn_cxx17_compat_inline_nested_namespace_definition, diag::warn_cxx17_compat_lambda_def_ctor_assign, diag::warn_cxx17_compat_lambda_template_parameter_list, diag::warn_cxx17_compat_spaceship, diag::warn_cxx17_compat_unicode_type, -1,
  /* DiagArray101 */ diag::warn_cxx17_compat_pointer_to_const_ref_member_on_rvalue, -1,
  /* DiagArray102 */ diag::warn_cxx14_compat_class_template_argument_deduction, diag::warn_cxx14_compat_constexpr_if, diag::warn_cxx14_compat_constexpr_on_lambda, diag::warn_cxx14_compat_decomp_decl, diag::warn_cxx14_compat_fold_expression, diag::warn_cxx14_compat_init_statement, diag::warn_cxx14_compat_inline_variable, diag::warn_cxx14_compat_nested_namespace_definition, diag::warn_cxx14_compat_star_this_lambda_capture, diag::warn_cxx14_compat_static_assert_no_message, diag::warn_cxx14_compat_template_nontype_parm_auto_type, diag::warn_cxx14_compat_template_template_param_typename, diag::warn_cxx14_compat_u8_character_literal, diag::warn_cxx14_compat_using_attribute_ns, diag::warn_cxx17_compat_multi_using_declaration, diag::warn_cxx17_compat_using_declaration_pack, diag::warn_for_range_begin_end_types_differ, -1,
  /* DiagArray103 */ diag::warn_cxx14_compat_ns_enum_attribute, diag::warn_cxx17_hex_literal, -1,
  /* DiagArray104 */ diag::warn_cxx11_compat_constexpr_body_invalid_stmt, diag::warn_cxx11_compat_constexpr_body_multiple_return, diag::warn_cxx11_compat_constexpr_body_no_return, diag::warn_cxx11_compat_constexpr_local_var, diag::warn_cxx11_compat_constexpr_type_definition, diag::warn_cxx11_compat_decltype_auto_type_specifier, diag::warn_cxx11_compat_deduced_return_type, diag::warn_cxx11_compat_digit_separator, diag::warn_cxx11_compat_generic_lambda, diag::warn_cxx11_compat_init_capture, diag::warn_cxx11_compat_variable_template, -1,
  /* DiagArray105 */ diag::warn_cxx11_compat_binary_literal, -1,
  /* DiagArray107 */ diag::warn_cxx98_compat_alias_declaration, diag::warn_cxx98_compat_alignas, diag::warn_cxx98_compat_alignof, diag::warn_cxx98_compat_attribute, diag::warn_cxx98_compat_auto_type_specifier, diag::warn_cxx98_compat_constexpr, diag::warn_cxx98_compat_ctor_list_init, diag::warn_cxx98_compat_decltype, diag::warn_cxx98_compat_defaulted_deleted_function, diag::warn_cxx98_compat_delegating_ctor, diag::warn_cxx98_compat_empty_scalar_initializer, diag::warn_cxx98_compat_enum_fixed_underlying_type, diag::warn_cxx98_compat_enum_friend, diag::warn_cxx98_compat_enum_nested_name_spec, diag::warn_cxx98_compat_explicit_conversion_functions, diag::warn_cxx98_compat_for_range, diag::warn_cxx98_compat_friend_is_member, diag::warn_cxx98_compat_generalized_initializer_lists, diag::warn_cxx98_compat_goto_into_protected_scope, diag::warn_cxx98_compat_indirect_goto_in_protected_scope, diag::warn_cxx98_compat_initializer_list_init, diag::warn_cxx98_compat_inline_namespace, diag::warn_cxx98_compat_lambda, diag::warn_cxx98_compat_less_colon_colon, diag::warn_cxx98_compat_literal_operator, diag::warn_cxx98_compat_literal_ucn_control_character, diag::warn_cxx98_compat_literal_ucn_escape_basic_scs, diag::warn_cxx98_compat_noexcept_decl, diag::warn_cxx98_compat_noexcept_expr, diag::warn_cxx98_compat_non_static_member_use, diag::warn_cxx98_compat_nonclass_type_friend, diag::warn_cxx98_compat_nonstatic_member_init, diag::warn_cxx98_compat_nontrivial_union_or_anon_struct_member, diag::warn_cxx98_compat_nullptr, diag::warn_cxx98_compat_override_control_keyword, diag::warn_cxx98_compat_pass_non_pod_arg_to_vararg, diag::warn_cxx98_compat_raw_string_literal, diag::warn_cxx98_compat_ref_qualifier, diag::warn_cxx98_compat_reference_list_init, diag::warn_cxx98_compat_rvalue_reference, diag::warn_cxx98_compat_scoped_enum, diag::warn_cxx98_compat_sfinae_access_control, diag::warn_cxx98_compat_static_assert, diag::warn_cxx98_compat_static_data_member_in_union, diag::warn_cxx98_compat_switch_into_protected_scope, diag::warn_cxx98_compat_template_arg_extra_parens, diag::warn_cxx98_compat_template_arg_null, diag::warn_cxx98_compat_template_arg_object_internal, diag::warn_cxx98_compat_template_outside_of_template, diag::warn_cxx98_compat_template_parameter_default_in_function_template, diag::warn_cxx98_compat_trailing_return_type, diag::warn_cxx98_compat_two_right_angle_brackets, diag::warn_cxx98_compat_typename_outside_of_template, diag::warn_cxx98_compat_unelaborated_friend_type, diag::warn_cxx98_compat_unicode_id, diag::warn_cxx98_compat_unicode_literal, diag::warn_cxx98_compat_unicode_type, diag::warn_cxx98_compat_using_decl_constructor, diag::warn_cxx98_compat_variadic_templates, -1,
  /* DiagArray108 */ diag::warn_cxx98_compat_temp_copy, -1,
  /* DiagArray109 */ diag::warn_cxx98_compat_top_level_semi, -1,
  /* DiagArray110 */ diag::warn_cxx98_compat_template_arg_local_type, -1,
  /* DiagArray111 */ diag::warn_cxx98_compat_array_size_conversion, diag::warn_cxx98_compat_cast_fn_obj, diag::warn_cxx98_compat_empty_fnmacro_arg, diag::warn_cxx98_compat_enumerator_list_comma, diag::warn_cxx98_compat_extern_template, diag::warn_cxx98_compat_longlong, diag::warn_cxx98_compat_no_newline_eof, diag::warn_cxx98_compat_pp_line_too_big, diag::warn_cxx98_compat_variadic_macro, -1,
  /* DiagArray112 */ diag::warn_cxx98_compat_template_arg_unnamed_type, -1,
  /* DiagArray113 */ diag::ext_anonymous_union, diag::ext_c11_alignment, diag::ext_c11_anonymous_struct, diag::ext_c11_generic_selection, diag::ext_c11_noreturn, diag::ext_c11_static_assert, -1,
  /* DiagArray114 */ diag::warn_c99_compat_unicode_id, diag::warn_c99_compat_unicode_literal, diag::warn_old_implicitly_unsigned_long, -1,
  /* DiagArray115 */ diag::ext_aggregate_init_not_constant, diag::ext_c99_array_usage, diag::ext_c99_compound_literal, diag::ext_c99_flexible_array_member, diag::ext_c99_variable_decl_in_for_loop, diag::ext_c99_whitespace_required_after_macro_name, diag::ext_designated_init, diag::ext_empty_fnmacro_arg, diag::ext_enumerator_list_comma_c, diag::ext_hex_constant_invalid, -1,
  /* DiagArray116 */ diag::warn_call_to_pure_virtual_member_function_from_ctor_dtor, -1,
  /* DiagArray117 */ diag::warn_cast_align, -1,
  /* DiagArray118 */ diag::warn_cast_calling_conv, -1,
  /* DiagArray119 */ diag::warn_cast_pointer_from_sel, -1,
  /* DiagArray120 */ diag::warn_cast_qual, diag::warn_cast_qual2, -1,
  /* DiagArray121 */ diag::ext_bad_cxx_cast_qualifiers_away_incoherent, -1,
  /* DiagArray123 */ diag::warn_omp_section_is_char, diag::warn_subscript_is_char, -1,
  /* DiagArray124 */ diag::warn_drv_yc_multiple_inputs_clang_cl, diag::warn_drv_ycyu_different_arg_clang_cl, diag::warn_drv_ycyu_no_fi_arg_clang_cl, diag::warn_pp_hdrstop_filename_ignored, diag::warn_pp_macro_def_mismatch_with_pch, -1,
  /* DiagArray125 */ diag::warn_pass_class_arg_to_vararg, -1,
  /* DiagArray126 */ diag::warn_comma_operator, -1,
  /* DiagArray127 */ diag::escaped_newline_block_comment_end, diag::ext_line_comment, diag::ext_multi_line_line_comment, diag::warn_nested_block_comment, -1,
  /* DiagArray129 */ diag::ext_typecheck_comparison_of_distinct_pointers, -1,
  /* DiagArray130 */ diag::ext_complex_component_init, -1,
  /* DiagArray131 */ diag::ext_concept_legacy_bool_keyword, -1,
  /* DiagArray132 */ diag::ext_typecheck_cond_pointer_integer_mismatch, -1,
  /* DiagArray133 */ diag::warn_maybe_uninit_var, -1,
  /* DiagArray134 */ diag::warn_module_config_macro_undef, -1,
  /* DiagArray135 */ diag::warn_impcast_integer_precision_constant, -1,
  /* DiagArray136 */ diag::warn_logical_instead_of_bitwise, -1,
  /* DiagArray137 */ diag::warn_cxx14_compat_constexpr_not_const, -1,
  /* DiagArray138 */ diag::warn_attr_on_unconsumable_class, diag::warn_loop_state_mismatch, diag::warn_param_return_typestate_mismatch, diag::warn_param_typestate_mismatch, diag::warn_return_typestate_for_unconsumable_type, diag::warn_return_typestate_mismatch, diag::warn_use_in_invalid_state, diag::warn_use_of_temp_in_invalid_state, -1,
  /* DiagArray139 */ diag::warn_impcast_complex_scalar, diag::warn_impcast_vector_scalar, diag::warn_opencl_generic_address_space_arg, diag::warn_template_arg_negative, diag::warn_template_arg_too_large, -1,
  /* DiagArray142 */ diag::warn_coroutine_promise_unhandled_exception_required_with_exceptions, -1,
  /* DiagArray143 */ diag::warn_unreachable_default, -1,
  /* DiagArray145 */ diag::warn_objc_cdirective_format_string, -1,
  /* DiagArray146 */ diag::warn_ctad_maybe_unsupported, -1,
  /* DiagArray148 */ diag::warn_ctu_incompat_triple, -1,
  /* DiagArray149 */ diag::warn_attribute_argument_n_negative, diag::warn_cuda_attr_lambda_position, diag::warn_kern_is_inline, diag::warn_kern_is_method, diag::warn_pragma_unroll_cuda_value_in_parens, -1,
  /* DiagArray150 */ diag::warn_shared_var_init, -1,
  /* DiagArray151 */ diag::warn_default_atomic_custom_getter_setter, -1,
  /* DiagArray152 */ diag::warn_dangling_variable, diag::warn_unsupported_lifetime_extension, -1,
  /* DiagArray153 */ diag::warn_dangling_else, -1,
  /* DiagArray154 */ diag::warn_bind_ref_member_to_parameter, diag::warn_dangling_member, diag::warn_init_ptr_member_to_parameter_addr, diag::warn_new_dangling_reference, -1,
  /* DiagArray155 */ diag::warn_new_dangling_initializer_list, -1,
  /* DiagArray156 */ diag::warn_drv_darwin_sdk_invalid_settings, -1,
  /* DiagArray157 */ diag::warn_pp_date_time, -1,
  /* DiagArray158 */ diag::warn_dealloc_in_category, -1,
  /* DiagArray159 */ diag::warn_debug_compression_unavailable, -1,
  /* DiagArray160 */ diag::ext_mixed_decls_code, -1,
  /* DiagArray161 */ diag::warn_defaulted_method_deleted, -1,
  /* DiagArray162 */ diag::warn_delegating_ctor_cycle, -1,
  /* DiagArray163 */ diag::warn_delete_abstract_non_virtual_dtor, -1,
  /* DiagArray164 */ diag::ext_delete_void_ptr_operand, diag::warn_delete_incomplete, -1,
  /* DiagArray165 */ diag::warn_delete_non_virtual_dtor, -1,
  /* DiagArray167 */ diag::warn_O4_is_O3, diag::warn_access_decl_deprecated, diag::warn_deprecated_copy_operation, diag::warn_deprecated_redundant_constexpr_static_def, diag::warn_drv_deprecated_arg, diag::warn_drv_treating_input_as_cxx, diag::warn_option_invalid_ocl_version, diag::warn_vector_long_decl_spec_combination, -1,
  /* DiagArray168 */ diag::warn_vector_mode_deprecated, -1,
  /* DiagArray169 */ diag::warn_atl_uuid_deprecated, diag::warn_cstyle_param, diag::warn_deprecated, diag::warn_deprecated_fwdclass_message, diag::warn_deprecated_message, diag::warn_property_method_deprecated, -1,
  /* DiagArray170 */ diag::warn_exception_spec_deprecated, -1,
  /* DiagArray171 */ diag::warn_deprecated_def, diag::warn_unavailable_def, -1,
  /* DiagArray172 */ diag::warn_increment_bool, -1,
  /* DiagArray173 */ diag::warn_objc_isa_assign, diag::warn_objc_isa_use, -1,
  /* DiagArray174 */ diag::warn_objc_pointer_masking, -1,
  /* DiagArray175 */ diag::warn_objc_pointer_masking_performSelector, -1,
  /* DiagArray176 */ diag::warn_deprecated_register, -1,
  /* DiagArray177 */ diag::warn_deprecated_this_capture, -1,
  /* DiagArray179 */ diag::warn_direct_ivar_access, -1,
  /* DiagArray180 */ diag::pp_disabled_macro_expansion, -1,
  /* DiagArray183 */ diag::warn_conflicting_param_modifiers, diag::warn_conflicting_ret_type_modifiers, -1,
  /* DiagArray185 */ diag::warn_remainder_division_by_zero, -1,
  /* DiagArray186 */ diag::warn_attribute_dll_redeclaration, -1,
  /* DiagArray187 */ diag::warn_attribute_dllexport_explicit_instantiation_decl, -1,
  /* DiagArray188 */ diag::warn_attribute_dllimport_static_field_definition, -1,
  /* DiagArray189 */ diag::warn_doc_api_container_decl_mismatch, diag::warn_doc_block_command_duplicate, diag::warn_doc_block_command_empty_paragraph, diag::warn_doc_container_decl_mismatch, diag::warn_doc_function_method_decl_mismatch, diag::warn_doc_html_start_tag_expected_ident_or_greater, diag::warn_doc_html_start_tag_expected_quoted_string, diag::warn_doc_param_duplicate, diag::warn_doc_param_invalid_direction, diag::warn_doc_param_not_attached_to_a_function_decl, diag::warn_doc_param_not_found, diag::warn_doc_returns_attached_to_a_void_function, diag::warn_doc_returns_not_attached_to_a_function_decl, diag::warn_doc_tparam_duplicate, diag::warn_doc_tparam_not_attached_to_a_template_decl, diag::warn_doc_tparam_not_found, diag::warn_not_a_doxygen_trailing_member_comment, diag::warn_verbatim_block_end_without_start, -1,
  /* DiagArray190 */ diag::warn_doc_deprecated_not_sync, -1,
  /* DiagArray191 */ diag::warn_doc_html_end_forbidden, diag::warn_doc_html_end_unbalanced, diag::warn_doc_html_missing_end_tag, diag::warn_doc_html_start_end_mismatch, -1,
  /* DiagArray192 */ diag::warn_doc_param_spaces_in_direction, -1,
  /* DiagArray193 */ diag::warn_correct_comment_command_name, diag::warn_unknown_comment_command_name, -1,
  /* DiagArray194 */ diag::ext_dollar_in_identifier, -1,
  /* DiagArray195 */ diag::warn_impcast_double_promotion, -1,
  /* DiagArray196 */ diag::ext_duplicate_declspec, diag::ext_warn_duplicate_declspec, diag::warn_attribute_address_multiple_identical_qualifiers, diag::warn_duplicate_declspec, -1,
  /* DiagArray197 */ diag::warn_duplicate_enum_values, -1,
  /* DiagArray198 */ diag::warn_method_param_declaration, -1,
  /* DiagArray199 */ diag::warn_duplicate_method_decl, -1,
  /* DiagArray200 */ diag::warn_duplicate_protocol_def, -1,
  /* DiagArray201 */ diag::warn_dyn_class_memaccess, -1,
  /* DiagArray202 */ diag::ext_dynamic_exception_spec, -1,
  /* DiagArray204 */ diag::ext_embedded_directive, -1,
  /* DiagArray205 */ diag::warn_empty_for_body, diag::warn_empty_if_body, diag::warn_empty_range_based_for_body, diag::warn_empty_switch_body, diag::warn_empty_while_body, -1,
  /* DiagArray206 */ diag::ext_decomp_decl_empty, -1,
  /* DiagArray207 */ diag::warn_empty_init_statement, -1,
  /* DiagArray208 */ diag::ext_empty_translation_unit, -1,
  /* DiagArray209 */ diag::warn_incomplete_encoded_type, -1,
  /* DiagArray211 */ diag::warn_comparison_of_mixed_enum_types, -1,
  /* DiagArray212 */ diag::warn_comparison_of_mixed_enum_types_switch, -1,
  /* DiagArray213 */ diag::warn_impcast_different_enum_types, -1,
  /* DiagArray214 */ diag::ext_enum_too_large, diag::ext_enumerator_increment_too_large, -1,
  /* DiagArray215 */ diag::warn_cdtor_function_try_handler_mem_expr, diag::warn_exception_caught_by_earlier_handler, diag::warn_throw_in_noexcept_func, -1,
  /* DiagArray216 */ diag::warn_exit_time_destructor, -1,
  /* DiagArray217 */ diag::warn_defined_in_function_type_macro, diag::warn_defined_in_object_type_macro, -1,
  /* DiagArray218 */ diag::warn_drv_experimental_isel_incomplete, diag::warn_drv_experimental_isel_incomplete_opt, -1,
  /* DiagArray219 */ diag::warn_direct_initialize_call, diag::warn_direct_super_initialize_call, -1,
  /* DiagArray220 */ diag::warn_arc_strong_pointer_objc_pointer, -1,
  /* DiagArray221 */ diag::ext_export_no_name_block, diag::ext_export_no_names, -1,
  /* DiagArray222 */ diag::ext_export_using_directive, -1,
  /* DiagArray223 */ diag::warn_zero_size_struct_union_in_extern_c, -1,
  /* DiagArray224 */ diag::warn_extern_init, -1,
  /* DiagArray225 */ diag::warn_arm_interrupt_calling_convention, -1,
  /* DiagArray226 */ diag::warn_namespace_member_extra_qualification, -1,
  /* DiagArray227 */ diag::ext_extra_semi, diag::warn_extra_semi_after_mem_fn_def, -1,
  /* DiagArray228 */ diag::warn_null_statement, -1,
  /* DiagArray229 */ diag::ext_pp_extra_tokens_at_eol, diag::warn_omp_extra_tokens_at_eol, -1,
  /* DiagArray230 */ diag::warn_drv_invoking_fallback, -1,
  /* DiagArray231 */ diag::ext_clang_c_enum_fixed_underlying_type, -1,
  /* DiagArray232 */ diag::warn_flag_enum_constant_out_of_range, -1,
  /* DiagArray233 */ diag::ext_flexible_array_in_array, diag::ext_flexible_array_in_struct, -1,
  /* DiagArray234 */ diag::warn_impcast_float_integer, -1,
  /* DiagArray235 */ diag::warn_floatingpoint_eq, -1,
  /* DiagArray236 */ diag::warn_impcast_float_to_integer, diag::warn_impcast_float_to_integer_out_of_range, -1,
  /* DiagArray237 */ diag::warn_impcast_float_to_integer_zero, -1,
  /* DiagArray238 */ diag::warn_redundant_loop_iteration, diag::warn_variables_not_in_loop_body, -1,
  /* DiagArray239 */ diag::warn_format_P_no_precision, diag::warn_format_argument_needs_cast, diag::warn_format_conversion_argument_type_mismatch, diag::warn_format_invalid_annotation, diag::warn_format_invalid_positional_specifier, diag::warn_format_mix_positional_nonpositional_args, diag::warn_format_nonsensical_length, diag::warn_format_string_is_wide_literal, diag::warn_format_zero_positional_specifier, diag::warn_missing_format_string, diag::warn_printf_ObjCflags_without_ObjCConversion, diag::warn_printf_asterisk_missing_arg, diag::warn_printf_asterisk_wrong_type, diag::warn_printf_empty_objc_flag, diag::warn_printf_format_string_contains_null_char, diag::warn_printf_format_string_not_null_terminated, diag::warn_printf_ignored_flag, diag::warn_printf_incomplete_specifier, diag::warn_printf_insufficient_data_args, diag::warn_printf_invalid_objc_flag, diag::warn_printf_nonsensical_flag, diag::warn_printf_nonsensical_optional_amount, diag::warn_printf_positional_arg_exceeds_data_args, diag::warn_scanf_nonzero_width, diag::warn_scanf_scanlist_incomplete, -1,
  /* DiagArray240 */ diag::warn_printf_data_arg_not_used, -1,
  /* DiagArray241 */ diag::warn_format_invalid_conversion, -1,
  /* DiagArray242 */ diag::warn_format_non_standard, diag::warn_format_non_standard_conversion_spec, diag::warn_format_non_standard_positional_arg, -1,
  /* DiagArray243 */ diag::warn_format_nonliteral, -1,
  /* DiagArray244 */ diag::warn_format_argument_needs_cast_pedantic, diag::warn_format_conversion_argument_type_mismatch_pedantic, -1,
  /* DiagArray245 */ diag::warn_format_nonliteral_noargs, -1,
  /* DiagArray247 */ diag::warn_empty_format_string, -1,
  /* DiagArray249 */ diag::warn_fortify_source_overflow, diag::warn_fortify_source_size_mismatch, -1,
  /* DiagArray250 */ diag::ext_four_char_character_literal, -1,
  /* DiagArray251 */ diag::warn_fe_backend_frame_larger_than, diag::warn_fe_frame_larger_than, -1,
  /* DiagArray252 */ diag::warn_framework_include_private_from_public, -1,
  /* DiagArray253 */ diag::warn_function_def_in_objc_container, -1,
  /* DiagArray254 */ diag::warn_dispatch_body_ignored, diag::warn_multiversion_duplicate_entries, -1,
  /* DiagArray256 */ diag::ext_clang_diagnose_if, diag::ext_clang_enable_if, diag::ext_warn_gnu_final, diag::warn_attribute_on_function_definition, diag::warn_break_binds_to_switch, diag::warn_cleanup_ext, diag::warn_gcc_attribute_location, diag::warn_gcc_ignores_type_attr, diag::warn_gcc_variable_decl_in_for_loop, diag::warn_loop_ctrl_binds_to_inner, -1,
  /* DiagArray257 */ diag::warn_global_constructor, diag::warn_global_destructor, -1,
  /* DiagArray259 */ diag::ext_alignof_expr, -1,
  /* DiagArray260 */ diag::ext_gnu_anonymous_struct, -1,
  /* DiagArray261 */ diag::ext_array_init_parens, -1,
  /* DiagArray262 */ diag::ext_auto_type, -1,
  /* DiagArray263 */ diag::ext_binary_literal, -1,
  /* DiagArray264 */ diag::ext_gnu_case_range, -1,
  /* DiagArray265 */ diag::ext_integer_complex, -1,
  /* DiagArray266 */ diag::ext_array_init_copy, -1,
  /* DiagArray267 */ diag::ext_gnu_conditional_expr, -1,
  /* DiagArray268 */ diag::ext_gnu_array_range, diag::ext_gnu_missing_equal_designator, diag::ext_gnu_old_style_field_designator, -1,
  /* DiagArray269 */ diag::ext_gnu_empty_initializer, -1,
  /* DiagArray270 */ diag::ext_empty_struct_union, diag::ext_flexible_array_empty_aggregate_gnu, diag::ext_no_named_members_in_struct_union, -1,
  /* DiagArray271 */ diag::ext_flexible_array_init, -1,
  /* DiagArray272 */ diag::ext_flexible_array_union_gnu, -1,
  /* DiagArray273 */ diag::ext_expr_not_ice, diag::ext_in_class_initializer_non_constant, diag::ext_vla_folded_to_constant, -1,
  /* DiagArray274 */ diag::ext_imaginary_constant, -1,
  /* DiagArray275 */ diag::ext_pp_include_next_directive, -1,
  /* DiagArray276 */ diag::ext_gnu_address_of_label, diag::ext_gnu_indirect_goto, -1,
  /* DiagArray277 */ diag::ext_forward_ref_enum_def, -1,
  /* DiagArray278 */ diag::ext_gnu_statement_expr, -1,
  /* DiagArray279 */ diag::ext_in_class_initializer_float_type, -1,
  /* DiagArray280 */ diag::ext_string_literal_operator_template, -1,
  /* DiagArray281 */ diag::ext_typecheck_cast_to_union, -1,
  /* DiagArray282 */ diag::ext_variable_sized_type_in_struct, -1,
  /* DiagArray283 */ diag::ext_pp_line_zero, -1,
  /* DiagArray284 */ diag::ext_missing_varargs_arg, diag::ext_paste_comma, -1,
  /* DiagArray285 */ diag::warn_header_guard, -1,
  /* DiagArray286 */ diag::warn_using_directive_in_header, -1,
  /* DiagArray287 */ diag::warn_condition_is_idiomatic_assignment, -1,
  /* DiagArray288 */ diag::ext_cannot_use_trivial_abi, diag::warn_alias_to_weak_alias, diag::warn_alias_with_section, diag::warn_attr_abi_tag_namespace, diag::warn_attribute_after_definition_ignored, diag::warn_attribute_dllexport_explicit_instantiation_def, diag::warn_attribute_iboutlet, diag::warn_attribute_ignored, diag::warn_attribute_ignored_for_field_of_type, diag::warn_attribute_ignored_on_inline, diag::warn_attribute_invalid_on_definition, diag::warn_attribute_no_decl, diag::warn_attribute_nonnull_no_pointers, diag::warn_attribute_nonnull_parm_no_args, diag::warn_attribute_not_on_decl, diag::warn_attribute_pointer_or_reference_only, diag::warn_attribute_pointers_only, diag::warn_attribute_precede_definition, diag::warn_attribute_return_pointers_only, diag::warn_attribute_return_pointers_refs_only, diag::warn_attribute_sentinel_named_arguments, diag::warn_attribute_sentinel_not_variadic, diag::warn_attribute_type_not_supported, diag::warn_attribute_unknown_visibility, diag::warn_attribute_void_function_method, diag::warn_attribute_weak_on_field, diag::warn_attribute_weak_on_local, diag::warn_attribute_wrong_decl_type, diag::warn_attribute_wrong_decl_type_str, diag::warn_block_literal_attributes_on_omitted_return_type, diag::warn_cconv_unsupported, diag::warn_cxx11_gnu_attribute_on_type, diag::warn_declspec_allocator_nonpointer, diag::warn_declspec_attribute_ignored, diag::warn_deprecated_anonymous_namespace, diag::warn_dllimport_dropped_from_inline_function, diag::warn_duplicate_attribute, diag::warn_duplicate_attribute_exact, diag::warn_gc_attribute_weak_on_local, diag::warn_gnu_inline_attribute_requires_inline, diag::warn_ignored_ms_inheritance, diag::warn_ignored_objc_externally_retained, diag::warn_internal_linkage_local_storage, diag::warn_interrupt_attribute_invalid, diag::warn_microsoft_qualifiers_ignored, diag::warn_mig_server_routine_does_not_return_kern_return_t, diag::warn_mmap_unknown_attribute, diag::warn_nocf_check_attribute_ignored, diag::warn_noderef_on_non_pointer_or_array, diag::warn_nothrow_attribute_ignored, diag::warn_ns_attribute_wrong_parameter_type, diag::warn_ns_attribute_wrong_return_type, diag::warn_opencl_attr_deprecated_ignored, diag::warn_riscv_repeated_interrupt_attribute, diag::warn_transparent_union_attribute_field_size_align, diag::warn_transparent_union_attribute_floating, diag::warn_transparent_union_attribute_not_definition, diag::warn_transparent_union_attribute_zero_fields, diag::warn_type_attribute_wrong_type, diag::warn_unhandled_ms_attribute_ignored, diag::warn_unsupported_target_attribute, diag::warn_wrong_clang_attr_namespace, -1,
  /* DiagArray289 */ diag::warn_drv_unsupported_opt_for_target, diag::warn_ignored_gcc_optimization, -1,
  /* DiagArray290 */ diag::warn_pragma_intrinsic_builtin, -1,
  /* DiagArray291 */ diag::warn_pragma_optimize, -1,
  /* DiagArray292 */ diag::warn_pragma_align_expected_equal, diag::warn_pragma_align_invalid_option, diag::warn_pragma_begin_end_mismatch, diag::warn_pragma_comment_ignored, diag::warn_pragma_debug_missing_argument, diag::warn_pragma_debug_unexpected_command, diag::warn_pragma_debug_unknown_module, diag::warn_pragma_expected_action_or_r_paren, diag::warn_pragma_expected_colon, diag::warn_pragma_expected_colon_r_paren, diag::warn_pragma_expected_comma, diag::warn_pragma_expected_identifier, diag::warn_pragma_expected_init_seg, diag::warn_pragma_expected_integer, diag::warn_pragma_expected_lparen, diag::warn_pragma_expected_non_wide_string, diag::warn_pragma_expected_predicate, diag::warn_pragma_expected_punc, diag::warn_pragma_expected_rparen, diag::warn_pragma_expected_section_label_or_name, diag::warn_pragma_expected_section_name, diag::warn_pragma_expected_section_push_pop_or_name, diag::warn_pragma_expected_string, diag::warn_pragma_extra_tokens_at_eol, diag::warn_pragma_force_cuda_host_device_bad_arg, diag::warn_pragma_init_seg_unsupported_target, diag::warn_pragma_invalid_action, diag::warn_pragma_invalid_argument, diag::warn_pragma_invalid_specific_action, diag::warn_pragma_missing_argument, diag::warn_pragma_ms_struct, diag::warn_pragma_options_align_reset_failed, diag::warn_pragma_options_expected_align, diag::warn_pragma_pack_invalid_alignment, diag::warn_pragma_pack_malformed, diag::warn_pragma_pop_failed, diag::warn_pragma_pop_macro_no_push, diag::warn_pragma_unknown_extension, diag::warn_pragma_unsupported_action, diag::warn_pragma_unsupported_extension, diag::warn_pragma_unused_expected_var, diag::warn_pragma_unused_expected_var_arg, diag::warn_pragma_unused_undeclared_var, -1,
  /* DiagArray293 */ diag::warn_arc_lifetime_result_type, diag::warn_block_literal_qualifiers_on_omitted_return_type, diag::warn_qual_return_type, diag::warn_typecheck_function_qualifiers_ignored, diag::warn_typecheck_reference_qualifiers, -1,
  /* DiagArray295 */ diag::warn_auto_implicit_atomic_property, diag::warn_implicit_atomic_property, -1,
  /* DiagArray296 */ diag::warn_impcast_floating_point_to_bool, -1,
  /* DiagArray297 */ diag::ext_implicit_exception_spec_mismatch, -1,
  /* DiagArray298 */ diag::warn_fallthrough_attr_unreachable, diag::warn_unannotated_fallthrough, -1,
  /* DiagArray299 */ diag::warn_unannotated_fallthrough_per_function, -1,
  /* DiagArray300 */ diag::warn_impcast_fixed_point_range, -1,
  /* DiagArray301 */ diag::warn_impcast_float_precision, diag::warn_impcast_float_result_precision, -1,
  /* DiagArray302 */ diag::ext_implicit_function_decl, diag::ext_implicit_lib_function_decl, diag::warn_builtin_unknown, diag::warn_implicit_function_decl, -1,
  /* DiagArray303 */ diag::ext_missing_type_specifier, -1,
  /* DiagArray304 */ diag::warn_impcast_high_order_zero_bits, diag::warn_impcast_integer_precision, -1,
  /* DiagArray305 */ diag::warn_implicitly_retains_self, -1,
  /* DiagArray306 */ diag::ext_integer_literal_too_large_for_signed, -1,
  /* DiagArray308 */ diag::ext_pp_import_directive, -1,
  /* DiagArray309 */ diag::warn_inaccessible_base_class, -1,
  /* DiagArray310 */ diag::pp_include_next_absolute_path, -1,
  /* DiagArray311 */ diag::pp_include_next_in_primary, -1,
  /* DiagArray312 */ diag::warn_deep_exception_specs_differ, diag::warn_incompatible_exception_specs, -1,
  /* DiagArray313 */ diag::ext_typecheck_convert_incompatible_function_pointer, -1,
  /* DiagArray314 */ diag::warn_redecl_library_builtin, -1,
  /* DiagArray315 */ diag::warn_cxx_ms_struct, diag::warn_npot_ms_struct, -1,
  /* DiagArray316 */ diag::ext_typecheck_convert_incompatible_pointer, -1,
  /* DiagArray317 */ diag::ext_nested_pointer_qualifier_mismatch, diag::ext_typecheck_convert_discards_qualifiers, -1,
  /* DiagArray318 */ diag::warn_property_types_are_incompatible, -1,
  /* DiagArray319 */ diag::warn_incompatible_sysroot, -1,
  /* DiagArray320 */ diag::warn_mmap_incomplete_framework_module_declaration, -1,
  /* DiagArray321 */ diag::warn_undef_method_impl, -1,
  /* DiagArray323 */ diag::warn_implicit_decl_no_jmp_buf, -1,
  /* DiagArray324 */ diag::warn_missing_submodule, diag::warn_mmap_umbrella_dir_not_found, diag::warn_uncovered_module_header, -1,
  /* DiagArray325 */ diag::warn_redeclaration_without_attribute_prev_attribute_ignored, diag::warn_redeclaration_without_import_attribute, -1,
  /* DiagArray326 */ diag::warn_destructor_marked_not_override_overriding, -1,
  /* DiagArray327 */ diag::warn_function_marked_not_override_overriding, -1,
  /* DiagArray328 */ diag::ext_increment_bool, -1,
  /* DiagArray329 */ diag::warn_infinite_recursive_function, -1,
  /* DiagArray331 */ diag::warn_initializer_overrides, diag::warn_subobject_initializer_overrides, -1,
  /* DiagArray332 */ diag::ext_out_of_line_qualified_id_type_names_constructor, -1,
  /* DiagArray334 */ diag::warn_fe_inline_asm, -1,
  /* DiagArray335 */ diag::ext_operator_new_delete_declared_inline, -1,
  /* DiagArray336 */ diag::warn_explicit_instantiation_after_specialization, -1,
  /* DiagArray337 */ diag::ext_typecheck_convert_int_pointer, diag::ext_typecheck_convert_pointer_int, -1,
  /* DiagArray339 */ diag::warn_int_to_pointer_cast, -1,
  /* DiagArray340 */ diag::warn_int_to_void_pointer_cast, -1,
  /* DiagArray341 */ diag::warn_integer_constant_overflow, -1,
  /* DiagArray342 */ diag::warn_drv_msp430_hwmult_mismatch, diag::warn_drv_msp430_hwmult_no_device, diag::warn_drv_msp430_hwmult_unsupported, diag::warn_drv_object_size_disabled_O0, diag::warn_drv_optimization_value, -1,
  /* DiagArray343 */ diag::ext_constexpr_function_never_constant_expr, -1,
  /* DiagArray344 */ diag::warn_iboutlet_object_type, diag::warn_iboutletcollection_property_assign, -1,
  /* DiagArray345 */ diag::warn_invalid_initializer_from_system_header, -1,
  /* DiagArray346 */ diag::warn_invalid_ios_deployment_target, -1,
  /* DiagArray347 */ diag::warn_falloff_noreturn_function, diag::warn_noreturn_function_has_return_expr, -1,
  /* DiagArray348 */ diag::ext_offsetof_non_pod_type, diag::ext_offsetof_non_standardlayout_type, -1,
  /* DiagArray349 */ diag::warn_drv_ps4_sdk_dir, diag::warn_drv_unable_to_find_directory_expected, -1,
  /* DiagArray350 */ diag::ext_partial_spec_not_more_specialized_than_primary, -1,
  /* DiagArray352 */ diag::ext_empty_character, diag::ext_unterminated_char_or_string, -1,
  /* DiagArray353 */ diag::warn_bad_character_encoding, diag::warn_bad_string_encoding, -1,
  /* DiagArray354 */ diag::ext_pp_bad_paste_ms, -1,
  /* DiagArray355 */ diag::warn_jump_out_of_seh_finally, -1,
  /* DiagArray356 */ diag::ext_keyword_as_ident, -1,
  /* DiagArray357 */ diag::warn_pp_macro_hides_keyword, -1,
  /* DiagArray358 */ diag::ext_param_promoted_not_compatible_with_prototype, -1,
  /* DiagArray359 */ diag::ext_token_used, -1,
  /* DiagArray360 */ diag::warn_parameter_size, diag::warn_return_value_size, -1,
  /* DiagArray362 */ diag::warn_impcast_literal_float_to_integer, diag::warn_impcast_literal_float_to_integer_out_of_range, -1,
  /* DiagArray363 */ diag::warn_float_overflow, diag::warn_float_underflow, -1,
  /* DiagArray364 */ diag::ext_template_arg_local_type, -1,
  /* DiagArray365 */ diag::warn_logical_not_on_lhs_of_check, -1,
  /* DiagArray366 */ diag::warn_logical_and_in_logical_or, -1,
  /* DiagArray367 */ diag::ext_c99_longlong, -1,
  /* DiagArray369 */ diag::ext_pp_macro_redef, -1,
  /* DiagArray370 */ diag::ext_main_used, diag::ext_noreturn_main, diag::ext_variadic_main, diag::warn_main_one_arg, diag::warn_main_redefined, diag::warn_main_returns_bool_literal, diag::warn_static_main, -1,
  /* DiagArray371 */ diag::ext_main_returns_nonint, -1,
  /* DiagArray372 */ diag::warn_has_warning_invalid_option, -1,
  /* DiagArray373 */ diag::ext_many_braces_around_scalar_init, -1,
  /* DiagArray374 */ diag::warn_max_unsigned_zero, -1,
  /* DiagArray375 */ diag::warn_suspicious_sizeof_memset, -1,
  /* DiagArray376 */ diag::warn_memsize_comparison, -1,
  /* DiagArray377 */ diag::warn_non_contravariant_param_types, diag::warn_non_covariant_ret_types, -1,
  /* DiagArray379 */ diag::ext_anonymous_record_with_type, diag::ext_ms_anonymous_record, -1,
  /* DiagArray380 */ diag::ext_ms_cast_fn_obj, diag::ext_ms_impcast_fn_obj, -1,
  /* DiagArray381 */ diag::ext_charize_microsoft, -1,
  /* DiagArray382 */ diag::ext_comment_paste_microsoft, -1,
  /* DiagArray383 */ diag::ext_default_init_const, -1,
  /* DiagArray384 */ diag::ext_pp_operator_used_as_macro_name, -1,
  /* DiagArray385 */ diag::ext_param_default_argument_redefinition, -1,
  /* DiagArray386 */ diag::warn_attribute_section_drectve, -1,
  /* DiagArray387 */ diag::ext_ctrl_z_eof_microsoft, -1,
  /* DiagArray388 */ diag::ext_ms_forward_ref_enum, -1,
  /* DiagArray389 */ diag::ext_enumerator_too_large, -1,
  /* DiagArray390 */ diag::ext_ellipsis_exception_spec, diag::ext_incomplete_in_exception_spec, diag::ext_mismatched_exception_spec, diag::ext_mismatched_exception_spec_explicit_instantiation, diag::ext_ms_missing_exception_specification, diag::ext_override_exception_spec, -1,
  /* DiagArray391 */ diag::warn_microsoft_dependent_exists, -1,
  /* DiagArray392 */ diag::ext_ms_explicit_constructor_call, -1,
  /* DiagArray393 */ diag::warn_member_extra_qualification, -1,
  /* DiagArray394 */ diag::ext_ms_c_enum_fixed_underlying_type, -1,
  /* DiagArray395 */ diag::ext_flexible_array_empty_aggregate_ms, diag::ext_flexible_array_union_ms, -1,
  /* DiagArray396 */ diag::ext_goto_into_protected_scope, -1,
  /* DiagArray397 */ diag::ext_ms_ambiguous_direct_base, -1,
  /* DiagArray398 */ diag::ext_pp_include_search_ms, -1,
  /* DiagArray399 */ diag::ext_mutable_reference, -1,
  /* DiagArray400 */ diag::ext_pure_function_definition, -1,
  /* DiagArray401 */ diag::ext_static_non_static, -1,
  /* DiagArray402 */ diag::ext_ms_sealed_keyword, -1,
  /* DiagArray403 */ diag::ext_explicit_instantiation_duplicate, diag::ext_found_via_dependent_bases_lookup, diag::ext_ms_delayed_template_argument, diag::ext_ms_deref_template_argument, diag::ext_ms_template_spec_redecl_out_of_scope, diag::ext_ms_template_type_arg_missing_typename, diag::ext_static_out_of_line, diag::ext_undeclared_unqual_id_with_dependent_base, -1,
  /* DiagArray404 */ diag::ext_union_member_of_reference_type, -1,
  /* DiagArray405 */ diag::ext_friend_tag_redecl_outside_namespace, -1,
  /* DiagArray406 */ diag::ext_ms_using_declaration_inaccessible, -1,
  /* DiagArray407 */ diag::ext_pseudo_dtor_on_void, -1,
  /* DiagArray408 */ diag::warn_mismatched_delete_new, -1,
  /* DiagArray409 */ diag::warn_conflicting_param_types, -1,
  /* DiagArray410 */ diag::warn_conflicting_ret_types, -1,
  /* DiagArray411 */ diag::warn_struct_class_previous_tag_mismatch, diag::warn_struct_class_tag_mismatch, -1,
  /* DiagArray412 */ diag::warn_missing_braces, -1,
  /* DiagArray413 */ diag::ext_no_declarators, diag::ext_standalone_specifier, diag::ext_typedef_without_a_name, diag::warn_standalone_specifier, -1,
  /* DiagArray414 */ diag::ext_missing_exception_specification, -1,
  /* DiagArray415 */ diag::warn_missing_field_initializers, -1,
  /* DiagArray418 */ diag::warn_missing_method_return_type, -1,
  /* DiagArray419 */ diag::warn_overriding_method_missing_noescape, -1,
  /* DiagArray420 */ diag::warn_suggest_noreturn_block, diag::warn_suggest_noreturn_function, -1,
  /* DiagArray421 */ diag::warn_cconv_knr, -1,
  /* DiagArray422 */ diag::warn_missing_prototype, -1,
  /* DiagArray423 */ diag::warn_missing_selector_name, -1,
  /* DiagArray424 */ diag::warn_missing_sysroot, -1,
  /* DiagArray425 */ diag::warn_missing_variable_declarations, -1,
  /* DiagArray426 */ diag::remark_module_build, diag::remark_module_build_done, diag::remark_module_lock_failure, diag::remark_module_lock_timeout, -1,
  /* DiagArray427 */ diag::warn_module_conflict, diag::warn_module_system_bit_conflict, -1,
  /* DiagArray428 */ diag::warn_module_config_mismatch, -1,
  /* DiagArray429 */ diag::warn_duplicate_module_file_extension, -1,
  /* DiagArray430 */ diag::remark_module_import, -1,
  /* DiagArray431 */ diag::ext_module_import_in_extern_c, -1,
  /* DiagArray432 */ diag::ext_equivalent_internal_linkage_decl_in_modules, -1,
  /* DiagArray433 */ diag::ext_module_import_not_at_top_level_noop, -1,
  /* DiagArray437 */ diag::warn_drv_msvc_not_found, -1,
  /* DiagArray438 */ diag::ext_multichar_character_literal, -1,
  /* DiagArray439 */ diag::warn_vbase_moved_multiple_times, -1,
  /* DiagArray441 */ diag::ext_anonymous_record_with_anonymous_type, -1,
  /* DiagArray443 */ diag::warn_operator_new_returns_null, -1,
  /* DiagArray444 */ diag::ext_no_newline_eof, diag::warn_no_newline_eof, -1,
  /* DiagArray445 */ diag::warn_dereference_of_noderef_type, diag::warn_dereference_of_noderef_type_no_decl, diag::warn_noderef_to_dereferenceable_pointer, -1,
  /* DiagArray448 */ diag::warn_non_literal_null_pointer, -1,
  /* DiagArray449 */ diag::warn_non_modular_include_in_framework_module, -1,
  /* DiagArray450 */ diag::warn_non_modular_include_in_module, -1,
  /* DiagArray451 */ diag::warn_cannot_pass_non_pod_arg_to_vararg, diag::warn_non_pod_vararg_with_format_string, diag::warn_second_parameter_to_va_arg_not_pod, diag::warn_second_parameter_to_va_arg_ownership_qualified, -1,
  /* DiagArray452 */ diag::warn_non_virtual_dtor, -1,
  /* DiagArray453 */ diag::warn_null_arg, diag::warn_null_ret, -1,
  /* DiagArray455 */ diag::pp_nonportable_path, -1,
  /* DiagArray456 */ diag::pp_nonportable_system_path, -1,
  /* DiagArray457 */ diag::warn_neon_vector_initializer_non_portable, -1,
  /* DiagArray458 */ diag::warn_cstruct_memaccess, -1,
  /* DiagArray459 */ diag::warn_nsconsumed_attribute_mismatch, -1,
  /* DiagArray460 */ diag::warn_nsreturns_retained_attribute_mismatch, -1,
  /* DiagArray461 */ diag::warn_null_in_arithmetic_operation, diag::warn_null_in_comparison_operation, -1,
  /* DiagArray462 */ diag::null_in_char_or_string, diag::null_in_file, -1,
  /* DiagArray463 */ diag::warn_impcast_null_pointer_to_integer, -1,
  /* DiagArray464 */ diag::warn_binding_null_to_reference, diag::warn_indirection_through_null, -1,
  /* DiagArray465 */ diag::warn_gnu_null_ptr_arith, diag::warn_pointer_arith_null_ptr, -1,
  /* DiagArray466 */ diag::warn_conflicting_nullability_attr_overriding_param_types, diag::warn_conflicting_nullability_attr_overriding_ret_types, diag::warn_mismatched_nullability_attr, diag::warn_null_resettable_setter, diag::warn_nullability_duplicate, -1,
  /* DiagArray467 */ diag::warn_nullability_missing, -1,
  /* DiagArray468 */ diag::warn_nullability_missing_array, -1,
  /* DiagArray469 */ diag::warn_nullability_declspec, -1,
  /* DiagArray470 */ diag::ext_nullability, -1,
  /* DiagArray471 */ diag::warn_nullability_inferred_on_nested_type, -1,
  /* DiagArray472 */ diag::warn_nullability_lost, -1,
  /* DiagArray473 */ diag::warn_autosynthesis_property_ivar_match, -1,
  /* DiagArray474 */ diag::warn_impcast_constant_int_to_objc_bool, -1,
  /* DiagArray475 */ diag::warn_objc_boxing_invalid_utf8_string, -1,
  /* DiagArray476 */ diag::warn_objc_circular_container, -1,
  /* DiagArray478 */ diag::warn_objc_designated_init_missing_super_call, diag::warn_objc_designated_init_non_designated_init_call, diag::warn_objc_designated_init_non_super_designated_init_call, diag::warn_objc_implementation_missing_designated_init_override, diag::warn_objc_secondary_init_missing_init_call, diag::warn_objc_secondary_init_super_init_call, -1,
  /* DiagArray479 */ diag::warn_superclass_variable_sized_type_not_at_end, diag::warn_variable_sized_ivar_visibility, -1,
  /* DiagArray480 */ diag::warn_forward_class_redefinition, -1,
  /* DiagArray481 */ diag::warn_ivars_in_interface, -1,
  /* DiagArray482 */ diag::warn_objc_literal_comparison, -1,
  /* DiagArray483 */ diag::warn_impcast_objective_c_literal_to_bool, diag::warn_objc_collection_literal_element, -1,
  /* DiagArray484 */ diag::warn_pp_objc_macro_redef_ignored, -1,
  /* DiagArray485 */ diag::warn_messaging_unqualified_id, -1,
  /* DiagArray486 */ diag::warn_class_method_not_found, diag::warn_class_method_not_found_with_typo, diag::warn_inst_method_not_found, diag::warn_instance_method_not_found_with_typo, diag::warn_instance_method_on_class_found, diag::warn_root_inst_method_not_found, -1,
  /* DiagArray487 */ diag::warn_missing_explicit_synthesis, -1,
  /* DiagArray488 */ diag::warn_objc_missing_super_call, -1,
  /* DiagArray489 */ diag::warn_multiple_method_decl, -1,
  /* DiagArray490 */ diag::warn_objc_property_retain_of_block, -1,
  /* DiagArray491 */ diag::warn_objc_pointer_cxx_catch_fragile, -1,
  /* DiagArray492 */ diag::warn_objc_property_assign_on_object, -1,
  /* DiagArray493 */ diag::warn_impl_required_for_class_property, diag::warn_impl_required_in_category_for_class_property, diag::warn_setter_getter_impl_required, diag::warn_setter_getter_impl_required_in_category, -1,
  /* DiagArray494 */ diag::warn_property_implicitly_mismatched, -1,
  /* DiagArray495 */ diag::warn_cocoa_naming_owned_rule, -1,
  /* DiagArray496 */ diag::warn_objc_property_default_assign_on_object, diag::warn_objc_property_no_assignment_attribute, -1,
  /* DiagArray497 */ diag::warn_autosynthesis_property_in_superclass, diag::warn_no_autosynthesis_property, diag::warn_no_autosynthesis_shared_ivar_property, -1,
  /* DiagArray498 */ diag::warn_category_method_impl_match, -1,
  /* DiagArray499 */ diag::warn_auto_synthesizing_protocol_property, -1,
  /* DiagArray500 */ diag::warn_objc_redundant_qualified_class_type, -1,
  /* DiagArray501 */ diag::warn_objc_readonly_property_has_setter, -1,
  /* DiagArray503 */ diag::warn_objc_redundant_literal_use, -1,
  /* DiagArray504 */ diag::warn_objc_root_class_missing, -1,
  /* DiagArray505 */ diag::warn_objc_string_literal_comparison, -1,
  /* DiagArray506 */ diag::warn_concatenated_nsarray_literal, -1,
  /* DiagArray507 */ diag::warn_objc_unsafe_perform_selector, -1,
  /* DiagArray508 */ diag::warn_odr_different_num_template_parameters, diag::warn_odr_different_template_parameter_kind, diag::warn_odr_field_type_inconsistent, diag::warn_odr_function_type_inconsistent, diag::warn_odr_ivar_type_inconsistent, diag::warn_odr_non_type_parameter_type_inconsistent, diag::warn_odr_objc_method_num_params_inconsistent, diag::warn_odr_objc_method_param_type_inconsistent, diag::warn_odr_objc_method_result_type_inconsistent, diag::warn_odr_objc_method_variadic_inconsistent, diag::warn_odr_objc_property_impl_kind_inconsistent, diag::warn_odr_objc_property_type_inconsistent, diag::warn_odr_objc_superclass_inconsistent, diag::warn_odr_objc_synthesize_ivar_inconsistent, diag::warn_odr_parameter_pack_non_pack, diag::warn_odr_tag_type_inconsistent, diag::warn_odr_variable_multiple_def, diag::warn_odr_variable_type_inconsistent, -1,
  /* DiagArray509 */ diag::warn_old_style_cast, -1,
  /* DiagArray511 */ diag::ext_opencl_ext_vector_type_rgba_selector, -1,
  /* DiagArray512 */ diag::warn_omp_alignment_not_power_of_two, diag::warn_omp_allocate_thread_on_task_target_directive, diag::warn_omp_linear_step_zero, diag::warn_omp_used_different_allocator, -1,
  /* DiagArray513 */ diag::ext_omp_loop_not_canonical_init, diag::warn_omp_loop_64_bit_var, -1,
  /* DiagArray514 */ diag::warn_drv_omp_offload_target_duplicate, diag::warn_drv_omp_offload_target_missingbcruntime, diag::warn_omp_non_trivial_type_mapped, diag::warn_omp_not_in_target_context, -1,
  /* DiagArray515 */ diag::warn_drv_fine_grained_bitfield_accesses_ignored, diag::warn_drv_moutline_unsupported_opt, diag::warn_drv_ps4_force_pic, diag::warn_drv_unsupported_longcalls, diag::warn_drv_unsupported_pic_with_mabicalls, diag::warn_drv_vectorize_needs_hvx, -1,
  /* DiagArray516 */ diag::ext_typecheck_ordered_comparison_of_function_pointers, -1,
  /* DiagArray517 */ diag::ext_out_of_line_declaration, -1,
  /* DiagArray518 */ diag::ext_use_out_of_scope_declaration, -1,
  /* DiagArray519 */ diag::warn_overaligned_type, -1,
  /* DiagArray521 */ diag::ext_string_too_long, -1,
  /* DiagArray522 */ diag::warn_overloaded_shift_in_comparison, -1,
  /* DiagArray523 */ diag::warn_overloaded_virtual, -1,
  /* DiagArray525 */ diag::warn_fe_override_module, -1,
  /* DiagArray526 */ diag::warn_conflicting_overriding_param_modifiers, diag::warn_conflicting_overriding_param_types, diag::warn_conflicting_overriding_ret_type_modifiers, diag::warn_conflicting_overriding_ret_types, diag::warn_conflicting_overriding_variadic, diag::warn_non_contravariant_overriding_param_types, diag::warn_non_covariant_overriding_ret_types, -1,
  /* DiagArray527 */ diag::warn_drv_overriding_flag_option, -1,
  /* DiagArray528 */ diag::warn_unnecessary_packed, -1,
  /* DiagArray529 */ diag::warn_padded_struct_anon_field, diag::warn_padded_struct_field, diag::warn_padded_struct_size, -1,
  /* DiagArray530 */ diag::warn_condition_is_assignment, diag::warn_precedence_bitwise_rel, diag::warn_precedence_conditional, -1,
  /* DiagArray531 */ diag::warn_equality_with_extra_parens, -1,
  /* DiagArray533 */ diag::remark_fe_backend_optimization_remark, -1,
  /* DiagArray534 */ diag::remark_fe_backend_optimization_remark_analysis, diag::remark_fe_backend_optimization_remark_analysis_aliasing, diag::remark_fe_backend_optimization_remark_analysis_fpcommute, -1,
  /* DiagArray535 */ diag::warn_fe_backend_optimization_failure, -1,
  /* DiagArray536 */ diag::remark_fe_backend_optimization_remark_missed, -1,
  /* DiagArray537 */ diag::warn_module_uses_date_time, -1,
  /* DiagArray538 */ diag::ext_aggregate_init_not_constant, diag::ext_anonymous_record_with_type, diag::ext_anonymous_struct_union_qualified, diag::ext_array_size_conversion, diag::ext_auto_new_list_init, diag::ext_c99_array_usage, diag::ext_c99_compound_literal, diag::ext_c99_flexible_array_member, diag::ext_c99_variable_decl_in_for_loop, diag::ext_cast_fn_obj, diag::ext_clang_diagnose_if, diag::ext_clang_enable_if, diag::ext_cxx11_enum_fixed_underlying_type, diag::ext_cxx14_attr, diag::ext_cxx17_attr, diag::ext_designated_init, diag::ext_duplicate_declspec, diag::ext_ellipsis_exception_spec, diag::ext_empty_fnmacro_arg, diag::ext_enum_value_not_int, diag::ext_enumerator_list_comma_c, diag::ext_enumerator_list_comma_cxx, diag::ext_explicit_instantiation_without_qualified_id, diag::ext_extern_template, diag::ext_extra_semi, diag::ext_forward_ref_enum, diag::ext_freestanding_complex, diag::ext_gnu_array_range, diag::ext_gnu_ptr_func_arith, diag::ext_gnu_subscript_void_type, diag::ext_gnu_void_ptr, diag::ext_hex_constant_invalid, diag::ext_hex_literal_invalid, diag::ext_ident_list_in_param, diag::ext_integer_complement_complex, diag::ext_integer_increment_complex, diag::ext_internal_in_extern_inline_quiet, diag::ext_invalid_sign_spec, diag::ext_line_comment, diag::ext_main_used, diag::ext_multi_line_line_comment, diag::ext_named_variadic_macro, diag::ext_no_newline_eof, diag::ext_nonstandard_escape, diag::ext_ns_enum_attribute, diag::ext_param_not_declared, diag::ext_pointer_to_const_ref_member_on_rvalue, diag::ext_pp_bad_vaargs_use, diag::ext_pp_comma_expr, diag::ext_pp_ident_directive, diag::ext_pp_line_too_big, diag::ext_pp_opencl_variadic_macros, diag::ext_pp_warning_directive, diag::ext_return_has_void_expr, diag::ext_rvalue_to_reference_access_ctor, diag::ext_rvalue_to_reference_temp_copy_no_viable, diag::ext_sizeof_alignof_function_type, diag::ext_sizeof_alignof_void_type, diag::ext_subscript_non_lvalue, diag::ext_thread_before, diag::ext_typecheck_addrof_void, diag::ext_typecheck_cast_nonscalar, diag::ext_typecheck_comparison_of_fptr_to_void, diag::ext_typecheck_cond_one_void, diag::ext_typecheck_convert_pointer_void_func, diag::ext_typecheck_ordered_comparison_of_pointer_and_zero, diag::ext_variadic_macro, diag::warn_defined_in_function_type_macro, diag::warn_format_conversion_argument_type_mismatch_pedantic, diag::warn_illegal_constant_array_size, diag::warn_kern_is_method, -1,
  /* DiagArray539 */ diag::warn_pragma_extension_is_core, -1,
  /* DiagArray540 */ diag::warn_pessimizing_move_on_initialization, diag::warn_pessimizing_move_on_return, -1,
  /* DiagArray541 */ diag::ext_gnu_ptr_func_arith, diag::ext_gnu_subscript_void_type, diag::ext_gnu_void_ptr, diag::ext_sizeof_alignof_function_type, diag::ext_sizeof_alignof_void_type, diag::warn_sub_ptr_zero_size_types, -1,
  /* DiagArray542 */ diag::warn_cast_nonnull_to_bool, diag::warn_impcast_pointer_to_bool, -1,
  /* DiagArray543 */ diag::ext_typecheck_comparison_of_pointer_integer, -1,
  /* DiagArray544 */ diag::ext_typecheck_convert_incompatible_pointer_sign, -1,
  /* DiagArray546 */ diag::ext_typecheck_cond_incompatible_pointers, -1,
  /* DiagArray547 */ diag::warn_side_effects_typeid, -1,
  /* DiagArray548 */ diag::warn_pragma_attribute_unused, -1,
  /* DiagArray549 */ diag::pp_pragma_once_in_main_file, -1,
  /* DiagArray550 */ diag::warn_pragma_pack_modified_after_include, diag::warn_pragma_pack_no_pop_eof, -1,
  /* DiagArray551 */ diag::warn_pragma_pack_non_default_at_include, -1,
  /* DiagArray552 */ diag::pp_pragma_sysheader_in_main_file, -1,
  /* DiagArray553 */ diag::warn_redefine_extname_not_applied, -1,
  /* DiagArray554 */ diag::ext_predef_outside_function, -1,
  /* DiagArray555 */ diag::warn_private_extern, -1,
  /* DiagArray556 */ diag::warn_use_of_private_header_outside_module, -1,
  /* DiagArray557 */ diag::warn_mmap_mismatched_private_module_name, diag::warn_mmap_mismatched_private_submodule, diag::warn_mmap_redundant_export_as, diag::warn_no_priv_submodule_use_toplevel, -1,
  /* DiagArray558 */ diag::warn_profile_data_missing, -1,
  /* DiagArray559 */ diag::warn_profile_data_out_of_date, -1,
  /* DiagArray560 */ diag::warn_profile_data_unprofiled, -1,
  /* DiagArray561 */ diag::warn_property_access_suggest, -1,
  /* DiagArray562 */ diag::warn_property_attr_mismatch, diag::warn_property_attribute, diag::warn_property_redecl_getter_mismatch, diag::warn_readonly_property, -1,
  /* DiagArray563 */ diag::warn_unimplemented_protocol_method, -1,
  /* DiagArray564 */ diag::warn_protocol_property_mismatch, -1,
  /* DiagArray565 */ diag::err_func_returning_qualified_void, -1,
  /* DiagArray566 */ diag::warn_quoted_include_in_framework_header, -1,
  /* DiagArray567 */ diag::warn_for_range_const_reference_copy, diag::warn_for_range_copy, diag::warn_for_range_variable_always_copy, -1,
  /* DiagArray568 */ diag::warn_auto_readonly_iboutlet_property, -1,
  /* DiagArray569 */ diag::warn_bad_receiver_type, -1,
  /* DiagArray570 */ diag::warn_receiver_forward_class, diag::warn_receiver_forward_instance, -1,
  /* DiagArray571 */ diag::ext_member_redeclared, -1,
  /* DiagArray573 */ diag::warn_redundant_move_on_return, -1,
  /* DiagArray574 */ diag::warn_redundant_parens_around_declarator, -1,
  /* DiagArray575 */ diag::ext_register_storage_class, -1,
  /* DiagArray576 */ diag::warn_reinterpret_different_from_static, -1,
  /* DiagArray577 */ diag::remark_fe_backend_plugin, -1,
  /* DiagArray578 */ diag::warn_initializer_out_of_order, -1,
  /* DiagArray579 */ diag::warn_objc_requires_super_protocol, -1,
  /* DiagArray580 */ diag::warn_pp_macro_is_reserved_id, -1,
  /* DiagArray581 */ diag::ext_ms_reserved_user_defined_literal, diag::ext_reserved_user_defined_literal, -1,
  /* DiagArray582 */ diag::ext_retained_language_linkage, -1,
  /* DiagArray583 */ diag::warn_ret_addr_label, diag::warn_ret_local_temp_addr_ref, diag::warn_ret_stack_addr_ref, -1,
  /* DiagArray584 */ diag::warn_return_std_move, -1,
  /* DiagArray585 */ diag::warn_return_std_move_in_cxx11, -1,
  /* DiagArray586 */ diag::ext_return_has_expr, diag::ext_return_missing_expr, diag::warn_falloff_nonvoid_coroutine, diag::warn_falloff_nonvoid_function, diag::warn_falloff_nonvoid_lambda, diag::warn_maybe_falloff_nonvoid_coroutine, diag::warn_maybe_falloff_nonvoid_function, diag::warn_maybe_falloff_nonvoid_lambda, diag::warn_return_missing_expr, -1,
  /* DiagArray587 */ diag::warn_return_value_udt, diag::warn_return_value_udt_incomplete, -1,
  /* DiagArray588 */ diag::remark_sanitize_address_insert_extra_padding_accepted, diag::remark_sanitize_address_insert_extra_padding_rejected, -1,
  /* DiagArray589 */ diag::warn_attribute_section_on_redeclaration, diag::warn_duplicate_codeseg_attribute, diag::warn_mismatched_section, -1,
  /* DiagArray590 */ diag::warn_unimplemented_selector, -1,
  /* DiagArray591 */ diag::warn_multiple_selectors, -1,
  /* DiagArray592 */ diag::warn_self_assignment_builtin, -1,
  /* DiagArray593 */ diag::warn_identity_field_assign, -1,
  /* DiagArray594 */ diag::warn_self_assignment_overloaded, -1,
  /* DiagArray595 */ diag::warn_self_move, -1,
  /* DiagArray596 */ diag::warn_semicolon_before_method_body, -1,
  /* DiagArray597 */ diag::warn_missing_sentinel, diag::warn_not_enough_argument, -1,
  /* DiagArray599 */ diag::warn_fe_serialized_diag_failure, diag::warn_fe_serialized_diag_merge_failure, -1,
  /* DiagArray600 */ diag::warn_decl_shadow, -1,
  /* DiagArray602 */ diag::warn_shadow_field, -1,
  /* DiagArray603 */ diag::warn_ctor_parm_shadows_field, -1,
  /* DiagArray604 */ diag::warn_modifying_shadowing_decl, -1,
  /* DiagArray605 */ diag::warn_ivar_use_hidden, -1,
  /* DiagArray606 */ diag::warn_decl_shadow_uncaptured_local, -1,
  /* DiagArray607 */ diag::warn_shift_negative, -1,
  /* DiagArray608 */ diag::warn_shift_gt_typewidth, -1,
  /* DiagArray609 */ diag::warn_shift_lhs_negative, -1,
  /* DiagArray610 */ diag::warn_addition_in_bitshift, -1,
  /* DiagArray611 */ diag::warn_shift_result_gt_typewidth, -1,
  /* DiagArray612 */ diag::warn_shift_result_sets_sign_bit, -1,
  /* DiagArray613 */ diag::warn_impcast_integer_64_32, -1,
  /* DiagArray614 */ diag::warn_mixed_sign_comparison, -1,
  /* DiagArray615 */ diag::warn_impcast_integer_sign, diag::warn_impcast_integer_sign_conditional, diag::warn_impcast_nonnegative_result, -1,
  /* DiagArray617 */ diag::warn_no_underlying_type_specified_for_enum_bitfield, -1,
  /* DiagArray618 */ diag::warn_sizeof_array_param, -1,
  /* DiagArray619 */ diag::warn_sizeof_array_decay, -1,
  /* DiagArray620 */ diag::warn_division_sizeof_ptr, -1,
  /* DiagArray621 */ diag::warn_sizeof_pointer_expr_memaccess, diag::warn_sizeof_pointer_type_memaccess, -1,
  /* DiagArray622 */ diag::warn_slash_u_filename, -1,
  /* DiagArray623 */ diag::warn_sometimes_uninit_var, -1,
  /* DiagArray624 */ diag::warn_omp_nesting_simd, diag::warn_pragma_omp_ignored, -1,
  /* DiagArray625 */ diag::warn_sampler_initializer_invalid_bits, -1,
  /* DiagArray627 */ diag::ext_in_class_initializer_float_type_cxx11, -1,
  /* DiagArray628 */ diag::ext_internal_in_extern_inline, diag::ext_internal_in_extern_inline_quiet, -1,
  /* DiagArray629 */ diag::warn_static_inline_explicit_inst_ignored, -1,
  /* DiagArray630 */ diag::warn_static_local_in_extern_inline, -1,
  /* DiagArray631 */ diag::warn_static_self_reference_in_init, -1,
  /* DiagArray632 */ diag::warn_drv_libstdcxx_not_found, -1,
  /* DiagArray644 */ diag::warn_strict_prototypes, -1,
  /* DiagArray645 */ diag::warn_strict_multiple_method_decl, -1,
  /* DiagArray646 */ diag::warn_stringcompare, -1,
  /* DiagArray647 */ diag::warn_impcast_string_literal_to_bool, -1,
  /* DiagArray648 */ diag::warn_string_plus_char, -1,
  /* DiagArray649 */ diag::warn_string_plus_int, -1,
  /* DiagArray650 */ diag::warn_strlcpycat_wrong_size, -1,
  /* DiagArray651 */ diag::warn_strncat_large_size, diag::warn_strncat_src_size, diag::warn_strncat_wrong_size, -1,
  /* DiagArray652 */ diag::ext_typecheck_base_super, -1,
  /* DiagArray653 */ diag::warn_suspicious_bzero_size, -1,
  /* DiagArray655 */ diag::warn_case_value_overflow, diag::warn_missing_case, diag::warn_not_in_enum, -1,
  /* DiagArray656 */ diag::warn_bool_switch_condition, -1,
  /* DiagArray658 */ diag::warn_def_missing_case, -1,
  /* DiagArray659 */ diag::warn_sync_fetch_and_nand_semantics_change, -1,
  /* DiagArray661 */ diag::warn_comparison_always, diag::warn_comparison_bitwise_always, -1,
  /* DiagArray662 */ diag::warn_tautological_bool_compare, -1,
  /* DiagArray664 */ diag::warn_out_of_range_compare, -1,
  /* DiagArray665 */ diag::warn_tautological_compare_objc_bool, -1,
  /* DiagArray666 */ diag::warn_tautological_overlap_comparison, -1,
  /* DiagArray667 */ diag::warn_nonnull_expr_compare, diag::warn_null_pointer_compare, -1,
  /* DiagArray668 */ diag::warn_tautological_constant_compare, -1,
  /* DiagArray669 */ diag::warn_address_of_reference_null_compare, diag::warn_this_null_compare, -1,
  /* DiagArray670 */ diag::warn_unsigned_enum_always_true_comparison, -1,
  /* DiagArray671 */ diag::warn_unsigned_always_true_comparison, -1,
  /* DiagArray672 */ diag::ext_typecheck_decl_incomplete_type, -1,
  /* DiagArray674 */ diag::warn_acquired_before, diag::warn_acquired_before_after_cycle, diag::warn_cannot_resolve_lock, diag::warn_double_lock, diag::warn_expecting_lock_held_on_loop, diag::warn_expecting_locked, diag::warn_fun_excludes_mutex, diag::warn_fun_requires_lock, diag::warn_lock_exclusive_and_shared, diag::warn_lock_some_predecessors, diag::warn_no_unlock, diag::warn_unlock_but_no_lock, diag::warn_unlock_kind_mismatch, diag::warn_var_deref_requires_any_lock, diag::warn_var_deref_requires_lock, diag::warn_variable_requires_any_lock, diag::warn_variable_requires_lock, -1,
  /* DiagArray675 */ diag::warn_invalid_capability_name, diag::warn_thread_attribute_argument_not_lockable, diag::warn_thread_attribute_decl_not_lockable, diag::warn_thread_attribute_decl_not_pointer, diag::warn_thread_attribute_ignored, diag::warn_thread_attribute_not_on_capability_member, diag::warn_thread_attribute_not_on_non_static_member, -1,
  /* DiagArray676 */ diag::warn_thread_safety_beta, -1,
  /* DiagArray677 */ diag::warn_acquire_requires_negative_cap, -1,
  /* DiagArray678 */ diag::warn_fun_requires_lock_precise, diag::warn_var_deref_requires_lock_precise, diag::warn_variable_requires_lock_precise, -1,
  /* DiagArray679 */ diag::warn_guarded_pass_by_reference, diag::warn_pt_guarded_pass_by_reference, -1,
  /* DiagArray680 */ diag::warn_thread_safety_verbose, -1,
  /* DiagArray681 */ diag::trigraph_converted, diag::trigraph_ends_block_comment, diag::trigraph_ignored, diag::trigraph_ignored_block_comment, -1,
  /* DiagArray683 */ diag::warn_type_safety_null_pointer_required, diag::warn_type_safety_type_mismatch, diag::warn_type_tag_for_datatype_wrong_kind, -1,
  /* DiagArray684 */ diag::ext_redefinition_of_typedef, -1,
  /* DiagArray685 */ diag::ext_typename_missing, -1,
  /* DiagArray686 */ diag::warn_fe_unable_to_open_stats_file, -1,
  /* DiagArray687 */ diag::warn_unavailable_fwdclass_message, -1,
  /* DiagArray688 */ diag::warn_undeclared_selector, diag::warn_undeclared_selector_with_typo, -1,
  /* DiagArray689 */ diag::warn_pp_undef_identifier, -1,
  /* DiagArray690 */ diag::warn_address_of_reference_bool_conversion, diag::warn_this_bool_conversion, -1,
  /* DiagArray691 */ diag::warn_func_template_missing, -1,
  /* DiagArray692 */ diag::warn_undefined_inline, -1,
  /* DiagArray693 */ diag::warn_undefined_internal, -1,
  /* DiagArray694 */ diag::ext_undefined_internal_type, -1,
  /* DiagArray695 */ diag::warn_pointer_indirection_from_incompatible_type, diag::warn_undefined_reinterpret_cast, -1,
  /* DiagArray696 */ diag::warn_var_template_missing, -1,
  /* DiagArray697 */ diag::warn_throw_underaligned_obj, -1,
  /* DiagArray698 */ diag::warn_side_effects_unevaluated_context, -1,
  /* DiagArray699 */ diag::warn_unguarded_availability, -1,
  /* DiagArray700 */ diag::warn_unguarded_availability_new, -1,
  /* DiagArray701 */ diag::warn_ucn_escape_incomplete, diag::warn_ucn_escape_no_digits, diag::warn_ucn_escape_surrogate, diag::warn_ucn_not_valid_in_c89, diag::warn_ucn_not_valid_in_c89_literal, -1,
  /* DiagArray702 */ diag::warn_utf8_symbol_homoglyph, -1,
  /* DiagArray703 */ diag::ext_unicode_whitespace, -1,
  /* DiagArray704 */ diag::warn_utf8_symbol_zero_width, -1,
  /* DiagArray705 */ diag::warn_base_class_is_uninit, diag::warn_field_is_uninit, diag::warn_reference_field_is_uninit, diag::warn_uninit_byref_blockvar_captured_by_block, diag::warn_uninit_self_reference_in_init, diag::warn_uninit_self_reference_in_reference_init, diag::warn_uninit_var, -1,
  /* DiagArray706 */ diag::warn_drv_unknown_argument_clang_cl, diag::warn_drv_unknown_argument_clang_cl_with_suggestion, -1,
  /* DiagArray707 */ diag::warn_unknown_attribute_ignored, -1,
  /* DiagArray708 */ diag::ext_unknown_escape, -1,
  /* DiagArray709 */ diag::ext_on_off_switch_syntax, diag::ext_pragma_syntax_eod, diag::ext_stdc_pragma_ignored, diag::warn_pragma_diagnostic_cannot_pop, diag::warn_pragma_diagnostic_invalid, diag::warn_pragma_diagnostic_invalid_option, diag::warn_pragma_diagnostic_invalid_token, diag::warn_pragma_exec_charset_expected, diag::warn_pragma_exec_charset_push_invalid, diag::warn_pragma_exec_charset_spec_invalid, diag::warn_pragma_ignored, diag::warn_pragma_include_alias_expected, diag::warn_pragma_include_alias_expected_filename, diag::warn_pragma_include_alias_mismatch_angle, diag::warn_pragma_include_alias_mismatch_quote, diag::warn_pragma_warning_expected, diag::warn_pragma_warning_expected_number, diag::warn_pragma_warning_push_level, diag::warn_pragma_warning_spec_invalid, diag::warn_stdc_fenv_access_not_supported, -1,
  /* DiagArray710 */ diag::warn_unknown_sanitizer_ignored, -1,
  /* DiagArray711 */ diag::warn_pragma_diagnostic_unknown_warning, diag::warn_unknown_diag_option, diag::warn_unknown_warning_specifier, -1,
  /* DiagArray712 */ diag::ext_template_arg_unnamed_type, -1,
  /* DiagArray713 */ diag::warn_unneeded_internal_decl, diag::warn_unneeded_static_internal_decl, -1,
  /* DiagArray714 */ diag::warn_unneeded_member_function, -1,
  /* DiagArray715 */ diag::warn_unreachable, -1,
  /* DiagArray717 */ diag::warn_unreachable_break, -1,
  /* DiagArray718 */ diag::warn_unreachable_loop_increment, -1,
  /* DiagArray719 */ diag::warn_unreachable_return, -1,
  /* DiagArray720 */ diag::warn_unsequenced_mod_mod, diag::warn_unsequenced_mod_use, -1,
  /* DiagArray721 */ diag::warn_target_unsupported_abs2008, diag::warn_target_unsupported_abslegacy, -1,
  /* DiagArray722 */ diag::warn_at_available_unchecked_use, -1,
  /* DiagArray723 */ diag::warn_target_unsupported_compact_branches, -1,
  /* DiagArray724 */ diag::warn_attribute_dll_instantiated_base_class, -1,
  /* DiagArray725 */ diag::warn_template_qualified_friend_ignored, diag::warn_template_qualified_friend_unsupported, -1,
  /* DiagArray726 */ diag::warn_drv_unsupported_gpopt, -1,
  /* DiagArray727 */ diag::warn_target_unsupported_nan2008, diag::warn_target_unsupported_nanlegacy, -1,
  /* DiagArray728 */ diag::warn_drv_unsupported_debug_info_opt_for_target, -1,
  /* DiagArray729 */ diag::warn_attribute_protected_visibility, -1,
  /* DiagArray730 */ diag::ext_partial_specs_not_deducible, -1,
  /* DiagArray733 */ diag::warn_drv_diagnostics_hotness_requires_pgo, diag::warn_drv_empty_joined_argument, diag::warn_drv_input_file_unused, diag::warn_drv_input_file_unused_by_cpp, diag::warn_drv_preprocessed_input_file_unused, diag::warn_drv_unused_argument, diag::warn_ignored_clang_option, -1,
  /* DiagArray734 */ diag::warn_unused_comparison, -1,
  /* DiagArray735 */ diag::warn_unused_const_variable, -1,
  /* DiagArray736 */ diag::warn_unused_exception_param, -1,
  /* DiagArray737 */ diag::warn_unused_function, -1,
  /* DiagArray738 */ diag::warn_unused_property_expr, -1,
  /* DiagArray739 */ diag::warn_unused_label, -1,
  /* DiagArray740 */ diag::warn_unused_lambda_capture, -1,
  /* DiagArray741 */ diag::warn_unused_local_typedef, -1,
  /* DiagArray743 */ diag::pp_macro_not_used, -1,
  /* DiagArray744 */ diag::warn_unused_member_function, -1,
  /* DiagArray745 */ diag::warn_unused_parameter, -1,
  /* DiagArray746 */ diag::warn_unused_private_field, -1,
  /* DiagArray747 */ diag::warn_unused_property_backing_ivar, -1,
  /* DiagArray748 */ diag::warn_unused_result, -1,
  /* DiagArray749 */ diag::warn_unused_template, -1,
  /* DiagArray750 */ diag::warn_unused_call, diag::warn_unused_container_subscript_expr, diag::warn_unused_expr, diag::warn_unused_voidptr, -1,
  /* DiagArray751 */ diag::warn_unused_variable, -1,
  /* DiagArray752 */ diag::warn_unused_volatile, -1,
  /* DiagArray753 */ diag::warn_used_but_marked_unused, -1,
  /* DiagArray754 */ diag::warn_user_literal_reserved, -1,
  /* DiagArray755 */ diag::warn_diagnose_if_succeeded, -1,
  /* DiagArray756 */ diag::warn_second_arg_of_va_start_not_last_named_param, diag::warn_second_parameter_to_va_arg_never_compatible, diag::warn_va_start_type_is_undefined, -1,
  /* DiagArray757 */ diag::ext_named_variadic_macro, diag::ext_pp_bad_vaopt_use, diag::ext_variadic_macro, -1,
  /* DiagArray758 */ diag::warn_typecheck_vector_element_sizes_not_equal, -1,
  /* DiagArray759 */ diag::warn_incompatible_vectors, -1,
  /* DiagArray761 */ diag::warn_empty_parens_are_function_decl, diag::warn_parens_disambiguated_as_function_declaration, diag::warn_parens_disambiguated_as_variable_declaration, -1,
  /* DiagArray762 */ diag::warn_decl_in_param_list, diag::warn_redefinition_in_param_list, -1,
  /* DiagArray763 */ diag::warn_vla_used, -1,
  /* DiagArray764 */ diag::ext_vla, -1,
  /* DiagArray765 */ diag::ext_typecheck_indirection_through_void_pointer, -1,
  /* DiagArray767 */ diag::warn_weak_template_vtable, -1,
  /* DiagArray768 */ diag::warn_weak_vtable, -1,
  /* DiagArray769 */ diag::ext_deprecated_string_literal_conversion, -1,
  /* DiagArray771 */ diag::warn_zero_as_null_pointer_constant, -1,
  /* DiagArray772 */ diag::ext_typecheck_zero_array_size, -1,
};

static const int16_t DiagSubGroups[] = {
  /* Empty */ -1,
  /* DiagSubGroup0 */ 225, -1,
  /* DiagSubGroup4 */ 15, 225, -1,
  /* DiagSubGroup11 */ 542, 646, 667, -1,
  /* DiagSubGroup15 */ 434, 530, 655, 656, -1,
  /* DiagSubGroup23 */ 30, 29, 26, -1,
  /* DiagSubGroup28 */ 25, -1,
  /* DiagSubGroup34 */ 36, 35, -1,
  /* DiagSubGroup44 */ 295, 151, -1,
  /* DiagSubGroup47 */ 707, 288, -1,
  /* DiagSubGroup57 */ 85, 105, 263, -1,
  /* DiagSubGroup58 */ 108, -1,
  /* DiagSubGroup65 */ 542, 690, -1,
  /* DiagSubGroup66 */ 65, -1,
  /* DiagSubGroup73 */ 76, -1,
  /* DiagSubGroup74 */ 80, -1,
  /* DiagSubGroup75 */ 84, -1,
  /* DiagSubGroup76 */ 84, 79, 77, 104, 102, 100, -1,
  /* DiagSubGroup78 */ 76, 106, 103, 101, -1,
  /* DiagSubGroup80 */ 81, 82, 83, -1,
  /* DiagSubGroup86 */ 102, 100, -1,
  /* DiagSubGroup87 */ 86, 103, 101, -1,
  /* DiagSubGroup88 */ 85, -1,
  /* DiagSubGroup89 */ 176, 172, 90, 100, -1,
  /* DiagSubGroup91 */ 89, 101, -1,
  /* DiagSubGroup93 */ 88, -1,
  /* DiagSubGroup94 */ 89, -1,
  /* DiagSubGroup95 */ 90, -1,
  /* DiagSubGroup96 */ 92, -1,
  /* DiagSubGroup98 */ 97, -1,
  /* DiagSubGroup101 */ 100, -1,
  /* DiagSubGroup103 */ 102, -1,
  /* DiagSubGroup106 */ 104, 105, -1,
  /* DiagSubGroup107 */ 110, 112, 104, 102, 100, -1,
  /* DiagSubGroup111 */ 107, 108, 109, 106, 103, 101, -1,
  /* DiagSubGroup125 */ 451, -1,
  /* DiagSubGroup128 */ 127, -1,
  /* DiagSubGroup135 */ 60, 474, -1,
  /* DiagSubGroup139 */ 65, 135, 213, 61, 234, 613, 337, 304, 301, 362, 448, 463, 483, 615, 647, -1,
  /* DiagSubGroup140 */ 463, -1,
  /* DiagSubGroup141 */ 142, -1,
  /* DiagSubGroup144 */ 2, -1,
  /* DiagSubGroup152 */ 154, 155, 583, -1,
  /* DiagSubGroup166 */ 165, 163, -1,
  /* DiagSubGroup167 */ 168, 169, 170, 172, 176, 177, 178, -1,
  /* DiagSubGroup174 */ 175, -1,
  /* DiagSubGroup178 */ 77, -1,
  /* DiagSubGroup184 */ 185, -1,
  /* DiagSubGroup189 */ 191, 190, -1,
  /* DiagSubGroup192 */ 193, -1,
  /* DiagSubGroup202 */ 170, -1,
  /* DiagSubGroup203 */ 452, -1,
  /* DiagSubGroup210 */ 229, -1,
  /* DiagSubGroup211 */ 212, -1,
  /* DiagSubGroup225 */ 415, 293, 331, 596, 418, 614, 745, 465, 207, -1,
  /* DiagSubGroup227 */ 109, 81, -1,
  /* DiagSubGroup228 */ 207, -1,
  /* DiagSubGroup234 */ 236, 237, -1,
  /* DiagSubGroup239 */ 240, 247, 453, 245, 246, 241, -1,
  /* DiagSubGroup248 */ 243, 245, 246, -1,
  /* DiagSubGroup258 */ 259, 260, 262, 263, 264, 265, 266, 267, 268, 269, 270, 764, 271, 272, 273, 274, 275, 276, 571, 277, 278, 279, 280, 281, 282, 772, 283, 284, -1,
  /* DiagSubGroup292 */ 290, 291, -1,
  /* DiagSubGroup294 */ 302, 303, -1,
  /* DiagSubGroup298 */ 299, -1,
  /* DiagSubGroup316 */ 317, 313, -1,
  /* DiagSubGroup322 */ 324, 450, -1,
  /* DiagSubGroup328 */ 172, -1,
  /* DiagSubGroup338 */ 337, -1,
  /* DiagSubGroup339 */ 340, -1,
  /* DiagSubGroup342 */ 289, -1,
  /* DiagSubGroup364 */ 110, -1,
  /* DiagSubGroup367 */ 83, -1,
  /* DiagSubGroup368 */ 238, 567, -1,
  /* DiagSubGroup378 */ 381, 386, 398, 384, 394, 402, 405, 390, 406, 399, 400, 404, 392, 389, 385, 403, 401, 388, 396, 395, 393, 380, 383, 407, 379, 382, 387, 325, -1,
  /* DiagSubGroup434 */ 123, 127, 166, 238, 239, 294, 329, 411, 412, 435, 438, 578, 586, 592, 595, 618, 619, 649, 681, 705, 709, 731, 766, 488, 478, 479, 523, 555, 119, 223, 755, -1,
  /* DiagSubGroup435 */ 540, 573, 584, 595, -1,
  /* DiagSubGroup436 */ 398, -1,
  /* DiagSubGroup440 */ 84, -1,
  /* DiagSubGroup446 */ 90, -1,
  /* DiagSubGroup447 */ 614, 139, 363, -1,
  /* DiagSubGroup450 */ 449, -1,
  /* DiagSubGroup467 */ 468, -1,
  /* DiagSubGroup477 */ 502, -1,
  /* DiagSubGroup482 */ 505, -1,
  /* DiagSubGroup502 */ 503, -1,
  /* DiagSubGroup524 */ 331, -1,
  /* DiagSubGroup530 */ 366, 365, 63, 610, 522, 531, 153, -1,
  /* DiagSubGroup532 */ 699, -1,
  /* DiagSubGroup538 */ 113, 81, 83, 85, 233, 250, 260, 262, 263, 264, 265, 266, 267, 269, 270, 271, 272, 273, 274, 275, 276, 277, 278, 281, 283, 284, 357, 367, 381, 382, 384, 387, 389, 394, 395, 401, 521, 764, 772, 231, 694, 582, 130, 441, 160, 194, 359, 308, 204, 208, 470, -1,
  /* DiagSubGroup550 */ 551, -1,
  /* DiagSubGroup553 */ 709, 292, 548, 550, -1,
  /* DiagSubGroup575 */ 176, -1,
  /* DiagSubGroup581 */ 79, -1,
  /* DiagSubGroup586 */ 587, -1,
  /* DiagSubGroup590 */ 591, -1,
  /* DiagSubGroup592 */ 594, 593, -1,
  /* DiagSubGroup598 */ 720, -1,
  /* DiagSubGroup600 */ 604, 605, -1,
  /* DiagSubGroup601 */ 600, 603, 606, 602, -1,
  /* DiagSubGroup603 */ 604, -1,
  /* DiagSubGroup627 */ 279, -1,
  /* DiagSubGroup654 */ 621, 201, 458, 375, 653, -1,
  /* DiagSubGroup661 */ 662, 667, 666, 669, 665, -1,
  /* DiagSubGroup662 */ 664, -1,
  /* DiagSubGroup663 */ 668, 671, 670, -1,
  /* DiagSubGroup673 */ 675, 674, 678, 679, -1,
  /* DiagSubGroup682 */ 663, -1,
  /* DiagSubGroup698 */ 547, -1,
  /* DiagSubGroup699 */ 700, -1,
  /* DiagSubGroup705 */ 623, 631, -1,
  /* DiagSubGroup712 */ 112, -1,
  /* DiagSubGroup715 */ 718, -1,
  /* DiagSubGroup716 */ 715, 717, 719, -1,
  /* DiagSubGroup731 */ 732, 737, 739, 746, 740, 741, 750, 751, 747, -1,
  /* DiagSubGroup737 */ 713, -1,
  /* DiagSubGroup742 */ 741, -1,
  /* DiagSubGroup744 */ 714, -1,
  /* DiagSubGroup749 */ 713, -1,
  /* DiagSubGroup750 */ 734, 748, 698, -1,
  /* DiagSubGroup751 */ 735, -1,
  /* DiagSubGroup760 */ 759, -1,
  /* DiagSubGroup769 */ 178, -1,
  /* DiagSubGroup770 */ 769, -1,
};

static const char DiagGroupNames[] = {
    "\000\020#pragma-messages\t#warnings\020CFString-literal\003CL4\032Indep"
    "endentClass-attribute\022NSObject-attribute\003abi\016absolute-value\024"
    "abstract-final-class\023abstract-vbase-init\007address\030address-of-pa"
    "cked-member\024address-of-temporary\020aggregate-return\003all\031alloc"
    "a-with-align-alignof\020ambiguous-delete\022ambiguous-ellipsis\017ambig"
    "uous-macro\031ambiguous-member-template\034analyzer-incompatible-plugin"
    "\025anonymous-pack-parens\003arc%arc-bridge-casts-disallowed-in-nonarc\036"
    "arc-maybe-repeated-use-of-weak\025arc-non-pod-memaccess\031arc-performS"
    "elector-leaks\030arc-repeated-use-of-weak\021arc-retain-cycles\032arc-u"
    "nsafe-retained-assign\026argument-outside-range\014array-bounds\037arra"
    "y-bounds-pointer-arithmetic\003asm\025asm-ignored-qualifier\022asm-oper"
    "and-widths\013assign-enum\006assume\013at-protocol\034atimport-in-frame"
    "work-header\020atomic-alignment\027atomic-implicit-seq-cst\026atomic-me"
    "mory-ordering\021atomic-properties*atomic-property-with-user-defined-ac"
    "cessor\035attribute-packed-for-bitfield\nattributes\033auto-disable-vpt"
    "r-sanitizer\013auto-import\022auto-storage-class\013auto-var-id\014avai"
    "lability\030avr-rtlib-linking-quirks\016backend-plugin\030backslash-new"
    "line-escape\021bad-function-cast\016binary-literal\026bind-to-temporary"
    "-copy\024binding-in-condition\034bitfield-constant-conversion\030bitfie"
    "ld-enum-conversion\016bitfield-width\026bitwise-op-parentheses\033block"
    "-capture-autoreleasing\017bool-conversion\020bool-conversions\022braced"
    "-scalar-init\013bridge-cast\027builtin-macro-redefined\027builtin-memcp"
    "y-chk-size\027builtin-requires-header\nc++-compat\014c++0x-compat\020c+"
    "+0x-extensions\017c++0x-narrowing\014c++11-compat(c++11-compat-deprecat"
    "ed-writable-strings\025c++11-compat-pedantic*c++11-compat-reserved-user"
    "-defined-literal\020c++11-extensions\020c++11-extra-semi\026c++11-inlin"
    "e-namespace\017c++11-long-long\017c++11-narrowing\024c++14-binary-liter"
    "al\014c++14-compat\025c++14-compat-pedantic\020c++14-extensions\014c++1"
    "7-compat\025c++17-compat-mangling\025c++17-compat-pedantic\020c++17-ext"
    "ensions\020c++1y-extensions\014c++1z-compat\025c++1z-compat-mangling\020"
    "c++1z-extensions\014c++2a-compat\025c++2a-compat-pedantic\020c++2a-exte"
    "nsions\036c++98-c++11-c++14-c++17-compat'c++98-c++11-c++14-c++17-compat"
    "-pedantic\030c++98-c++11-c++14-compat!c++98-c++11-c++14-compat-pedantic"
    "\022c++98-c++11-compat!c++98-c++11-compat-binary-literal\033c++98-c++11"
    "-compat-pedantic\014c++98-compat#c++98-compat-bind-to-temporary-copy\027"
    "c++98-compat-extra-semi%c++98-compat-local-type-template-args\025c++98-"
    "compat-pedantic'c++98-compat-unnamed-type-template-args\016c11-extensio"
    "ns\nc99-compat\016c99-extensions#call-to-pure-virtual-from-ctor-dtor\nc"
    "ast-align\027cast-calling-convention\020cast-of-sel-type\tcast-qual\023"
    "cast-qual-unrelated\nchar-align\017char-subscripts\014clang-cl-pch\015c"
    "lass-varargs\005comma\007comment\010comments\036compare-distinct-pointe"
    "r-types\026complex-component-init\022concepts-ts-compat\031conditional-"
    "type-mismatch\031conditional-uninitialized\015config-macros\023constant"
    "-conversion\030constant-logical-operand\023constexpr-not-const\010consu"
    "med\nconversion\017conversion-null\tcoroutine%coroutine-missing-unhandl"
    "ed-exception\026covered-switch-default\003cpp\030cstring-format-directi"
    "ve\026ctad-maybe-unsupported\021ctor-dtor-privacy\003ctu\013cuda-compat"
    "\020cuda-shared-init\030custom-atomic-properties\010dangling\015danglin"
    "g-else\016dangling-field\031dangling-initializer-list\023darwin-sdk-set"
    "tings\tdate-time\023dealloc-in-category\035debug-compression-unavailabl"
    "e\033declaration-after-statement\032defaulted-function-deleted\026deleg"
    "ating-ctor-cycles delete-abstract-non-virtual-dtor\021delete-incomplete"
    "$delete-non-abstract-non-virtual-dtor\027delete-non-virtual-dtor\ndepre"
    "cated\025deprecated-attributes\027deprecated-declarations!deprecated-dy"
    "namic-exception-spec\032deprecated-implementations\031deprecated-increm"
    "ent-bool\031deprecated-objc-isa-usage%deprecated-objc-pointer-introspec"
    "tion5deprecated-objc-pointer-introspection-performSelector\023deprecate"
    "d-register\027deprecated-this-capture\033deprecated-writable-strings\022"
    "direct-ivar-access\030disabled-macro-expansion\025disabled-optimization"
    "\014discard-qual\034distributed-object-modifiers\013div-by-zero\020divi"
    "sion-by-zero\036dll-attribute-on-redeclaration%dllexport-explicit-insta"
    "ntiation-decl\032dllimport-static-field-def\015documentation\035documen"
    "tation-deprecated-sync\022documentation-html\026documentation-pedantic\035"
    "documentation-unknown-command\036dollar-in-identifier-extension\020doub"
    "le-promotion\030duplicate-decl-specifier\016duplicate-enum\024duplicate"
    "-method-arg\026duplicate-method-match\022duplicate-protocol\027dynamic-"
    "class-memaccess\026dynamic-exception-spec\006effc++\022embedded-directi"
    "ve\nempty-body\023empty-decomposition\017empty-init-stmt\026empty-trans"
    "lation-unit\013encode-type\014endif-labels\014enum-compare\023enum-comp"
    "are-switch\017enum-conversion\016enum-too-large\nexceptions\025exit-tim"
    "e-destructors\024expansion-to-defined\021experimental-isel\030explicit-"
    "initialize-call\027explicit-ownership-type\016export-unnamed\026export-"
    "using-directive\017extern-c-compat\022extern-initializer\005extra\023ex"
    "tra-qualification\nextra-semi\017extra-semi-stmt\014extra-tokens\010fal"
    "lback\024fixed-enum-extension\tflag-enum\031flexible-array-extensions\020"
    "float-conversion\013float-equal\031float-overflow-conversion\025float-z"
    "ero-conversion\021for-loop-analysis\006format\021format-extra-args\030f"
    "ormat-invalid-specifier\016format-non-iso\021format-nonliteral\017forma"
    "t-pedantic\017format-security\nformat-y2k\022format-zero-length\010form"
    "at=2\016fortify-source\023four-char-constants\022frame-larger-than=%fra"
    "mework-include-private-from-public\036function-def-in-objc-container\025"
    "function-multiversion\015future-compat\ngcc-compat\023global-constructo"
    "rs\003gnu\026gnu-alignof-expression\024gnu-anonymous-struct\033gnu-arra"
    "y-member-paren-init\015gnu-auto-type\022gnu-binary-literal\016gnu-case-"
    "range\023gnu-complex-integer gnu-compound-literal-initializer\037gnu-co"
    "nditional-omitted-operand\016gnu-designator\025gnu-empty-initializer\020"
    "gnu-empty-struct\036gnu-flexible-array-initializer\037gnu-flexible-arra"
    "y-union-member\024gnu-folding-constant\026gnu-imaginary-constant\020gnu"
    "-include-next\022gnu-label-as-value\023gnu-redeclared-enum\030gnu-state"
    "ment-expression\025gnu-static-float-init$gnu-string-literal-operator-te"
    "mplate\016gnu-union-cast\"gnu-variable-sized-type-not-at-end\027gnu-zer"
    "o-line-directive!gnu-zero-variadic-macro-arguments\014header-guard\016h"
    "eader-hygiene\025idiomatic-parentheses\022ignored-attributes\035ignored"
    "-optimization-argument\030ignored-pragma-intrinsic\027ignored-pragma-op"
    "timize\017ignored-pragmas\022ignored-qualifiers\010implicit\032implicit"
    "-atomic-properties*implicit-conversion-floating-point-to-bool implicit-"
    "exception-spec-mismatch\024implicit-fallthrough!implicit-fallthrough-pe"
    "r-function\037implicit-fixed-point-conversion\031implicit-float-convers"
    "ion\035implicit-function-declaration\014implicit-int\027implicit-int-co"
    "nversion\024implicit-retain-self\033implicitly-unsigned-literal\006impo"
    "rt&import-preprocessor-directive-pedantic\021inaccessible-base\032inclu"
    "de-next-absolute-path\033include-next-outside-header\033incompatible-ex"
    "ception-spec#incompatible-function-pointer-types\"incompatible-library-"
    "redeclaration\026incompatible-ms-struct\032incompatible-pointer-types.i"
    "ncompatible-pointer-types-discards-qualifiers\032incompatible-property-"
    "type\024incompatible-sysroot'incomplete-framework-module-declaration\031"
    "incomplete-implementation\021incomplete-module\035incomplete-setjmp-dec"
    "laration\023incomplete-umbrella\026inconsistent-dllimport(inconsistent-"
    "missing-destructor-override\035inconsistent-missing-override\016increme"
    "nt-bool\022infinite-recursion\tinit-self\025initializer-overrides\023in"
    "jected-class-name\006inline\ninline-asm\021inline-new-delete\"instantia"
    "tion-after-specialization\016int-conversion\017int-conversions\023int-t"
    "o-pointer-cast\030int-to-void-pointer-cast\020integer-overflow\035inval"
    "id-command-line-argument\021invalid-constexpr\020invalid-iboutlet&inval"
    "id-initializer-from-system-header\035invalid-ios-deployment-target\020i"
    "nvalid-noreturn\020invalid-offsetof invalid-or-nonexistent-directory\036"
    "invalid-partial-specialization\013invalid-pch\020invalid-pp-token\027in"
    "valid-source-encoding\023invalid-token-paste\020jump-seh-finally\016key"
    "word-compat\015keyword-macro\026knr-promoted-parameter\030language-exte"
    "nsion-token\023large-by-value-copy\006liblto\022literal-conversion\015l"
    "iteral-range\030local-type-template-args\027logical-not-parentheses\026"
    "logical-op-parentheses\tlong-long\015loop-analysis\017macro-redefined\004"
    "main\020main-return-type\027malformed-warning-check\036many-braces-arou"
    "nd-scalar-init\021max-unsigned-zero\026memset-transposed-args\022memsiz"
    "e-comparison\021method-signatures\tmicrosoft\022microsoft-anon-tag\016m"
    "icrosoft-cast\021microsoft-charize\027microsoft-comment-paste\024micros"
    "oft-const-init\023microsoft-cpp-macro\"microsoft-default-arg-redefiniti"
    "on\031microsoft-drectve-section\025microsoft-end-of-file microsoft-enum"
    "-forward-reference\024microsoft-enum-value\030microsoft-exception-spec\020"
    "microsoft-exists#microsoft-explicit-constructor-call\035microsoft-extra"
    "-qualification\024microsoft-fixed-enum\030microsoft-flexible-array\016m"
    "icrosoft-goto\033microsoft-inaccessible-base\021microsoft-include\033mi"
    "crosoft-mutable-reference\031microsoft-pure-definition\032microsoft-red"
    "eclare-static\020microsoft-sealed\022microsoft-template microsoft-union"
    "-member-reference\034microsoft-unqualified-friend\024microsoft-using-de"
    "cl\032microsoft-void-pseudo-dtor\025mismatched-new-delete\032mismatched"
    "-parameter-types\027mismatched-return-types\017mismatched-tags\016missi"
    "ng-braces\024missing-declarations\026missing-exception-spec\032missing-"
    "field-initializers\030missing-format-attribute\024missing-include-dirs\032"
    "missing-method-return-type\020missing-noescape\020missing-noreturn\030m"
    "issing-prototype-for-cc\022missing-prototypes\025missing-selector-name\017"
    "missing-sysroot\035missing-variable-declarations\014module-build\017mod"
    "ule-conflict\033module-file-config-mismatch\025module-file-extension\015"
    "module-import\031module-import-in-extern-c\"modules-ambiguous-internal-"
    "linkage\037modules-import-nested-redundant\004most\004move\014msvc-incl"
    "ude\016msvc-not-found\tmultichar\023multiple-move-vbase\tnarrowing\021n"
    "ested-anon-types\016nested-externs\020new-returns-null\013newline-eof\007"
    "noderef\015noexcept-type\007non-gcc\033non-literal-null-conversion'non-"
    "modular-include-in-framework-module\035non-modular-include-in-module\017"
    "non-pod-varargs\020non-virtual-dtor\007nonnull\025nonportable-cfstrings"
    "\030nonportable-include-path\037nonportable-system-include-path!nonport"
    "able-vector-initialization\024nontrivial-memaccess\023nsconsumed-mismat"
    "ch\022nsreturns-mismatch\017null-arithmetic\016null-character\017null-c"
    "onversion\020null-dereference\027null-pointer-arithmetic\013nullability"
    "\030nullability-completeness\"nullability-completeness-on-arrays\024nul"
    "lability-declspec\025nullability-extension#nullability-inferred-on-nest"
    "ed-type\036nullable-to-nonnull-conversion+objc-autosynthesis-property-i"
    "var-name-match\035objc-bool-constant-conversion\013objc-boxing\027objc-"
    "circular-container\016objc-cocoa-api\034objc-designated-initializers\023"
    "objc-flexible-array\037objc-forward-class-redefinition\024objc-interfac"
    "e-ivars\024objc-literal-compare\027objc-literal-conversion\027objc-macr"
    "o-redefinition\021objc-messaging-id\022objc-method-access\037objc-missi"
    "ng-property-synthesis\030objc-missing-super-calls\032objc-multiple-meth"
    "od-names\"objc-noncopy-retain-block-property\032objc-nonunified-excepti"
    "ons#objc-property-assign-on-object-type\034objc-property-implementation"
    "\037objc-property-implicit-mismatch*objc-property-matches-cocoa-ownersh"
    "ip-rule\032objc-property-no-attribute\027objc-property-synthesis#objc-p"
    "rotocol-method-implementation objc-protocol-property-synthesis\030objc-"
    "protocol-qualifiers\"objc-readonly-with-setter-property\026objc-redunda"
    "nt-api-use\032objc-redundant-literal-use\017objc-root-class\023objc-str"
    "ing-compare\031objc-string-concatenation\034objc-unsafe-perform-selecto"
    "r\003odr\016old-style-cast\024old-style-definition\027opencl-unsupporte"
    "d-rgba\016openmp-clauses\020openmp-loop-form\015openmp-target\016option"
    "-ignored!ordered-compare-function-pointers\027out-of-line-declaration\025"
    "out-of-scope-function\014over-aligned\010overflow\022overlength-strings"
    "\037overloaded-shift-op-parentheses\022overloaded-virtual\015override-i"
    "nit\017override-module\032overriding-method-mismatch\023overriding-t-op"
    "tion\006packed\006padded\013parentheses\024parentheses-equality\024part"
    "ial-availability\004pass\015pass-analysis\013pass-failed\013pass-missed"
    "\015pch-date-time\010pedantic\026pedantic-core-features\020pessimizing-"
    "move\015pointer-arith\027pointer-bool-conversion\027pointer-integer-com"
    "pare\014pointer-sign\023pointer-to-int-cast\025pointer-type-mismatch po"
    "tentially-evaluated-expression\026pragma-clang-attribute\032pragma-once"
    "-outside-header\013pragma-pack\036pragma-pack-suspicious-include#pragma"
    "-system-header-outside-header\007pragmas&predefined-identifier-outside-"
    "function\016private-extern\016private-header\016private-module\025profi"
    "le-instr-missing\031profile-instr-out-of-date\030profile-instr-unprofil"
    "ed\032property-access-dot-syntax\033property-attribute-mismatch\010prot"
    "ocol%protocol-property-synthesis-ambiguity\032qualified-void-return-typ"
    "e\"quoted-include-in-framework-header\023range-loop-analysis\032readonl"
    "y-iboutlet-property\015receiver-expr\026receiver-forward-class\027redec"
    "lared-class-member\017redundant-decls\016redundant-move\020redundant-pa"
    "rens\010register\026reinterpret-base-class\025remark-backend-plugin\007"
    "reorder\030requires-super-attribute\021reserved-id-macro\035reserved-us"
    "er-defined-literal\031retained-language-linkage\024return-stack-address"
    "\017return-std-move\030return-std-move-in-c++11\013return-type\025retur"
    "n-type-c-linkage\020sanitize-address\007section\010selector\026selector"
    "-type-mismatch\013self-assign\021self-assign-field\026self-assign-overl"
    "oaded\tself-move\034semicolon-before-method-body\010sentinel\016sequenc"
    "e-point\026serialized-diagnostics\006shadow\nshadow-all\014shadow-field"
    "\033shadow-field-in-constructor$shadow-field-in-constructor-modified\013"
    "shadow-ivar\027shadow-uncaptured-local\024shift-count-negative\024shift"
    "-count-overflow\024shift-negative-value\024shift-op-parentheses\016shif"
    "t-overflow\023shift-sign-overflow\020shorten-64-to-32\014sign-compare\017"
    "sign-conversion\nsign-promo\024signed-enum-bitfield\025sizeof-array-arg"
    "ument\022sizeof-array-decay\022sizeof-pointer-div\030sizeof-pointer-mem"
    "access\020slash-u-filename\027sometimes-uninitialized\022source-uses-op"
    "enmp\013spir-compat\017stack-protector\021static-float-init\020static-i"
    "n-inline$static-inline-explicit-instantiation\026static-local-in-inline"
    "\020static-self-init\023stdlibcxx-not-found\017strict-aliasing\021stric"
    "t-aliasing=0\021strict-aliasing=1\021strict-aliasing=2\017strict-overfl"
    "ow\021strict-overflow=0\021strict-overflow=1\021strict-overflow=2\021st"
    "rict-overflow=3\021strict-overflow=4\021strict-overflow=5\021strict-pro"
    "totypes\025strict-selector-match\016string-compare\021string-conversion"
    "\020string-plus-char\017string-plus-int\024strlcpy-strlcat-size\014strn"
    "cat-size\033super-class-method-mismatch\020suspicious-bzero\024suspicio"
    "us-memaccess\006switch\013switch-bool\016switch-default\013switch-enum%"
    "sync-fetch-and-nand-semantics-changed\005synth\024tautological-compare\035"
    "tautological-constant-compare&tautological-constant-in-range-compare*ta"
    "utological-constant-out-of-range-compare\036tautological-objc-bool-comp"
    "are\034tautological-overlap-compare\034tautological-pointer-compare\037"
    "tautological-type-limit-compare\036tautological-undefined-compare'tauto"
    "logical-unsigned-enum-zero-compare\"tautological-unsigned-zero-compare$"
    "tentative-definition-incomplete-type\015thread-safety\026thread-safety-"
    "analysis\030thread-safety-attributes\022thread-safety-beta\026thread-sa"
    "fety-negative\025thread-safety-precise\027thread-safety-reference\025th"
    "read-safety-verbose\ttrigraphs\013type-limits\013type-safety\024typedef"
    "-redefinition\020typename-missing\031unable-to-open-stats-file\030unava"
    "ilable-declarations\023undeclared-selector\005undef\031undefined-bool-c"
    "onversion\027undefined-func-template\020undefined-inline\022undefined-i"
    "nternal\027undefined-internal-type\032undefined-reinterpret-cast\026und"
    "efined-var-template\035underaligned-exception-object\026unevaluated-exp"
    "ression\026unguarded-availability\032unguarded-availability-new\007unic"
    "ode\021unicode-homoglyph\022unicode-whitespace\022unicode-zero-width\015"
    "uninitialized\020unknown-argument\022unknown-attributes\027unknown-esca"
    "pe-sequence\017unknown-pragmas\022unknown-sanitizers\026unknown-warning"
    "-option\032unnamed-type-template-args\035unneeded-internal-declaration\030"
    "unneeded-member-function\020unreachable-code\033unreachable-code-aggres"
    "sive\026unreachable-code-break\037unreachable-code-loop-increment\027un"
    "reachable-code-return\013unsequenced\017unsupported-abs\036unsupported-"
    "availability-guard\016unsupported-cb#unsupported-dll-base-class-templat"
    "e\022unsupported-friend\021unsupported-gpopt\017unsupported-nan\026unsu"
    "pported-target-opt\026unsupported-visibility\037unusable-partial-specia"
    "lization\006unused\017unused-argument\034unused-command-line-argument\021"
    "unused-comparison\025unused-const-variable\032unused-exception-paramete"
    "r\017unused-function\032unused-getter-return-value\014unused-label\025u"
    "nused-lambda-capture\024unused-local-typedef\025unused-local-typedefs\015"
    "unused-macros\026unused-member-function\020unused-parameter\024unused-p"
    "rivate-field\024unused-property-ivar\015unused-result\017unused-templat"
    "e\014unused-value\017unused-variable\026unused-volatile-lvalue\026used-"
    "but-marked-unused\025user-defined-literals\025user-defined-warnings\007"
    "varargs\017variadic-macros\015vec-elem-size\021vector-conversion\022vec"
    "tor-conversions\014vexing-parse\nvisibility\003vla\015vla-extension\024"
    "void-ptr-dereference\025volatile-register-var\025weak-template-vtables\014"
    "weak-vtables\020writable-strings\015write-strings\035zero-as-null-point"
    "er-constant\021zero-length-array"};

#endif // GET_DIAG_ARRAYS


#ifdef GET_DIAG_TABLE
  { /*  */                                                      0, /* Empty */     0, /* DiagSubGroup0 */ 1 },
  { /* #pragma-messages */                                      1, /* DiagArray1 */ 1, /* Empty */         0 },
  { /* #warnings */                                             18, /* DiagArray2 */ 3, /* Empty */         0 },
  { /* CFString-literal */                                      28, /* DiagArray3 */ 5, /* Empty */         0 },
  { /* CL4 */                                                   45, /* Empty */     0, /* DiagSubGroup4 */ 3 },
  { /* IndependentClass-attribute */                            49, /* DiagArray5 */ 7, /* Empty */         0 },
  { /* NSObject-attribute */                                    76, /* DiagArray6 */ 10, /* Empty */         0 },
  { /* abi */                                                   95, /* Empty */     0, /* Empty */         0 },
  { /* absolute-value */                                        99, /* DiagArray8 */ 12, /* Empty */         0 },
  { /* abstract-final-class */                                  114, /* DiagArray9 */ 17, /* Empty */         0 },
  { /* abstract-vbase-init */                                   135, /* DiagArray10 */ 19, /* Empty */         0 },
  { /* address */                                               155, /* Empty */     0, /* DiagSubGroup11 */ 6 },
  { /* address-of-packed-member */                              163, /* DiagArray12 */ 21, /* Empty */         0 },
  { /* address-of-temporary */                                  188, /* DiagArray13 */ 23, /* Empty */         0 },
  { /* aggregate-return */                                      209, /* Empty */     0, /* Empty */         0 },
  { /* all */                                                   226, /* Empty */     0, /* DiagSubGroup15 */ 10 },
  { /* alloca-with-align-alignof */                             230, /* DiagArray16 */ 25, /* Empty */         0 },
  { /* ambiguous-delete */                                      256, /* DiagArray17 */ 27, /* Empty */         0 },
  { /* ambiguous-ellipsis */                                    273, /* DiagArray18 */ 29, /* Empty */         0 },
  { /* ambiguous-macro */                                       292, /* DiagArray19 */ 31, /* Empty */         0 },
  { /* ambiguous-member-template */                             308, /* DiagArray20 */ 33, /* Empty */         0 },
  { /* analyzer-incompatible-plugin */                          334, /* DiagArray21 */ 35, /* Empty */         0 },
  { /* anonymous-pack-parens */                                 363, /* DiagArray22 */ 37, /* Empty */         0 },
  { /* arc */                                                   385, /* Empty */     0, /* DiagSubGroup23 */ 15 },
  { /* arc-bridge-casts-disallowed-in-nonarc */                 389, /* DiagArray24 */ 39, /* Empty */         0 },
  { /* arc-maybe-repeated-use-of-weak */                        427, /* DiagArray25 */ 41, /* Empty */         0 },
  { /* arc-non-pod-memaccess */                                 458, /* DiagArray26 */ 43, /* Empty */         0 },
  { /* arc-performSelector-leaks */                             480, /* DiagArray27 */ 45, /* Empty */         0 },
  { /* arc-repeated-use-of-weak */                              506, /* DiagArray28 */ 47, /* DiagSubGroup28 */ 19 },
  { /* arc-retain-cycles */                                     531, /* DiagArray29 */ 49, /* Empty */         0 },
  { /* arc-unsafe-retained-assign */                            549, /* DiagArray30 */ 51, /* Empty */         0 },
  { /* argument-outside-range */                                576, /* DiagArray31 */ 55, /* Empty */         0 },
  { /* array-bounds */                                          599, /* DiagArray32 */ 57, /* Empty */         0 },
  { /* array-bounds-pointer-arithmetic */                       612, /* DiagArray33 */ 62, /* Empty */         0 },
  { /* asm */                                                   644, /* Empty */     0, /* DiagSubGroup34 */ 21 },
  { /* asm-ignored-qualifier */                                 648, /* DiagArray35 */ 65, /* Empty */         0 },
  { /* asm-operand-widths */                                    670, /* DiagArray36 */ 68, /* Empty */         0 },
  { /* assign-enum */                                           689, /* DiagArray37 */ 70, /* Empty */         0 },
  { /* assume */                                                701, /* DiagArray38 */ 72, /* Empty */         0 },
  { /* at-protocol */                                           708, /* Empty */     0, /* Empty */         0 },
  { /* atimport-in-framework-header */                          720, /* DiagArray40 */ 74, /* Empty */         0 },
  { /* atomic-alignment */                                      749, /* DiagArray41 */ 76, /* Empty */         0 },
  { /* atomic-implicit-seq-cst */                               766, /* DiagArray42 */ 78, /* Empty */         0 },
  { /* atomic-memory-ordering */                                790, /* DiagArray43 */ 80, /* Empty */         0 },
  { /* atomic-properties */                                     813, /* Empty */     0, /* DiagSubGroup44 */ 24 },
  { /* atomic-property-with-user-defined-accessor */            831, /* DiagArray45 */ 82, /* Empty */         0 },
  { /* attribute-packed-for-bitfield */                         874, /* DiagArray46 */ 84, /* Empty */         0 },
  { /* attributes */                                            904, /* Empty */     0, /* DiagSubGroup47 */ 27 },
  { /* auto-disable-vptr-sanitizer */                           915, /* DiagArray48 */ 86, /* Empty */         0 },
  { /* auto-import */                                           943, /* DiagArray49 */ 88, /* Empty */         0 },
  { /* auto-storage-class */                                    955, /* DiagArray50 */ 90, /* Empty */         0 },
  { /* auto-var-id */                                           974, /* DiagArray51 */ 92, /* Empty */         0 },
  { /* availability */                                          986, /* DiagArray52 */ 94, /* Empty */         0 },
  { /* avr-rtlib-linking-quirks */                              999, /* DiagArray53 */ 104, /* Empty */         0 },
  { /* backend-plugin */                                        1024, /* DiagArray54 */ 110, /* Empty */         0 },
  { /* backslash-newline-escape */                              1039, /* DiagArray55 */ 112, /* Empty */         0 },
  { /* bad-function-cast */                                     1064, /* DiagArray56 */ 114, /* Empty */         0 },
  { /* binary-literal */                                        1082, /* Empty */     0, /* DiagSubGroup57 */ 30 },
  { /* bind-to-temporary-copy */                                1097, /* DiagArray58 */ 116, /* DiagSubGroup58 */ 34 },
  { /* binding-in-condition */                                  1120, /* DiagArray59 */ 119, /* Empty */         0 },
  { /* bitfield-constant-conversion */                          1141, /* DiagArray60 */ 121, /* Empty */         0 },
  { /* bitfield-enum-conversion */                              1170, /* DiagArray61 */ 123, /* Empty */         0 },
  { /* bitfield-width */                                        1195, /* DiagArray62 */ 127, /* Empty */         0 },
  { /* bitwise-op-parentheses */                                1210, /* DiagArray63 */ 130, /* Empty */         0 },
  { /* block-capture-autoreleasing */                           1233, /* DiagArray64 */ 132, /* Empty */         0 },
  { /* bool-conversion */                                       1261, /* DiagArray65 */ 134, /* DiagSubGroup65 */ 36 },
  { /* bool-conversions */                                      1277, /* Empty */     0, /* DiagSubGroup66 */ 39 },
  { /* braced-scalar-init */                                    1294, /* DiagArray67 */ 136, /* Empty */         0 },
  { /* bridge-cast */                                           1313, /* DiagArray68 */ 138, /* Empty */         0 },
  { /* builtin-macro-redefined */                               1325, /* DiagArray69 */ 141, /* Empty */         0 },
  { /* builtin-memcpy-chk-size */                               1349, /* DiagArray70 */ 144, /* Empty */         0 },
  { /* builtin-requires-header */                               1373, /* DiagArray71 */ 146, /* Empty */         0 },
  { /* c++-compat */                                            1397, /* DiagArray72 */ 148, /* Empty */         0 },
  { /* c++0x-compat */                                          1408, /* Empty */     0, /* DiagSubGroup73 */ 41 },
  { /* c++0x-extensions */                                      1421, /* Empty */     0, /* DiagSubGroup74 */ 43 },
  { /* c++0x-narrowing */                                       1438, /* Empty */     0, /* DiagSubGroup75 */ 45 },
  { /* c++11-compat */                                          1454, /* DiagArray76 */ 150, /* DiagSubGroup76 */ 47 },
  { /* c++11-compat-deprecated-writable-strings */              1467, /* DiagArray77 */ 161, /* Empty */         0 },
  { /* c++11-compat-pedantic */                                 1508, /* Empty */     0, /* DiagSubGroup78 */ 54 },
  { /* c++11-compat-reserved-user-defined-literal */            1530, /* DiagArray79 */ 163, /* Empty */         0 },
  { /* c++11-extensions */                                      1573, /* DiagArray80 */ 165, /* DiagSubGroup80 */ 59 },
  { /* c++11-extra-semi */                                      1590, /* DiagArray81 */ 191, /* Empty */         0 },
  { /* c++11-inline-namespace */                                1607, /* DiagArray82 */ 193, /* Empty */         0 },
  { /* c++11-long-long */                                       1630, /* DiagArray83 */ 195, /* Empty */         0 },
  { /* c++11-narrowing */                                       1646, /* DiagArray84 */ 197, /* Empty */         0 },
  { /* c++14-binary-literal */                                  1662, /* DiagArray85 */ 205, /* Empty */         0 },
  { /* c++14-compat */                                          1683, /* Empty */     0, /* DiagSubGroup86 */ 63 },
  { /* c++14-compat-pedantic */                                 1696, /* Empty */     0, /* DiagSubGroup87 */ 66 },
  { /* c++14-extensions */                                      1718, /* DiagArray88 */ 207, /* DiagSubGroup88 */ 70 },
  { /* c++17-compat */                                          1735, /* Empty */     0, /* DiagSubGroup89 */ 72 },
  { /* c++17-compat-mangling */                                 1748, /* DiagArray90 */ 216, /* Empty */         0 },
  { /* c++17-compat-pedantic */                                 1770, /* Empty */     0, /* DiagSubGroup91 */ 77 },
  { /* c++17-extensions */                                      1792, /* DiagArray92 */ 218, /* Empty */         0 },
  { /* c++1y-extensions */                                      1809, /* Empty */     0, /* DiagSubGroup93 */ 80 },
  { /* c++1z-compat */                                          1826, /* Empty */     0, /* DiagSubGroup94 */ 82 },
  { /* c++1z-compat-mangling */                                 1839, /* Empty */     0, /* DiagSubGroup95 */ 84 },
  { /* c++1z-extensions */                                      1861, /* Empty */     0, /* DiagSubGroup96 */ 86 },
  { /* c++2a-compat */                                          1878, /* DiagArray97 */ 237, /* Empty */         0 },
  { /* c++2a-compat-pedantic */                                 1891, /* Empty */     0, /* DiagSubGroup98 */ 88 },
  { /* c++2a-extensions */                                      1913, /* DiagArray99 */ 244, /* Empty */         0 },
  { /* c++98-c++11-c++14-c++17-compat */                        1930, /* DiagArray100 */ 256, /* Empty */         0 },
  { /* c++98-c++11-c++14-c++17-compat-pedantic */               1961, /* DiagArray101 */ 272, /* DiagSubGroup101 */ 90 },
  { /* c++98-c++11-c++14-compat */                              2001, /* DiagArray102 */ 274, /* Empty */         0 },
  { /* c++98-c++11-c++14-compat-pedantic */                     2026, /* DiagArray103 */ 292, /* DiagSubGroup103 */ 92 },
  { /* c++98-c++11-compat */                                    2060, /* DiagArray104 */ 295, /* Empty */         0 },
  { /* c++98-c++11-compat-binary-literal */                     2079, /* DiagArray105 */ 307, /* Empty */         0 },
  { /* c++98-c++11-compat-pedantic */                           2113, /* Empty */     0, /* DiagSubGroup106 */ 94 },
  { /* c++98-compat */                                          2141, /* DiagArray107 */ 309, /* DiagSubGroup107 */ 97 },
  { /* c++98-compat-bind-to-temporary-copy */                   2154, /* DiagArray108 */ 369, /* Empty */         0 },
  { /* c++98-compat-extra-semi */                               2190, /* DiagArray109 */ 371, /* Empty */         0 },
  { /* c++98-compat-local-type-template-args */                 2214, /* DiagArray110 */ 373, /* Empty */         0 },
  { /* c++98-compat-pedantic */                                 2252, /* DiagArray111 */ 375, /* DiagSubGroup111 */ 103 },
  { /* c++98-compat-unnamed-type-template-args */               2274, /* DiagArray112 */ 385, /* Empty */         0 },
  { /* c11-extensions */                                        2314, /* DiagArray113 */ 387, /* Empty */         0 },
  { /* c99-compat */                                            2329, /* DiagArray114 */ 394, /* Empty */         0 },
  { /* c99-extensions */                                        2340, /* DiagArray115 */ 398, /* Empty */         0 },
  { /* call-to-pure-virtual-from-ctor-dtor */                   2355, /* DiagArray116 */ 409, /* Empty */         0 },
  { /* cast-align */                                            2391, /* DiagArray117 */ 411, /* Empty */         0 },
  { /* cast-calling-convention */                               2402, /* DiagArray118 */ 413, /* Empty */         0 },
  { /* cast-of-sel-type */                                      2426, /* DiagArray119 */ 415, /* Empty */         0 },
  { /* cast-qual */                                             2443, /* DiagArray120 */ 417, /* Empty */         0 },
  { /* cast-qual-unrelated */                                   2453, /* DiagArray121 */ 420, /* Empty */         0 },
  { /* char-align */                                            2473, /* Empty */     0, /* Empty */         0 },
  { /* char-subscripts */                                       2484, /* DiagArray123 */ 422, /* Empty */         0 },
  { /* clang-cl-pch */                                          2500, /* DiagArray124 */ 425, /* Empty */         0 },
  { /* class-varargs */                                         2513, /* DiagArray125 */ 431, /* DiagSubGroup125 */ 110 },
  { /* comma */                                                 2527, /* DiagArray126 */ 433, /* Empty */         0 },
  { /* comment */                                               2533, /* DiagArray127 */ 435, /* Empty */         0 },
  { /* comments */                                              2541, /* Empty */     0, /* DiagSubGroup128 */ 112 },
  { /* compare-distinct-pointer-types */                        2550, /* DiagArray129 */ 440, /* Empty */         0 },
  { /* complex-component-init */                                2581, /* DiagArray130 */ 442, /* Empty */         0 },
  { /* concepts-ts-compat */                                    2604, /* DiagArray131 */ 444, /* Empty */         0 },
  { /* conditional-type-mismatch */                             2623, /* DiagArray132 */ 446, /* Empty */         0 },
  { /* conditional-uninitialized */                             2649, /* DiagArray133 */ 448, /* Empty */         0 },
  { /* config-macros */                                         2675, /* DiagArray134 */ 450, /* Empty */         0 },
  { /* constant-conversion */                                   2689, /* DiagArray135 */ 452, /* DiagSubGroup135 */ 114 },
  { /* constant-logical-operand */                              2709, /* DiagArray136 */ 454, /* Empty */         0 },
  { /* constexpr-not-const */                                   2734, /* DiagArray137 */ 456, /* Empty */         0 },
  { /* consumed */                                              2754, /* DiagArray138 */ 458, /* Empty */         0 },
  { /* conversion */                                            2763, /* DiagArray139 */ 467, /* DiagSubGroup139 */ 117 },
  { /* conversion-null */                                       2774, /* Empty */     0, /* DiagSubGroup140 */ 133 },
  { /* coroutine */                                             2790, /* Empty */     0, /* DiagSubGroup141 */ 135 },
  { /* coroutine-missing-unhandled-exception */                 2800, /* DiagArray142 */ 473, /* Empty */         0 },
  { /* covered-switch-default */                                2838, /* DiagArray143 */ 475, /* Empty */         0 },
  { /* cpp */                                                   2861, /* Empty */     0, /* DiagSubGroup144 */ 137 },
  { /* cstring-format-directive */                              2865, /* DiagArray145 */ 477, /* Empty */         0 },
  { /* ctad-maybe-unsupported */                                2890, /* DiagArray146 */ 479, /* Empty */         0 },
  { /* ctor-dtor-privacy */                                     2913, /* Empty */     0, /* Empty */         0 },
  { /* ctu */                                                   2931, /* DiagArray148 */ 481, /* Empty */         0 },
  { /* cuda-compat */                                           2935, /* DiagArray149 */ 483, /* Empty */         0 },
  { /* cuda-shared-init */                                      2947, /* DiagArray150 */ 489, /* Empty */         0 },
  { /* custom-atomic-properties */                              2964, /* DiagArray151 */ 491, /* Empty */         0 },
  { /* dangling */                                              2989, /* DiagArray152 */ 493, /* DiagSubGroup152 */ 139 },
  { /* dangling-else */                                         2998, /* DiagArray153 */ 496, /* Empty */         0 },
  { /* dangling-field */                                        3012, /* DiagArray154 */ 498, /* Empty */         0 },
  { /* dangling-initializer-list */                             3027, /* DiagArray155 */ 503, /* Empty */         0 },
  { /* darwin-sdk-settings */                                   3053, /* DiagArray156 */ 505, /* Empty */         0 },
  { /* date-time */                                             3073, /* DiagArray157 */ 507, /* Empty */         0 },
  { /* dealloc-in-category */                                   3083, /* DiagArray158 */ 509, /* Empty */         0 },
  { /* debug-compression-unavailable */                         3103, /* DiagArray159 */ 511, /* Empty */         0 },
  { /* declaration-after-statement */                           3133, /* DiagArray160 */ 513, /* Empty */         0 },
  { /* defaulted-function-deleted */                            3161, /* DiagArray161 */ 515, /* Empty */         0 },
  { /* delegating-ctor-cycles */                                3188, /* DiagArray162 */ 517, /* Empty */         0 },
  { /* delete-abstract-non-virtual-dtor */                      3211, /* DiagArray163 */ 519, /* Empty */         0 },
  { /* delete-incomplete */                                     3244, /* DiagArray164 */ 521, /* Empty */         0 },
  { /* delete-non-abstract-non-virtual-dtor */                  3262, /* DiagArray165 */ 524, /* Empty */         0 },
  { /* delete-non-virtual-dtor */                               3299, /* Empty */     0, /* DiagSubGroup166 */ 143 },
  { /* deprecated */                                            3323, /* DiagArray167 */ 526, /* DiagSubGroup167 */ 146 },
  { /* deprecated-attributes */                                 3334, /* DiagArray168 */ 535, /* Empty */         0 },
  { /* deprecated-declarations */                               3356, /* DiagArray169 */ 537, /* Empty */         0 },
  { /* deprecated-dynamic-exception-spec */                     3380, /* DiagArray170 */ 544, /* Empty */         0 },
  { /* deprecated-implementations */                            3414, /* DiagArray171 */ 546, /* Empty */         0 },
  { /* deprecated-increment-bool */                             3441, /* DiagArray172 */ 549, /* Empty */         0 },
  { /* deprecated-objc-isa-usage */                             3467, /* DiagArray173 */ 551, /* Empty */         0 },
  { /* deprecated-objc-pointer-introspection */                 3493, /* DiagArray174 */ 554, /* DiagSubGroup174 */ 154 },
  { /* deprecated-objc-pointer-introspection-performSelector */ 3531, /* DiagArray175 */ 556, /* Empty */         0 },
  { /* deprecated-register */                                   3585, /* DiagArray176 */ 558, /* Empty */         0 },
  { /* deprecated-this-capture */                               3605, /* DiagArray177 */ 560, /* Empty */         0 },
  { /* deprecated-writable-strings */                           3629, /* Empty */     0, /* DiagSubGroup178 */ 156 },
  { /* direct-ivar-access */                                    3657, /* DiagArray179 */ 562, /* Empty */         0 },
  { /* disabled-macro-expansion */                              3676, /* DiagArray180 */ 564, /* Empty */         0 },
  { /* disabled-optimization */                                 3701, /* Empty */     0, /* Empty */         0 },
  { /* discard-qual */                                          3723, /* Empty */     0, /* Empty */         0 },
  { /* distributed-object-modifiers */                          3736, /* DiagArray183 */ 566, /* Empty */         0 },
  { /* div-by-zero */                                           3765, /* Empty */     0, /* DiagSubGroup184 */ 158 },
  { /* division-by-zero */                                      3777, /* DiagArray185 */ 569, /* Empty */         0 },
  { /* dll-attribute-on-redeclaration */                        3794, /* DiagArray186 */ 571, /* Empty */         0 },
  { /* dllexport-explicit-instantiation-decl */                 3825, /* DiagArray187 */ 573, /* Empty */         0 },
  { /* dllimport-static-field-def */                            3863, /* DiagArray188 */ 575, /* Empty */         0 },
  { /* documentation */                                         3890, /* DiagArray189 */ 577, /* DiagSubGroup189 */ 160 },
  { /* documentation-deprecated-sync */                         3904, /* DiagArray190 */ 596, /* Empty */         0 },
  { /* documentation-html */                                    3934, /* DiagArray191 */ 598, /* Empty */         0 },
  { /* documentation-pedantic */                                3953, /* DiagArray192 */ 603, /* DiagSubGroup192 */ 163 },
  { /* documentation-unknown-command */                         3976, /* DiagArray193 */ 605, /* Empty */         0 },
  { /* dollar-in-identifier-extension */                        4006, /* DiagArray194 */ 608, /* Empty */         0 },
  { /* double-promotion */                                      4037, /* DiagArray195 */ 610, /* Empty */         0 },
  { /* duplicate-decl-specifier */                              4054, /* DiagArray196 */ 612, /* Empty */         0 },
  { /* duplicate-enum */                                        4079, /* DiagArray197 */ 617, /* Empty */         0 },
  { /* duplicate-method-arg */                                  4094, /* DiagArray198 */ 619, /* Empty */         0 },
  { /* duplicate-method-match */                                4115, /* DiagArray199 */ 621, /* Empty */         0 },
  { /* duplicate-protocol */                                    4138, /* DiagArray200 */ 623, /* Empty */         0 },
  { /* dynamic-class-memaccess */                               4157, /* DiagArray201 */ 625, /* Empty */         0 },
  { /* dynamic-exception-spec */                                4181, /* DiagArray202 */ 627, /* DiagSubGroup202 */ 165 },
  { /* effc++ */                                                4204, /* Empty */     0, /* DiagSubGroup203 */ 167 },
  { /* embedded-directive */                                    4211, /* DiagArray204 */ 629, /* Empty */         0 },
  { /* empty-body */                                            4230, /* DiagArray205 */ 631, /* Empty */         0 },
  { /* empty-decomposition */                                   4241, /* DiagArray206 */ 637, /* Empty */         0 },
  { /* empty-init-stmt */                                       4261, /* DiagArray207 */ 639, /* Empty */         0 },
  { /* empty-translation-unit */                                4277, /* DiagArray208 */ 641, /* Empty */         0 },
  { /* encode-type */                                           4300, /* DiagArray209 */ 643, /* Empty */         0 },
  { /* endif-labels */                                          4312, /* Empty */     0, /* DiagSubGroup210 */ 169 },
  { /* enum-compare */                                          4325, /* DiagArray211 */ 645, /* DiagSubGroup211 */ 171 },
  { /* enum-compare-switch */                                   4338, /* DiagArray212 */ 647, /* Empty */         0 },
  { /* enum-conversion */                                       4358, /* DiagArray213 */ 649, /* Empty */         0 },
  { /* enum-too-large */                                        4374, /* DiagArray214 */ 651, /* Empty */         0 },
  { /* exceptions */                                            4389, /* DiagArray215 */ 654, /* Empty */         0 },
  { /* exit-time-destructors */                                 4400, /* DiagArray216 */ 658, /* Empty */         0 },
  { /* expansion-to-defined */                                  4422, /* DiagArray217 */ 660, /* Empty */         0 },
  { /* experimental-isel */                                     4443, /* DiagArray218 */ 663, /* Empty */         0 },
  { /* explicit-initialize-call */                              4461, /* DiagArray219 */ 666, /* Empty */         0 },
  { /* explicit-ownership-type */                               4486, /* DiagArray220 */ 669, /* Empty */         0 },
  { /* export-unnamed */                                        4510, /* DiagArray221 */ 671, /* Empty */         0 },
  { /* export-using-directive */                                4525, /* DiagArray222 */ 674, /* Empty */         0 },
  { /* extern-c-compat */                                       4548, /* DiagArray223 */ 676, /* Empty */         0 },
  { /* extern-initializer */                                    4564, /* DiagArray224 */ 678, /* Empty */         0 },
  { /* extra */                                                 4583, /* DiagArray225 */ 680, /* DiagSubGroup225 */ 173 },
  { /* extra-qualification */                                   4589, /* DiagArray226 */ 682, /* Empty */         0 },
  { /* extra-semi */                                            4609, /* DiagArray227 */ 684, /* DiagSubGroup227 */ 183 },
  { /* extra-semi-stmt */                                       4620, /* DiagArray228 */ 687, /* DiagSubGroup228 */ 186 },
  { /* extra-tokens */                                          4636, /* DiagArray229 */ 689, /* Empty */         0 },
  { /* fallback */                                              4649, /* DiagArray230 */ 692, /* Empty */         0 },
  { /* fixed-enum-extension */                                  4658, /* DiagArray231 */ 694, /* Empty */         0 },
  { /* flag-enum */                                             4679, /* DiagArray232 */ 696, /* Empty */         0 },
  { /* flexible-array-extensions */                             4689, /* DiagArray233 */ 698, /* Empty */         0 },
  { /* float-conversion */                                      4715, /* DiagArray234 */ 701, /* DiagSubGroup234 */ 188 },
  { /* float-equal */                                           4732, /* DiagArray235 */ 703, /* Empty */         0 },
  { /* float-overflow-conversion */                             4744, /* DiagArray236 */ 705, /* Empty */         0 },
  { /* float-zero-conversion */                                 4770, /* DiagArray237 */ 708, /* Empty */         0 },
  { /* for-loop-analysis */                                     4792, /* DiagArray238 */ 710, /* Empty */         0 },
  { /* format */                                                4810, /* DiagArray239 */ 713, /* DiagSubGroup239 */ 191 },
  { /* format-extra-args */                                     4817, /* DiagArray240 */ 739, /* Empty */         0 },
  { /* format-invalid-specifier */                              4835, /* DiagArray241 */ 741, /* Empty */         0 },
  { /* format-non-iso */                                        4860, /* DiagArray242 */ 743, /* Empty */         0 },
  { /* format-nonliteral */                                     4875, /* DiagArray243 */ 747, /* Empty */         0 },
  { /* format-pedantic */                                       4893, /* DiagArray244 */ 749, /* Empty */         0 },
  { /* format-security */                                       4909, /* DiagArray245 */ 752, /* Empty */         0 },
  { /* format-y2k */                                            4925, /* Empty */     0, /* Empty */         0 },
  { /* format-zero-length */                                    4936, /* DiagArray247 */ 754, /* Empty */         0 },
  { /* format=2 */                                              4955, /* Empty */     0, /* DiagSubGroup248 */ 198 },
  { /* fortify-source */                                        4964, /* DiagArray249 */ 756, /* Empty */         0 },
  { /* four-char-constants */                                   4979, /* DiagArray250 */ 759, /* Empty */         0 },
  { /* frame-larger-than= */                                    4999, /* DiagArray251 */ 761, /* Empty */         0 },
  { /* framework-include-private-from-public */                 5018, /* DiagArray252 */ 764, /* Empty */         0 },
  { /* function-def-in-objc-container */                        5056, /* DiagArray253 */ 766, /* Empty */         0 },
  { /* function-multiversion */                                 5087, /* DiagArray254 */ 768, /* Empty */         0 },
  { /* future-compat */                                         5109, /* Empty */     0, /* Empty */         0 },
  { /* gcc-compat */                                            5123, /* DiagArray256 */ 771, /* Empty */         0 },
  { /* global-constructors */                                   5134, /* DiagArray257 */ 782, /* Empty */         0 },
  { /* gnu */                                                   5154, /* Empty */     0, /* DiagSubGroup258 */ 202 },
  { /* gnu-alignof-expression */                                5158, /* DiagArray259 */ 785, /* Empty */         0 },
  { /* gnu-anonymous-struct */                                  5181, /* DiagArray260 */ 787, /* Empty */         0 },
  { /* gnu-array-member-paren-init */                           5202, /* DiagArray261 */ 789, /* Empty */         0 },
  { /* gnu-auto-type */                                         5230, /* DiagArray262 */ 791, /* Empty */         0 },
  { /* gnu-binary-literal */                                    5244, /* DiagArray263 */ 793, /* Empty */         0 },
  { /* gnu-case-range */                                        5263, /* DiagArray264 */ 795, /* Empty */         0 },
  { /* gnu-complex-integer */                                   5278, /* DiagArray265 */ 797, /* Empty */         0 },
  { /* gnu-compound-literal-initializer */                      5298, /* DiagArray266 */ 799, /* Empty */         0 },
  { /* gnu-conditional-omitted-operand */                       5331, /* DiagArray267 */ 801, /* Empty */         0 },
  { /* gnu-designator */                                        5363, /* DiagArray268 */ 803, /* Empty */         0 },
  { /* gnu-empty-initializer */                                 5378, /* DiagArray269 */ 807, /* Empty */         0 },
  { /* gnu-empty-struct */                                      5400, /* DiagArray270 */ 809, /* Empty */         0 },
  { /* gnu-flexible-array-initializer */                        5417, /* DiagArray271 */ 813, /* Empty */         0 },
  { /* gnu-flexible-array-union-member */                       5448, /* DiagArray272 */ 815, /* Empty */         0 },
  { /* gnu-folding-constant */                                  5480, /* DiagArray273 */ 817, /* Empty */         0 },
  { /* gnu-imaginary-constant */                                5501, /* DiagArray274 */ 821, /* Empty */         0 },
  { /* gnu-include-next */                                      5524, /* DiagArray275 */ 823, /* Empty */         0 },
  { /* gnu-label-as-value */                                    5541, /* DiagArray276 */ 825, /* Empty */         0 },
  { /* gnu-redeclared-enum */                                   5560, /* DiagArray277 */ 828, /* Empty */         0 },
  { /* gnu-statement-expression */                              5580, /* DiagArray278 */ 830, /* Empty */         0 },
  { /* gnu-static-float-init */                                 5605, /* DiagArray279 */ 832, /* Empty */         0 },
  { /* gnu-string-literal-operator-template */                  5627, /* DiagArray280 */ 834, /* Empty */         0 },
  { /* gnu-union-cast */                                        5664, /* DiagArray281 */ 836, /* Empty */         0 },
  { /* gnu-variable-sized-type-not-at-end */                    5679, /* DiagArray282 */ 838, /* Empty */         0 },
  { /* gnu-zero-line-directive */                               5714, /* DiagArray283 */ 840, /* Empty */         0 },
  { /* gnu-zero-variadic-macro-arguments */                     5738, /* DiagArray284 */ 842, /* Empty */         0 },
  { /* header-guard */                                          5772, /* DiagArray285 */ 845, /* Empty */         0 },
  { /* header-hygiene */                                        5785, /* DiagArray286 */ 847, /* Empty */         0 },
  { /* idiomatic-parentheses */                                 5800, /* DiagArray287 */ 849, /* Empty */         0 },
  { /* ignored-attributes */                                    5822, /* DiagArray288 */ 851, /* Empty */         0 },
  { /* ignored-optimization-argument */                         5841, /* DiagArray289 */ 914, /* Empty */         0 },
  { /* ignored-pragma-intrinsic */                              5871, /* DiagArray290 */ 917, /* Empty */         0 },
  { /* ignored-pragma-optimize */                               5896, /* DiagArray291 */ 919, /* Empty */         0 },
  { /* ignored-pragmas */                                       5920, /* DiagArray292 */ 921, /* DiagSubGroup292 */ 231 },
  { /* ignored-qualifiers */                                    5936, /* DiagArray293 */ 965, /* Empty */         0 },
  { /* implicit */                                              5955, /* Empty */     0, /* DiagSubGroup294 */ 234 },
  { /* implicit-atomic-properties */                            5964, /* DiagArray295 */ 971, /* Empty */         0 },
  { /* implicit-conversion-floating-point-to-bool */            5991, /* DiagArray296 */ 974, /* Empty */         0 },
  { /* implicit-exception-spec-mismatch */                      6034, /* DiagArray297 */ 976, /* Empty */         0 },
  { /* implicit-fallthrough */                                  6067, /* DiagArray298 */ 978, /* DiagSubGroup298 */ 237 },
  { /* implicit-fallthrough-per-function */                     6088, /* DiagArray299 */ 981, /* Empty */         0 },
  { /* implicit-fixed-point-conversion */                       6122, /* DiagArray300 */ 983, /* Empty */         0 },
  { /* implicit-float-conversion */                             6154, /* DiagArray301 */ 985, /* Empty */         0 },
  { /* implicit-function-declaration */                         6180, /* DiagArray302 */ 988, /* Empty */         0 },
  { /* implicit-int */                                          6210, /* DiagArray303 */ 993, /* Empty */         0 },
  { /* implicit-int-conversion */                               6223, /* DiagArray304 */ 995, /* Empty */         0 },
  { /* implicit-retain-self */                                  6247, /* DiagArray305 */ 998, /* Empty */         0 },
  { /* implicitly-unsigned-literal */                           6268, /* DiagArray306 */ 1000, /* Empty */         0 },
  { /* import */                                                6296, /* Empty */     0, /* Empty */         0 },
  { /* import-preprocessor-directive-pedantic */                6303, /* DiagArray308 */ 1002, /* Empty */         0 },
  { /* inaccessible-base */                                     6342, /* DiagArray309 */ 1004, /* Empty */         0 },
  { /* include-next-absolute-path */                            6360, /* DiagArray310 */ 1006, /* Empty */         0 },
  { /* include-next-outside-header */                           6387, /* DiagArray311 */ 1008, /* Empty */         0 },
  { /* incompatible-exception-spec */                           6415, /* DiagArray312 */ 1010, /* Empty */         0 },
  { /* incompatible-function-pointer-types */                   6443, /* DiagArray313 */ 1013, /* Empty */         0 },
  { /* incompatible-library-redeclaration */                    6479, /* DiagArray314 */ 1015, /* Empty */         0 },
  { /* incompatible-ms-struct */                                6514, /* DiagArray315 */ 1017, /* Empty */         0 },
  { /* incompatible-pointer-types */                            6537, /* DiagArray316 */ 1020, /* DiagSubGroup316 */ 239 },
  { /* incompatible-pointer-types-discards-qualifiers */        6564, /* DiagArray317 */ 1022, /* Empty */         0 },
  { /* incompatible-property-type */                            6611, /* DiagArray318 */ 1025, /* Empty */         0 },
  { /* incompatible-sysroot */                                  6638, /* DiagArray319 */ 1027, /* Empty */         0 },
  { /* incomplete-framework-module-declaration */               6659, /* DiagArray320 */ 1029, /* Empty */         0 },
  { /* incomplete-implementation */                             6699, /* DiagArray321 */ 1031, /* Empty */         0 },
  { /* incomplete-module */                                     6725, /* Empty */     0, /* DiagSubGroup322 */ 242 },
  { /* incomplete-setjmp-declaration */                         6743, /* DiagArray323 */ 1033, /* Empty */         0 },
  { /* incomplete-umbrella */                                   6773, /* DiagArray324 */ 1035, /* Empty */         0 },
  { /* inconsistent-dllimport */                                6793, /* DiagArray325 */ 1039, /* Empty */         0 },
  { /* inconsistent-missing-destructor-override */              6816, /* DiagArray326 */ 1042, /* Empty */         0 },
  { /* inconsistent-missing-override */                         6857, /* DiagArray327 */ 1044, /* Empty */         0 },
  { /* increment-bool */                                        6887, /* DiagArray328 */ 1046, /* DiagSubGroup328 */ 245 },
  { /* infinite-recursion */                                    6902, /* DiagArray329 */ 1048, /* Empty */         0 },
  { /* init-self */                                             6921, /* Empty */     0, /* Empty */         0 },
  { /* initializer-overrides */                                 6931, /* DiagArray331 */ 1050, /* Empty */         0 },
  { /* injected-class-name */                                   6953, /* DiagArray332 */ 1053, /* Empty */         0 },
  { /* inline */                                                6973, /* Empty */     0, /* Empty */         0 },
  { /* inline-asm */                                            6980, /* DiagArray334 */ 1055, /* Empty */         0 },
  { /* inline-new-delete */                                     6991, /* DiagArray335 */ 1057, /* Empty */         0 },
  { /* instantiation-after-specialization */                    7009, /* DiagArray336 */ 1059, /* Empty */         0 },
  { /* int-conversion */                                        7044, /* DiagArray337 */ 1061, /* Empty */         0 },
  { /* int-conversions */                                       7059, /* Empty */     0, /* DiagSubGroup338 */ 247 },
  { /* int-to-pointer-cast */                                   7075, /* DiagArray339 */ 1064, /* DiagSubGroup339 */ 249 },
  { /* int-to-void-pointer-cast */                              7095, /* DiagArray340 */ 1066, /* Empty */         0 },
  { /* integer-overflow */                                      7120, /* DiagArray341 */ 1068, /* Empty */         0 },
  { /* invalid-command-line-argument */                         7137, /* DiagArray342 */ 1070, /* DiagSubGroup342 */ 251 },
  { /* invalid-constexpr */                                     7167, /* DiagArray343 */ 1076, /* Empty */         0 },
  { /* invalid-iboutlet */                                      7185, /* DiagArray344 */ 1078, /* Empty */         0 },
  { /* invalid-initializer-from-system-header */                7202, /* DiagArray345 */ 1081, /* Empty */         0 },
  { /* invalid-ios-deployment-target */                         7241, /* DiagArray346 */ 1083, /* Empty */         0 },
  { /* invalid-noreturn */                                      7271, /* DiagArray347 */ 1085, /* Empty */         0 },
  { /* invalid-offsetof */                                      7288, /* DiagArray348 */ 1088, /* Empty */         0 },
  { /* invalid-or-nonexistent-directory */                      7305, /* DiagArray349 */ 1091, /* Empty */         0 },
  { /* invalid-partial-specialization */                        7338, /* DiagArray350 */ 1094, /* Empty */         0 },
  { /* invalid-pch */                                           7369, /* Empty */     0, /* Empty */         0 },
  { /* invalid-pp-token */                                      7381, /* DiagArray352 */ 1096, /* Empty */         0 },
  { /* invalid-source-encoding */                               7398, /* DiagArray353 */ 1099, /* Empty */         0 },
  { /* invalid-token-paste */                                   7422, /* DiagArray354 */ 1102, /* Empty */         0 },
  { /* jump-seh-finally */                                      7442, /* DiagArray355 */ 1104, /* Empty */         0 },
  { /* keyword-compat */                                        7459, /* DiagArray356 */ 1106, /* Empty */         0 },
  { /* keyword-macro */                                         7474, /* DiagArray357 */ 1108, /* Empty */         0 },
  { /* knr-promoted-parameter */                                7488, /* DiagArray358 */ 1110, /* Empty */         0 },
  { /* language-extension-token */                              7511, /* DiagArray359 */ 1112, /* Empty */         0 },
  { /* large-by-value-copy */                                   7536, /* DiagArray360 */ 1114, /* Empty */         0 },
  { /* liblto */                                                7556, /* Empty */     0, /* Empty */         0 },
  { /* literal-conversion */                                    7563, /* DiagArray362 */ 1117, /* Empty */         0 },
  { /* literal-range */                                         7582, /* DiagArray363 */ 1120, /* Empty */         0 },
  { /* local-type-template-args */                              7596, /* DiagArray364 */ 1123, /* DiagSubGroup364 */ 253 },
  { /* logical-not-parentheses */                               7621, /* DiagArray365 */ 1125, /* Empty */         0 },
  { /* logical-op-parentheses */                                7645, /* DiagArray366 */ 1127, /* Empty */         0 },
  { /* long-long */                                             7668, /* DiagArray367 */ 1129, /* DiagSubGroup367 */ 255 },
  { /* loop-analysis */                                         7678, /* Empty */     0, /* DiagSubGroup368 */ 257 },
  { /* macro-redefined */                                       7692, /* DiagArray369 */ 1131, /* Empty */         0 },
  { /* main */                                                  7708, /* DiagArray370 */ 1133, /* Empty */         0 },
  { /* main-return-type */                                      7713, /* DiagArray371 */ 1141, /* Empty */         0 },
  { /* malformed-warning-check */                               7730, /* DiagArray372 */ 1143, /* Empty */         0 },
  { /* many-braces-around-scalar-init */                        7754, /* DiagArray373 */ 1145, /* Empty */         0 },
  { /* max-unsigned-zero */                                     7785, /* DiagArray374 */ 1147, /* Empty */         0 },
  { /* memset-transposed-args */                                7803, /* DiagArray375 */ 1149, /* Empty */         0 },
  { /* memsize-comparison */                                    7826, /* DiagArray376 */ 1151, /* Empty */         0 },
  { /* method-signatures */                                     7845, /* DiagArray377 */ 1153, /* Empty */         0 },
  { /* microsoft */                                             7863, /* Empty */     0, /* DiagSubGroup378 */ 260 },
  { /* microsoft-anon-tag */                                    7873, /* DiagArray379 */ 1156, /* Empty */         0 },
  { /* microsoft-cast */                                        7892, /* DiagArray380 */ 1159, /* Empty */         0 },
  { /* microsoft-charize */                                     7907, /* DiagArray381 */ 1162, /* Empty */         0 },
  { /* microsoft-comment-paste */                               7925, /* DiagArray382 */ 1164, /* Empty */         0 },
  { /* microsoft-const-init */                                  7949, /* DiagArray383 */ 1166, /* Empty */         0 },
  { /* microsoft-cpp-macro */                                   7970, /* DiagArray384 */ 1168, /* Empty */         0 },
  { /* microsoft-default-arg-redefinition */                    7990, /* DiagArray385 */ 1170, /* Empty */         0 },
  { /* microsoft-drectve-section */                             8025, /* DiagArray386 */ 1172, /* Empty */         0 },
  { /* microsoft-end-of-file */                                 8051, /* DiagArray387 */ 1174, /* Empty */         0 },
  { /* microsoft-enum-forward-reference */                      8073, /* DiagArray388 */ 1176, /* Empty */         0 },
  { /* microsoft-enum-value */                                  8106, /* DiagArray389 */ 1178, /* Empty */         0 },
  { /* microsoft-exception-spec */                              8127, /* DiagArray390 */ 1180, /* Empty */         0 },
  { /* microsoft-exists */                                      8152, /* DiagArray391 */ 1187, /* Empty */         0 },
  { /* microsoft-explicit-constructor-call */                   8169, /* DiagArray392 */ 1189, /* Empty */         0 },
  { /* microsoft-extra-qualification */                         8205, /* DiagArray393 */ 1191, /* Empty */         0 },
  { /* microsoft-fixed-enum */                                  8235, /* DiagArray394 */ 1193, /* Empty */         0 },
  { /* microsoft-flexible-array */                              8256, /* DiagArray395 */ 1195, /* Empty */         0 },
  { /* microsoft-goto */                                        8281, /* DiagArray396 */ 1198, /* Empty */         0 },
  { /* microsoft-inaccessible-base */                           8296, /* DiagArray397 */ 1200, /* Empty */         0 },
  { /* microsoft-include */                                     8324, /* DiagArray398 */ 1202, /* Empty */         0 },
  { /* microsoft-mutable-reference */                           8342, /* DiagArray399 */ 1204, /* Empty */         0 },
  { /* microsoft-pure-definition */                             8370, /* DiagArray400 */ 1206, /* Empty */         0 },
  { /* microsoft-redeclare-static */                            8396, /* DiagArray401 */ 1208, /* Empty */         0 },
  { /* microsoft-sealed */                                      8423, /* DiagArray402 */ 1210, /* Empty */         0 },
  { /* microsoft-template */                                    8440, /* DiagArray403 */ 1212, /* Empty */         0 },
  { /* microsoft-union-member-reference */                      8459, /* DiagArray404 */ 1221, /* Empty */         0 },
  { /* microsoft-unqualified-friend */                          8492, /* DiagArray405 */ 1223, /* Empty */         0 },
  { /* microsoft-using-decl */                                  8521, /* DiagArray406 */ 1225, /* Empty */         0 },
  { /* microsoft-void-pseudo-dtor */                            8542, /* DiagArray407 */ 1227, /* Empty */         0 },
  { /* mismatched-new-delete */                                 8569, /* DiagArray408 */ 1229, /* Empty */         0 },
  { /* mismatched-parameter-types */                            8591, /* DiagArray409 */ 1231, /* Empty */         0 },
  { /* mismatched-return-types */                               8618, /* DiagArray410 */ 1233, /* Empty */         0 },
  { /* mismatched-tags */                                       8642, /* DiagArray411 */ 1235, /* Empty */         0 },
  { /* missing-braces */                                        8658, /* DiagArray412 */ 1238, /* Empty */         0 },
  { /* missing-declarations */                                  8673, /* DiagArray413 */ 1240, /* Empty */         0 },
  { /* missing-exception-spec */                                8694, /* DiagArray414 */ 1245, /* Empty */         0 },
  { /* missing-field-initializers */                            8717, /* DiagArray415 */ 1247, /* Empty */         0 },
  { /* missing-format-attribute */                              8744, /* Empty */     0, /* Empty */         0 },
  { /* missing-include-dirs */                                  8769, /* Empty */     0, /* Empty */         0 },
  { /* missing-method-return-type */                            8790, /* DiagArray418 */ 1249, /* Empty */         0 },
  { /* missing-noescape */                                      8817, /* DiagArray419 */ 1251, /* Empty */         0 },
  { /* missing-noreturn */                                      8834, /* DiagArray420 */ 1253, /* Empty */         0 },
  { /* missing-prototype-for-cc */                              8851, /* DiagArray421 */ 1256, /* Empty */         0 },
  { /* missing-prototypes */                                    8876, /* DiagArray422 */ 1258, /* Empty */         0 },
  { /* missing-selector-name */                                 8895, /* DiagArray423 */ 1260, /* Empty */         0 },
  { /* missing-sysroot */                                       8917, /* DiagArray424 */ 1262, /* Empty */         0 },
  { /* missing-variable-declarations */                         8933, /* DiagArray425 */ 1264, /* Empty */         0 },
  { /* module-build */                                          8963, /* DiagArray426 */ 1266, /* Empty */         0 },
  { /* module-conflict */                                       8976, /* DiagArray427 */ 1271, /* Empty */         0 },
  { /* module-file-config-mismatch */                           8992, /* DiagArray428 */ 1274, /* Empty */         0 },
  { /* module-file-extension */                                 9020, /* DiagArray429 */ 1276, /* Empty */         0 },
  { /* module-import */                                         9042, /* DiagArray430 */ 1278, /* Empty */         0 },
  { /* module-import-in-extern-c */                             9056, /* DiagArray431 */ 1280, /* Empty */         0 },
  { /* modules-ambiguous-internal-linkage */                    9082, /* DiagArray432 */ 1282, /* Empty */         0 },
  { /* modules-import-nested-redundant */                       9117, /* DiagArray433 */ 1284, /* Empty */         0 },
  { /* most */                                                  9149, /* Empty */     0, /* DiagSubGroup434 */ 289 },
  { /* move */                                                  9154, /* Empty */     0, /* DiagSubGroup435 */ 321 },
  { /* msvc-include */                                          9159, /* Empty */     0, /* DiagSubGroup436 */ 326 },
  { /* msvc-not-found */                                        9172, /* DiagArray437 */ 1286, /* Empty */         0 },
  { /* multichar */                                             9187, /* DiagArray438 */ 1288, /* Empty */         0 },
  { /* multiple-move-vbase */                                   9197, /* DiagArray439 */ 1290, /* Empty */         0 },
  { /* narrowing */                                             9217, /* Empty */     0, /* DiagSubGroup440 */ 328 },
  { /* nested-anon-types */                                     9227, /* DiagArray441 */ 1292, /* Empty */         0 },
  { /* nested-externs */                                        9245, /* Empty */     0, /* Empty */         0 },
  { /* new-returns-null */                                      9260, /* DiagArray443 */ 1294, /* Empty */         0 },
  { /* newline-eof */                                           9277, /* DiagArray444 */ 1296, /* Empty */         0 },
  { /* noderef */                                               9289, /* DiagArray445 */ 1299, /* Empty */         0 },
  { /* noexcept-type */                                         9297, /* Empty */     0, /* DiagSubGroup446 */ 330 },
  { /* non-gcc */                                               9311, /* Empty */     0, /* DiagSubGroup447 */ 332 },
  { /* non-literal-null-conversion */                           9319, /* DiagArray448 */ 1303, /* Empty */         0 },
  { /* non-modular-include-in-framework-module */               9347, /* DiagArray449 */ 1305, /* Empty */         0 },
  { /* non-modular-include-in-module */                         9387, /* DiagArray450 */ 1307, /* DiagSubGroup450 */ 336 },
  { /* non-pod-varargs */                                       9417, /* DiagArray451 */ 1309, /* Empty */         0 },
  { /* non-virtual-dtor */                                      9433, /* DiagArray452 */ 1314, /* Empty */         0 },
  { /* nonnull */                                               9450, /* DiagArray453 */ 1316, /* Empty */         0 },
  { /* nonportable-cfstrings */                                 9458, /* Empty */     0, /* Empty */         0 },
  { /* nonportable-include-path */                              9480, /* DiagArray455 */ 1319, /* Empty */         0 },
  { /* nonportable-system-include-path */                       9505, /* DiagArray456 */ 1321, /* Empty */         0 },
  { /* nonportable-vector-initialization */                     9537, /* DiagArray457 */ 1323, /* Empty */         0 },
  { /* nontrivial-memaccess */                                  9571, /* DiagArray458 */ 1325, /* Empty */         0 },
  { /* nsconsumed-mismatch */                                   9592, /* DiagArray459 */ 1327, /* Empty */         0 },
  { /* nsreturns-mismatch */                                    9612, /* DiagArray460 */ 1329, /* Empty */         0 },
  { /* null-arithmetic */                                       9631, /* DiagArray461 */ 1331, /* Empty */         0 },
  { /* null-character */                                        9647, /* DiagArray462 */ 1334, /* Empty */         0 },
  { /* null-conversion */                                       9662, /* DiagArray463 */ 1337, /* Empty */         0 },
  { /* null-dereference */                                      9678, /* DiagArray464 */ 1339, /* Empty */         0 },
  { /* null-pointer-arithmetic */                               9695, /* DiagArray465 */ 1342, /* Empty */         0 },
  { /* nullability */                                           9719, /* DiagArray466 */ 1345, /* Empty */         0 },
  { /* nullability-completeness */                              9731, /* DiagArray467 */ 1351, /* DiagSubGroup467 */ 338 },
  { /* nullability-completeness-on-arrays */                    9756, /* DiagArray468 */ 1353, /* Empty */         0 },
  { /* nullability-declspec */                                  9791, /* DiagArray469 */ 1355, /* Empty */         0 },
  { /* nullability-extension */                                 9812, /* DiagArray470 */ 1357, /* Empty */         0 },
  { /* nullability-inferred-on-nested-type */                   9834, /* DiagArray471 */ 1359, /* Empty */         0 },
  { /* nullable-to-nonnull-conversion */                        9870, /* DiagArray472 */ 1361, /* Empty */         0 },
  { /* objc-autosynthesis-property-ivar-name-match */           9901, /* DiagArray473 */ 1363, /* Empty */         0 },
  { /* objc-bool-constant-conversion */                         9945, /* DiagArray474 */ 1365, /* Empty */         0 },
  { /* objc-boxing */                                           9975, /* DiagArray475 */ 1367, /* Empty */         0 },
  { /* objc-circular-container */                               9987, /* DiagArray476 */ 1369, /* Empty */         0 },
  { /* objc-cocoa-api */                                        10011, /* Empty */     0, /* DiagSubGroup477 */ 340 },
  { /* objc-designated-initializers */                          10026, /* DiagArray478 */ 1371, /* Empty */         0 },
  { /* objc-flexible-array */                                   10055, /* DiagArray479 */ 1378, /* Empty */         0 },
  { /* objc-forward-class-redefinition */                       10075, /* DiagArray480 */ 1381, /* Empty */         0 },
  { /* objc-interface-ivars */                                  10107, /* DiagArray481 */ 1383, /* Empty */         0 },
  { /* objc-literal-compare */                                  10128, /* DiagArray482 */ 1385, /* DiagSubGroup482 */ 342 },
  { /* objc-literal-conversion */                               10149, /* DiagArray483 */ 1387, /* Empty */         0 },
  { /* objc-macro-redefinition */                               10173, /* DiagArray484 */ 1390, /* Empty */         0 },
  { /* objc-messaging-id */                                     10197, /* DiagArray485 */ 1392, /* Empty */         0 },
  { /* objc-method-access */                                    10215, /* DiagArray486 */ 1394, /* Empty */         0 },
  { /* objc-missing-property-synthesis */                       10234, /* DiagArray487 */ 1401, /* Empty */         0 },
  { /* objc-missing-super-calls */                              10266, /* DiagArray488 */ 1403, /* Empty */         0 },
  { /* objc-multiple-method-names */                            10291, /* DiagArray489 */ 1405, /* Empty */         0 },
  { /* objc-noncopy-retain-block-property */                    10318, /* DiagArray490 */ 1407, /* Empty */         0 },
  { /* objc-nonunified-exceptions */                            10353, /* DiagArray491 */ 1409, /* Empty */         0 },
  { /* objc-property-assign-on-object-type */                   10380, /* DiagArray492 */ 1411, /* Empty */         0 },
  { /* objc-property-implementation */                          10416, /* DiagArray493 */ 1413, /* Empty */         0 },
  { /* objc-property-implicit-mismatch */                       10445, /* DiagArray494 */ 1418, /* Empty */         0 },
  { /* objc-property-matches-cocoa-ownership-rule */            10477, /* DiagArray495 */ 1420, /* Empty */         0 },
  { /* objc-property-no-attribute */                            10520, /* DiagArray496 */ 1422, /* Empty */         0 },
  { /* objc-property-synthesis */                               10547, /* DiagArray497 */ 1425, /* Empty */         0 },
  { /* objc-protocol-method-implementation */                   10571, /* DiagArray498 */ 1429, /* Empty */         0 },
  { /* objc-protocol-property-synthesis */                      10607, /* DiagArray499 */ 1431, /* Empty */         0 },
  { /* objc-protocol-qualifiers */                              10640, /* DiagArray500 */ 1433, /* Empty */         0 },
  { /* objc-readonly-with-setter-property */                    10665, /* DiagArray501 */ 1435, /* Empty */         0 },
  { /* objc-redundant-api-use */                                10700, /* Empty */     0, /* DiagSubGroup502 */ 344 },
  { /* objc-redundant-literal-use */                            10723, /* DiagArray503 */ 1437, /* Empty */         0 },
  { /* objc-root-class */                                       10750, /* DiagArray504 */ 1439, /* Empty */         0 },
  { /* objc-string-compare */                                   10766, /* DiagArray505 */ 1441, /* Empty */         0 },
  { /* objc-string-concatenation */                             10786, /* DiagArray506 */ 1443, /* Empty */         0 },
  { /* objc-unsafe-perform-selector */                          10812, /* DiagArray507 */ 1445, /* Empty */         0 },
  { /* odr */                                                   10841, /* DiagArray508 */ 1447, /* Empty */         0 },
  { /* old-style-cast */                                        10845, /* DiagArray509 */ 1466, /* Empty */         0 },
  { /* old-style-definition */                                  10860, /* Empty */     0, /* Empty */         0 },
  { /* opencl-unsupported-rgba */                               10881, /* DiagArray511 */ 1468, /* Empty */         0 },
  { /* openmp-clauses */                                        10905, /* DiagArray512 */ 1470, /* Empty */         0 },
  { /* openmp-loop-form */                                      10920, /* DiagArray513 */ 1475, /* Empty */         0 },
  { /* openmp-target */                                         10937, /* DiagArray514 */ 1478, /* Empty */         0 },
  { /* option-ignored */                                        10951, /* DiagArray515 */ 1483, /* Empty */         0 },
  { /* ordered-compare-function-pointers */                     10966, /* DiagArray516 */ 1490, /* Empty */         0 },
  { /* out-of-line-declaration */                               11000, /* DiagArray517 */ 1492, /* Empty */         0 },
  { /* out-of-scope-function */                                 11024, /* DiagArray518 */ 1494, /* Empty */         0 },
  { /* over-aligned */                                          11046, /* DiagArray519 */ 1496, /* Empty */         0 },
  { /* overflow */                                              11059, /* Empty */     0, /* Empty */         0 },
  { /* overlength-strings */                                    11068, /* DiagArray521 */ 1498, /* Empty */         0 },
  { /* overloaded-shift-op-parentheses */                       11087, /* DiagArray522 */ 1500, /* Empty */         0 },
  { /* overloaded-virtual */                                    11119, /* DiagArray523 */ 1502, /* Empty */         0 },
  { /* override-init */                                         11138, /* Empty */     0, /* DiagSubGroup524 */ 346 },
  { /* override-module */                                       11152, /* DiagArray525 */ 1504, /* Empty */         0 },
  { /* overriding-method-mismatch */                            11168, /* DiagArray526 */ 1506, /* Empty */         0 },
  { /* overriding-t-option */                                   11195, /* DiagArray527 */ 1514, /* Empty */         0 },
  { /* packed */                                                11215, /* DiagArray528 */ 1516, /* Empty */         0 },
  { /* padded */                                                11222, /* DiagArray529 */ 1518, /* Empty */         0 },
  { /* parentheses */                                           11229, /* DiagArray530 */ 1522, /* DiagSubGroup530 */ 348 },
  { /* parentheses-equality */                                  11241, /* DiagArray531 */ 1526, /* Empty */         0 },
  { /* partial-availability */                                  11262, /* Empty */     0, /* DiagSubGroup532 */ 356 },
  { /* pass */                                                  11283, /* DiagArray533 */ 1528, /* Empty */         0 },
  { /* pass-analysis */                                         11288, /* DiagArray534 */ 1530, /* Empty */         0 },
  { /* pass-failed */                                           11302, /* DiagArray535 */ 1534, /* Empty */         0 },
  { /* pass-missed */                                           11314, /* DiagArray536 */ 1536, /* Empty */         0 },
  { /* pch-date-time */                                         11326, /* DiagArray537 */ 1538, /* Empty */         0 },
  { /* pedantic */                                              11340, /* DiagArray538 */ 1540, /* DiagSubGroup538 */ 358 },
  { /* pedantic-core-features */                                11349, /* DiagArray539 */ 1612, /* Empty */         0 },
  { /* pessimizing-move */                                      11372, /* DiagArray540 */ 1614, /* Empty */         0 },
  { /* pointer-arith */                                         11389, /* DiagArray541 */ 1617, /* Empty */         0 },
  { /* pointer-bool-conversion */                               11403, /* DiagArray542 */ 1624, /* Empty */         0 },
  { /* pointer-integer-compare */                               11427, /* DiagArray543 */ 1627, /* Empty */         0 },
  { /* pointer-sign */                                          11451, /* DiagArray544 */ 1629, /* Empty */         0 },
  { /* pointer-to-int-cast */                                   11464, /* Empty */     0, /* Empty */         0 },
  { /* pointer-type-mismatch */                                 11484, /* DiagArray546 */ 1631, /* Empty */         0 },
  { /* potentially-evaluated-expression */                      11506, /* DiagArray547 */ 1633, /* Empty */         0 },
  { /* pragma-clang-attribute */                                11539, /* DiagArray548 */ 1635, /* Empty */         0 },
  { /* pragma-once-outside-header */                            11562, /* DiagArray549 */ 1637, /* Empty */         0 },
  { /* pragma-pack */                                           11589, /* DiagArray550 */ 1639, /* DiagSubGroup550 */ 410 },
  { /* pragma-pack-suspicious-include */                        11601, /* DiagArray551 */ 1642, /* Empty */         0 },
  { /* pragma-system-header-outside-header */                   11632, /* DiagArray552 */ 1644, /* Empty */         0 },
  { /* pragmas */                                               11668, /* DiagArray553 */ 1646, /* DiagSubGroup553 */ 412 },
  { /* predefined-identifier-outside-function */                11676, /* DiagArray554 */ 1648, /* Empty */         0 },
  { /* private-extern */                                        11715, /* DiagArray555 */ 1650, /* Empty */         0 },
  { /* private-header */                                        11730, /* DiagArray556 */ 1652, /* Empty */         0 },
  { /* private-module */                                        11745, /* DiagArray557 */ 1654, /* Empty */         0 },
  { /* profile-instr-missing */                                 11760, /* DiagArray558 */ 1659, /* Empty */         0 },
  { /* profile-instr-out-of-date */                             11782, /* DiagArray559 */ 1661, /* Empty */         0 },
  { /* profile-instr-unprofiled */                              11808, /* DiagArray560 */ 1663, /* Empty */         0 },
  { /* property-access-dot-syntax */                            11833, /* DiagArray561 */ 1665, /* Empty */         0 },
  { /* property-attribute-mismatch */                           11860, /* DiagArray562 */ 1667, /* Empty */         0 },
  { /* protocol */                                              11888, /* DiagArray563 */ 1672, /* Empty */         0 },
  { /* protocol-property-synthesis-ambiguity */                 11897, /* DiagArray564 */ 1674, /* Empty */         0 },
  { /* qualified-void-return-type */                            11935, /* DiagArray565 */ 1676, /* Empty */         0 },
  { /* quoted-include-in-framework-header */                    11962, /* DiagArray566 */ 1678, /* Empty */         0 },
  { /* range-loop-analysis */                                   11997, /* DiagArray567 */ 1680, /* Empty */         0 },
  { /* readonly-iboutlet-property */                            12017, /* DiagArray568 */ 1684, /* Empty */         0 },
  { /* receiver-expr */                                         12044, /* DiagArray569 */ 1686, /* Empty */         0 },
  { /* receiver-forward-class */                                12058, /* DiagArray570 */ 1688, /* Empty */         0 },
  { /* redeclared-class-member */                               12081, /* DiagArray571 */ 1691, /* Empty */         0 },
  { /* redundant-decls */                                       12105, /* Empty */     0, /* Empty */         0 },
  { /* redundant-move */                                        12121, /* DiagArray573 */ 1693, /* Empty */         0 },
  { /* redundant-parens */                                      12136, /* DiagArray574 */ 1695, /* Empty */         0 },
  { /* register */                                              12153, /* DiagArray575 */ 1697, /* DiagSubGroup575 */ 417 },
  { /* reinterpret-base-class */                                12162, /* DiagArray576 */ 1699, /* Empty */         0 },
  { /* remark-backend-plugin */                                 12185, /* DiagArray577 */ 1701, /* Empty */         0 },
  { /* reorder */                                               12207, /* DiagArray578 */ 1703, /* Empty */         0 },
  { /* requires-super-attribute */                              12215, /* DiagArray579 */ 1705, /* Empty */         0 },
  { /* reserved-id-macro */                                     12240, /* DiagArray580 */ 1707, /* Empty */         0 },
  { /* reserved-user-defined-literal */                         12258, /* DiagArray581 */ 1709, /* DiagSubGroup581 */ 419 },
  { /* retained-language-linkage */                             12288, /* DiagArray582 */ 1712, /* Empty */         0 },
  { /* return-stack-address */                                  12314, /* DiagArray583 */ 1714, /* Empty */         0 },
  { /* return-std-move */                                       12335, /* DiagArray584 */ 1718, /* Empty */         0 },
  { /* return-std-move-in-c++11 */                              12351, /* DiagArray585 */ 1720, /* Empty */         0 },
  { /* return-type */                                           12376, /* DiagArray586 */ 1722, /* DiagSubGroup586 */ 421 },
  { /* return-type-c-linkage */                                 12388, /* DiagArray587 */ 1732, /* Empty */         0 },
  { /* sanitize-address */                                      12410, /* DiagArray588 */ 1735, /* Empty */         0 },
  { /* section */                                               12427, /* DiagArray589 */ 1738, /* Empty */         0 },
  { /* selector */                                              12435, /* DiagArray590 */ 1742, /* DiagSubGroup590 */ 423 },
  { /* selector-type-mismatch */                                12444, /* DiagArray591 */ 1744, /* Empty */         0 },
  { /* self-assign */                                           12467, /* DiagArray592 */ 1746, /* DiagSubGroup592 */ 425 },
  { /* self-assign-field */                                     12479, /* DiagArray593 */ 1748, /* Empty */         0 },
  { /* self-assign-overloaded */                                12497, /* DiagArray594 */ 1750, /* Empty */         0 },
  { /* self-move */                                             12520, /* DiagArray595 */ 1752, /* Empty */         0 },
  { /* semicolon-before-method-body */                          12530, /* DiagArray596 */ 1754, /* Empty */         0 },
  { /* sentinel */                                              12559, /* DiagArray597 */ 1756, /* Empty */         0 },
  { /* sequence-point */                                        12568, /* Empty */     0, /* DiagSubGroup598 */ 428 },
  { /* serialized-diagnostics */                                12583, /* DiagArray599 */ 1759, /* Empty */         0 },
  { /* shadow */                                                12606, /* DiagArray600 */ 1762, /* DiagSubGroup600 */ 430 },
  { /* shadow-all */                                            12613, /* Empty */     0, /* DiagSubGroup601 */ 433 },
  { /* shadow-field */                                          12624, /* DiagArray602 */ 1764, /* Empty */         0 },
  { /* shadow-field-in-constructor */                           12637, /* DiagArray603 */ 1766, /* DiagSubGroup603 */ 438 },
  { /* shadow-field-in-constructor-modified */                  12665, /* DiagArray604 */ 1768, /* Empty */         0 },
  { /* shadow-ivar */                                           12702, /* DiagArray605 */ 1770, /* Empty */         0 },
  { /* shadow-uncaptured-local */                               12714, /* DiagArray606 */ 1772, /* Empty */         0 },
  { /* shift-count-negative */                                  12738, /* DiagArray607 */ 1774, /* Empty */         0 },
  { /* shift-count-overflow */                                  12759, /* DiagArray608 */ 1776, /* Empty */         0 },
  { /* shift-negative-value */                                  12780, /* DiagArray609 */ 1778, /* Empty */         0 },
  { /* shift-op-parentheses */                                  12801, /* DiagArray610 */ 1780, /* Empty */         0 },
  { /* shift-overflow */                                        12822, /* DiagArray611 */ 1782, /* Empty */         0 },
  { /* shift-sign-overflow */                                   12837, /* DiagArray612 */ 1784, /* Empty */         0 },
  { /* shorten-64-to-32 */                                      12857, /* DiagArray613 */ 1786, /* Empty */         0 },
  { /* sign-compare */                                          12874, /* DiagArray614 */ 1788, /* Empty */         0 },
  { /* sign-conversion */                                       12887, /* DiagArray615 */ 1790, /* Empty */         0 },
  { /* sign-promo */                                            12903, /* Empty */     0, /* Empty */         0 },
  { /* signed-enum-bitfield */                                  12914, /* DiagArray617 */ 1794, /* Empty */         0 },
  { /* sizeof-array-argument */                                 12935, /* DiagArray618 */ 1796, /* Empty */         0 },
  { /* sizeof-array-decay */                                    12957, /* DiagArray619 */ 1798, /* Empty */         0 },
  { /* sizeof-pointer-div */                                    12976, /* DiagArray620 */ 1800, /* Empty */         0 },
  { /* sizeof-pointer-memaccess */                              12995, /* DiagArray621 */ 1802, /* Empty */         0 },
  { /* slash-u-filename */                                      13020, /* DiagArray622 */ 1805, /* Empty */         0 },
  { /* sometimes-uninitialized */                               13037, /* DiagArray623 */ 1807, /* Empty */         0 },
  { /* source-uses-openmp */                                    13061, /* DiagArray624 */ 1809, /* Empty */         0 },
  { /* spir-compat */                                           13080, /* DiagArray625 */ 1812, /* Empty */         0 },
  { /* stack-protector */                                       13092, /* Empty */     0, /* Empty */         0 },
  { /* static-float-init */                                     13108, /* DiagArray627 */ 1814, /* DiagSubGroup627 */ 440 },
  { /* static-in-inline */                                      13126, /* DiagArray628 */ 1816, /* Empty */         0 },
  { /* static-inline-explicit-instantiation */                  13143, /* DiagArray629 */ 1819, /* Empty */         0 },
  { /* static-local-in-inline */                                13180, /* DiagArray630 */ 1821, /* Empty */         0 },
  { /* static-self-init */                                      13203, /* DiagArray631 */ 1823, /* Empty */         0 },
  { /* stdlibcxx-not-found */                                   13220, /* DiagArray632 */ 1825, /* Empty */         0 },
  { /* strict-aliasing */                                       13240, /* Empty */     0, /* Empty */         0 },
  { /* strict-aliasing=0 */                                     13256, /* Empty */     0, /* Empty */         0 },
  { /* strict-aliasing=1 */                                     13274, /* Empty */     0, /* Empty */         0 },
  { /* strict-aliasing=2 */                                     13292, /* Empty */     0, /* Empty */         0 },
  { /* strict-overflow */                                       13310, /* Empty */     0, /* Empty */         0 },
  { /* strict-overflow=0 */                                     13326, /* Empty */     0, /* Empty */         0 },
  { /* strict-overflow=1 */                                     13344, /* Empty */     0, /* Empty */         0 },
  { /* strict-overflow=2 */                                     13362, /* Empty */     0, /* Empty */         0 },
  { /* strict-overflow=3 */                                     13380, /* Empty */     0, /* Empty */         0 },
  { /* strict-overflow=4 */                                     13398, /* Empty */     0, /* Empty */         0 },
  { /* strict-overflow=5 */                                     13416, /* Empty */     0, /* Empty */         0 },
  { /* strict-prototypes */                                     13434, /* DiagArray644 */ 1827, /* Empty */         0 },
  { /* strict-selector-match */                                 13452, /* DiagArray645 */ 1829, /* Empty */         0 },
  { /* string-compare */                                        13474, /* DiagArray646 */ 1831, /* Empty */         0 },
  { /* string-conversion */                                     13489, /* DiagArray647 */ 1833, /* Empty */         0 },
  { /* string-plus-char */                                      13507, /* DiagArray648 */ 1835, /* Empty */         0 },
  { /* string-plus-int */                                       13524, /* DiagArray649 */ 1837, /* Empty */         0 },
  { /* strlcpy-strlcat-size */                                  13540, /* DiagArray650 */ 1839, /* Empty */         0 },
  { /* strncat-size */                                          13561, /* DiagArray651 */ 1841, /* Empty */         0 },
  { /* super-class-method-mismatch */                           13574, /* DiagArray652 */ 1845, /* Empty */         0 },
  { /* suspicious-bzero */                                      13602, /* DiagArray653 */ 1847, /* Empty */         0 },
  { /* suspicious-memaccess */                                  13619, /* Empty */     0, /* DiagSubGroup654 */ 442 },
  { /* switch */                                                13640, /* DiagArray655 */ 1849, /* Empty */         0 },
  { /* switch-bool */                                           13647, /* DiagArray656 */ 1853, /* Empty */         0 },
  { /* switch-default */                                        13659, /* Empty */     0, /* Empty */         0 },
  { /* switch-enum */                                           13674, /* DiagArray658 */ 1855, /* Empty */         0 },
  { /* sync-fetch-and-nand-semantics-changed */                 13686, /* DiagArray659 */ 1857, /* Empty */         0 },
  { /* synth */                                                 13724, /* Empty */     0, /* Empty */         0 },
  { /* tautological-compare */                                  13730, /* DiagArray661 */ 1859, /* DiagSubGroup661 */ 448 },
  { /* tautological-constant-compare */                         13751, /* DiagArray662 */ 1862, /* DiagSubGroup662 */ 454 },
  { /* tautological-constant-in-range-compare */                13781, /* Empty */     0, /* DiagSubGroup663 */ 456 },
  { /* tautological-constant-out-of-range-compare */            13820, /* DiagArray664 */ 1864, /* Empty */         0 },
  { /* tautological-objc-bool-compare */                        13863, /* DiagArray665 */ 1866, /* Empty */         0 },
  { /* tautological-overlap-compare */                          13894, /* DiagArray666 */ 1868, /* Empty */         0 },
  { /* tautological-pointer-compare */                          13923, /* DiagArray667 */ 1870, /* Empty */         0 },
  { /* tautological-type-limit-compare */                       13952, /* DiagArray668 */ 1873, /* Empty */         0 },
  { /* tautological-undefined-compare */                        13984, /* DiagArray669 */ 1875, /* Empty */         0 },
  { /* tautological-unsigned-enum-zero-compare */               14015, /* DiagArray670 */ 1878, /* Empty */         0 },
  { /* tautological-unsigned-zero-compare */                    14055, /* DiagArray671 */ 1880, /* Empty */         0 },
  { /* tentative-definition-incomplete-type */                  14090, /* DiagArray672 */ 1882, /* Empty */         0 },
  { /* thread-safety */                                         14127, /* Empty */     0, /* DiagSubGroup673 */ 460 },
  { /* thread-safety-analysis */                                14141, /* DiagArray674 */ 1884, /* Empty */         0 },
  { /* thread-safety-attributes */                              14164, /* DiagArray675 */ 1902, /* Empty */         0 },
  { /* thread-safety-beta */                                    14189, /* DiagArray676 */ 1910, /* Empty */         0 },
  { /* thread-safety-negative */                                14208, /* DiagArray677 */ 1912, /* Empty */         0 },
  { /* thread-safety-precise */                                 14231, /* DiagArray678 */ 1914, /* Empty */         0 },
  { /* thread-safety-reference */                               14253, /* DiagArray679 */ 1918, /* Empty */         0 },
  { /* thread-safety-verbose */                                 14277, /* DiagArray680 */ 1921, /* Empty */         0 },
  { /* trigraphs */                                             14299, /* DiagArray681 */ 1923, /* Empty */         0 },
  { /* type-limits */                                           14309, /* Empty */     0, /* DiagSubGroup682 */ 465 },
  { /* type-safety */                                           14321, /* DiagArray683 */ 1928, /* Empty */         0 },
  { /* typedef-redefinition */                                  14333, /* DiagArray684 */ 1932, /* Empty */         0 },
  { /* typename-missing */                                      14354, /* DiagArray685 */ 1934, /* Empty */         0 },
  { /* unable-to-open-stats-file */                             14371, /* DiagArray686 */ 1936, /* Empty */         0 },
  { /* unavailable-declarations */                              14397, /* DiagArray687 */ 1938, /* Empty */         0 },
  { /* undeclared-selector */                                   14422, /* DiagArray688 */ 1940, /* Empty */         0 },
  { /* undef */                                                 14442, /* DiagArray689 */ 1943, /* Empty */         0 },
  { /* undefined-bool-conversion */                             14448, /* DiagArray690 */ 1945, /* Empty */         0 },
  { /* undefined-func-template */                               14474, /* DiagArray691 */ 1948, /* Empty */         0 },
  { /* undefined-inline */                                      14498, /* DiagArray692 */ 1950, /* Empty */         0 },
  { /* undefined-internal */                                    14515, /* DiagArray693 */ 1952, /* Empty */         0 },
  { /* undefined-internal-type */                               14534, /* DiagArray694 */ 1954, /* Empty */         0 },
  { /* undefined-reinterpret-cast */                            14558, /* DiagArray695 */ 1956, /* Empty */         0 },
  { /* undefined-var-template */                                14585, /* DiagArray696 */ 1959, /* Empty */         0 },
  { /* underaligned-exception-object */                         14608, /* DiagArray697 */ 1961, /* Empty */         0 },
  { /* unevaluated-expression */                                14638, /* DiagArray698 */ 1963, /* DiagSubGroup698 */ 467 },
  { /* unguarded-availability */                                14661, /* DiagArray699 */ 1965, /* DiagSubGroup699 */ 469 },
  { /* unguarded-availability-new */                            14684, /* DiagArray700 */ 1967, /* Empty */         0 },
  { /* unicode */                                               14711, /* DiagArray701 */ 1969, /* Empty */         0 },
  { /* unicode-homoglyph */                                     14719, /* DiagArray702 */ 1975, /* Empty */         0 },
  { /* unicode-whitespace */                                    14737, /* DiagArray703 */ 1977, /* Empty */         0 },
  { /* unicode-zero-width */                                    14756, /* DiagArray704 */ 1979, /* Empty */         0 },
  { /* uninitialized */                                         14775, /* DiagArray705 */ 1981, /* DiagSubGroup705 */ 471 },
  { /* unknown-argument */                                      14789, /* DiagArray706 */ 1989, /* Empty */         0 },
  { /* unknown-attributes */                                    14806, /* DiagArray707 */ 1992, /* Empty */         0 },
  { /* unknown-escape-sequence */                               14825, /* DiagArray708 */ 1994, /* Empty */         0 },
  { /* unknown-pragmas */                                       14849, /* DiagArray709 */ 1996, /* Empty */         0 },
  { /* unknown-sanitizers */                                    14865, /* DiagArray710 */ 2017, /* Empty */         0 },
  { /* unknown-warning-option */                                14884, /* DiagArray711 */ 2019, /* Empty */         0 },
  { /* unnamed-type-template-args */                            14907, /* DiagArray712 */ 2023, /* DiagSubGroup712 */ 474 },
  { /* unneeded-internal-declaration */                         14934, /* DiagArray713 */ 2025, /* Empty */         0 },
  { /* unneeded-member-function */                              14964, /* DiagArray714 */ 2028, /* Empty */         0 },
  { /* unreachable-code */                                      14989, /* DiagArray715 */ 2030, /* DiagSubGroup715 */ 476 },
  { /* unreachable-code-aggressive */                           15006, /* Empty */     0, /* DiagSubGroup716 */ 478 },
  { /* unreachable-code-break */                                15034, /* DiagArray717 */ 2032, /* Empty */         0 },
  { /* unreachable-code-loop-increment */                       15057, /* DiagArray718 */ 2034, /* Empty */         0 },
  { /* unreachable-code-return */                               15089, /* DiagArray719 */ 2036, /* Empty */         0 },
  { /* unsequenced */                                           15113, /* DiagArray720 */ 2038, /* Empty */         0 },
  { /* unsupported-abs */                                       15125, /* DiagArray721 */ 2041, /* Empty */         0 },
  { /* unsupported-availability-guard */                        15141, /* DiagArray722 */ 2044, /* Empty */         0 },
  { /* unsupported-cb */                                        15172, /* DiagArray723 */ 2046, /* Empty */         0 },
  { /* unsupported-dll-base-class-template */                   15187, /* DiagArray724 */ 2048, /* Empty */         0 },
  { /* unsupported-friend */                                    15223, /* DiagArray725 */ 2050, /* Empty */         0 },
  { /* unsupported-gpopt */                                     15242, /* DiagArray726 */ 2053, /* Empty */         0 },
  { /* unsupported-nan */                                       15260, /* DiagArray727 */ 2055, /* Empty */         0 },
  { /* unsupported-target-opt */                                15276, /* DiagArray728 */ 2058, /* Empty */         0 },
  { /* unsupported-visibility */                                15299, /* DiagArray729 */ 2060, /* Empty */         0 },
  { /* unusable-partial-specialization */                       15322, /* DiagArray730 */ 2062, /* Empty */         0 },
  { /* unused */                                                15354, /* Empty */     0, /* DiagSubGroup731 */ 482 },
  { /* unused-argument */                                       15361, /* Empty */     0, /* Empty */         0 },
  { /* unused-command-line-argument */                          15377, /* DiagArray733 */ 2064, /* Empty */         0 },
  { /* unused-comparison */                                     15406, /* DiagArray734 */ 2072, /* Empty */         0 },
  { /* unused-const-variable */                                 15424, /* DiagArray735 */ 2074, /* Empty */         0 },
  { /* unused-exception-parameter */                            15446, /* DiagArray736 */ 2076, /* Empty */         0 },
  { /* unused-function */                                       15473, /* DiagArray737 */ 2078, /* DiagSubGroup737 */ 492 },
  { /* unused-getter-return-value */                            15489, /* DiagArray738 */ 2080, /* Empty */         0 },
  { /* unused-label */                                          15516, /* DiagArray739 */ 2082, /* Empty */         0 },
  { /* unused-lambda-capture */                                 15529, /* DiagArray740 */ 2084, /* Empty */         0 },
  { /* unused-local-typedef */                                  15551, /* DiagArray741 */ 2086, /* Empty */         0 },
  { /* unused-local-typedefs */                                 15572, /* Empty */     0, /* DiagSubGroup742 */ 494 },
  { /* unused-macros */                                         15594, /* DiagArray743 */ 2088, /* Empty */         0 },
  { /* unused-member-function */                                15608, /* DiagArray744 */ 2090, /* DiagSubGroup744 */ 496 },
  { /* unused-parameter */                                      15631, /* DiagArray745 */ 2092, /* Empty */         0 },
  { /* unused-private-field */                                  15648, /* DiagArray746 */ 2094, /* Empty */         0 },
  { /* unused-property-ivar */                                  15669, /* DiagArray747 */ 2096, /* Empty */         0 },
  { /* unused-result */                                         15690, /* DiagArray748 */ 2098, /* Empty */         0 },
  { /* unused-template */                                       15704, /* DiagArray749 */ 2100, /* DiagSubGroup749 */ 498 },
  { /* unused-value */                                          15720, /* DiagArray750 */ 2102, /* DiagSubGroup750 */ 500 },
  { /* unused-variable */                                       15733, /* DiagArray751 */ 2107, /* DiagSubGroup751 */ 504 },
  { /* unused-volatile-lvalue */                                15749, /* DiagArray752 */ 2109, /* Empty */         0 },
  { /* used-but-marked-unused */                                15772, /* DiagArray753 */ 2111, /* Empty */         0 },
  { /* user-defined-literals */                                 15795, /* DiagArray754 */ 2113, /* Empty */         0 },
  { /* user-defined-warnings */                                 15817, /* DiagArray755 */ 2115, /* Empty */         0 },
  { /* varargs */                                               15839, /* DiagArray756 */ 2117, /* Empty */         0 },
  { /* variadic-macros */                                       15847, /* DiagArray757 */ 2121, /* Empty */         0 },
  { /* vec-elem-size */                                         15863, /* DiagArray758 */ 2125, /* Empty */         0 },
  { /* vector-conversion */                                     15877, /* DiagArray759 */ 2127, /* Empty */         0 },
  { /* vector-conversions */                                    15895, /* Empty */     0, /* DiagSubGroup760 */ 506 },
  { /* vexing-parse */                                          15914, /* DiagArray761 */ 2129, /* Empty */         0 },
  { /* visibility */                                            15927, /* DiagArray762 */ 2133, /* Empty */         0 },
  { /* vla */                                                   15938, /* DiagArray763 */ 2136, /* Empty */         0 },
  { /* vla-extension */                                         15942, /* DiagArray764 */ 2138, /* Empty */         0 },
  { /* void-ptr-dereference */                                  15956, /* DiagArray765 */ 2140, /* Empty */         0 },
  { /* volatile-register-var */                                 15977, /* Empty */     0, /* Empty */         0 },
  { /* weak-template-vtables */                                 15999, /* DiagArray767 */ 2142, /* Empty */         0 },
  { /* weak-vtables */                                          16021, /* DiagArray768 */ 2144, /* Empty */         0 },
  { /* writable-strings */                                      16034, /* DiagArray769 */ 2146, /* DiagSubGroup769 */ 508 },
  { /* write-strings */                                         16051, /* Empty */     0, /* DiagSubGroup770 */ 510 },
  { /* zero-as-null-pointer-constant */                         16065, /* DiagArray771 */ 2148, /* Empty */         0 },
  { /* zero-length-array */                                     16095, /* DiagArray772 */ 2150, /* Empty */         0 },
#endif // GET_DIAG_TABLE


#ifdef GET_CATEGORY_TABLE
CATEGORY("", DiagCat_None)
CATEGORY("Lexical or Preprocessor Issue", DiagCat_Lexical_or_Preprocessor_Issue)
CATEGORY("Semantic Issue", DiagCat_Semantic_Issue)
CATEGORY("Lambda Issue", DiagCat_Lambda_Issue)
CATEGORY("Parse Issue", DiagCat_Parse_Issue)
CATEGORY("ARC Semantic Issue", DiagCat_ARC_Semantic_Issue)
CATEGORY("ARC and @properties", DiagCat_ARC_and__properties)
CATEGORY("ARC Casting Rules", DiagCat_ARC_Casting_Rules)
CATEGORY("ARC Parse Issue", DiagCat_ARC_Parse_Issue)
CATEGORY("ARC Weak References", DiagCat_ARC_Weak_References)
CATEGORY("ARC Restrictions", DiagCat_ARC_Restrictions)
CATEGORY("OpenMP Issue", DiagCat_OpenMP_Issue)
CATEGORY("Inline Assembly Issue", DiagCat_Inline_Assembly_Issue)
CATEGORY("Modules Issue", DiagCat_Modules_Issue)
CATEGORY("Coroutines Issue", DiagCat_Coroutines_Issue)
CATEGORY("Concepts Issue", DiagCat_Concepts_Issue)
CATEGORY("Dependency Directive Source Minimization Issue", DiagCat_Dependency_Directive_Source_Minimization_Issue)
CATEGORY("AST Deserialization Issue", DiagCat_AST_Deserialization_Issue)
CATEGORY("Backend Issue", DiagCat_Backend_Issue)
CATEGORY("Related Result Type Issue", DiagCat_Related_Result_Type_Issue)
CATEGORY("AST Serialization Issue", DiagCat_AST_Serialization_Issue)
CATEGORY("Nullability Issue", DiagCat_Nullability_Issue)
CATEGORY("Generics Issue", DiagCat_Generics_Issue)
CATEGORY("User-Defined Issue", DiagCat_User_Defined_Issue)
CATEGORY("Refactoring Invocation Issue", DiagCat_Refactoring_Invocation_Issue)
CATEGORY("VTable ABI Issue", DiagCat_VTable_ABI_Issue)
CATEGORY("Value Conversion Issue", DiagCat_Value_Conversion_Issue)
CATEGORY("Documentation Issue", DiagCat_Documentation_Issue)
CATEGORY("ARC Retain Cycle", DiagCat_ARC_Retain_Cycle)
CATEGORY("Deprecations", DiagCat_Deprecations)
CATEGORY("Format String Issue", DiagCat_Format_String_Issue)
CATEGORY("Cocoa API Issue", DiagCat_Cocoa_API_Issue)
CATEGORY("#pragma message Directive", DiagCat__pragma_message_Directive)
CATEGORY("Instrumentation Issue", DiagCat_Instrumentation_Issue)
CATEGORY("Unused Entity Issue", DiagCat_Unused_Entity_Issue)
#endif // GET_CATEGORY_TABLE

